<?php
/**
 * SNS Get theme options - post meta.
 * This function to get the options in theme option and the page config.
 * The option in page config will priority than the option in theme option if set.
 * 
 * @param string $option ID of the option to get. Required.
 * @param string|int|null $default Return to default value. Optional.
 * @param string $key. Enter the key if the $option is an array. Default leave blank. Optional.
 * 					   This only support for theme option.
 * 
 * @return the value of theme option or page config. If the page config leave blank or "def" return theme option.
 */
function snsbiamuc_get_option($option, $default = '', $key = ''){
	global $snsbiamuc_obj;
	
	return $snsbiamuc_obj->getOption($option, $default, $key);
}

function snsbiamuc_set_themeoption($key, $value){
	global $snsbiamuc_opt;
	if ( $key != '' && $value != '' )
		$snsbiamuc_opt[$key] = $value;
}

/*
 * get meta box data
 */
function snsbiamuc_metabox($field_id, $args = array()){
	if( !function_exists('rwmb_meta') ){
		return '';
	}
	if( function_exists('is_shop') && is_shop() ) {
		return rwmb_meta($field_id, $args, get_option('woocommerce_shop_page_id'));
	}
	return rwmb_meta($field_id, $args);
}

/**
* Display Social Accounts
*/
function snsbiamuc_print_social_icon(){
	$social_list = array(
		'facebook' => esc_html__( 'Facebook', 'snsbiamuc' ),
		'twitter' => esc_html__( 'Twitter', 'snsbiamuc' ),
		'flickr' => esc_html__( 'Flickr', 'snsbiamuc' ),
		'google-plus' => esc_html__( 'Google Plus', 'snsbiamuc' ),
		'pinterest' => esc_html__( 'Pinterest', 'snsbiamuc' ),
		'instagram' => esc_html__( 'Instagram', 'snsbiamuc' ),
		'youtube-play' => esc_html__( 'Youtute', 'snsbiamuc' )
	);?>
	<div class="sns-socials">
	<?php
		foreach ($social_list as $social => $social_title) {
			if( snsbiamuc_get_option($social) != '' ): ?>
				<a data-original-title="<?php echo esc_attr( $social_title );?>" data-toggle="tooltip" class="<?php echo esc_attr( $social )?>" href="<?php echo esc_url(snsbiamuc_get_option($social));?>" title="<?php echo esc_attr( $social_title );?>"><i class="fa fa-<?php echo esc_attr( $social );?>"></i></a>
			<?php
			endif;
		}
		?>
	</div>
	<?php
}

/**
 * Display Ajax loading
 * 
 * @param $content_div (string) ID of the DIV which contains items
 * @param $template (string) Name of the template file hold HTML for a single item.
 */
function snsbiamuc_paging_nav_ajax( $content_div = '#snsmain', $template = '' ){
	// Don't print empty markup if there is only one page.
	if( $GLOBALS['wp_query']->max_num_pages < 2 ){
		return;
	}
	
	?>
	<nav class="navigation-ajax" role="navigation">
		<a href="javascript:void(0)" data-target="<?php echo esc_attr($content_div);?>" data-template="<?php echo esc_attr($template); ?>" id="navigation-ajax" class="load-more">
			<span><?php echo esc_html__('Load more item', 'snsbiamuc');?></span>
			<div class="sns-navloading"><div class="sns-navloader"></div></div>
		</a>
	</nav>
	<?php
}

/**
 * Display navigation to next/previous post when applicable.
 */
function snsbiamuc_post_nav() {
	// Don't print empty markup if there's nowhere to navigate.
	$previous = ( is_attachment() ) ? get_post( get_post()->post_parent ) : get_adjacent_post( false, '', true );
	$next     = get_adjacent_post( false, '', false );

	if ( ! $next && ! $previous ) {
		return;
	}
	?>
	<div class="post-standard-navigation navigation post-navigation" role="navigation">
	    	<?php 
        	if( $previous ):
        	?>
	        <div class="nav-previous">
	            <div class="area-content">
	            	<?php
	            	previous_post_link('%link',''); // link overlay
	                ?>
	                <div class="nav-content">
	                	<?php 
	                		previous_post_link( '<div class="nav-post-link">%link</div>', _x( 'Previous post', 'Previous post link', 'snsbiamuc' ) );
						
							previous_post_link( '<div class="nav-post-title">%link</div>');?>
							
							<div class="nav-meta">
								<span class="nav-author"><i class="fa fa-user"></i><?php printf( wp_kses(__( '<a class="author-link" href="%s" rel="author">%s</a>', 'snsbiamuc' ), array(
																		'a' => array(
																			'href' => array(),
																			'class' => array(),
																			'ref' => array()
																		),
																		) ), esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ),  get_the_author_meta('display_name') );?></span>
								<?php
			            		if ( ! post_password_required() && ( comments_open() || get_comments_number() ) ) {
									echo '<span class="nav-comments-link"><i class="fa fa-comment"></i>';
									/* translators: %s: post title */
									comments_popup_link( esc_html__( '0 comment','snsbiamuc' ),  esc_html__( '1 comment','snsbiamuc' ), '%' . esc_html__(' comments','snsbiamuc'));
									echo '</span>';
								}
								?>
							</div>
	                </div>
	            </div>
	        </div>
	        <?php endif; ?>
	        <?php if( $next ): ?>
	        <div class="nav-next">
	            <div class="area-content ">
	            	<?php
	            	next_post_link( '%link',''); // link overlay
	                ?>
	                <div class="nav-content">
	                	<?php 
	                		next_post_link( '<div class="nav-post-link">%link</div>', _x( 'Next post', 'Next post link', 'snsbiamuc' ) );
						
							next_post_link( '<div class="nav-post-title">%link</div>');?>
							
							<div class="nav-meta">
								<span class="nav-author"><i class="fa fa-user"></i><?php printf( wp_kses(__( '<a class="author-link" href="%s" rel="author">%s</a>', 'snsbiamuc' ), array(
																		'a' => array(
																			'href' => array(),
																			'class' => array(),
																			'ref' => array()
																		),
																		) ), esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ),  get_the_author_meta('display_name') );?></span>
								<?php
			            		if ( ! post_password_required() && ( comments_open() || get_comments_number() ) ) {
									echo '<span class="nav-comments-link"><i class="fa fa-comment"></i>';
									/* translators: %s: post title */
									comments_popup_link( esc_html__( '0 comment','snsbiamuc' ),  esc_html__( '1 comment','snsbiamuc' ), '%' . esc_html__(' comments','snsbiamuc'));
									echo '</span>';
								}
								?>
							</div>
							
	                </div>
	            </div>
	        </div>
	        <?php endif; ?>
	</div>
	
	
	<?php
}

/*
 * snsbiamuc_featured_image_shop_page hook
 */
add_filter('snsbiamuc_featured_image_shop_page', 'snsbiamuc_featured_image_shop_page');
function snsbiamuc_featured_image_shop_page(){
	global $post;
	$page_id = '';
	if( is_shop() ){
		$page_id = wc_get_page_id('shop');
		// Check has post thumbnai
		if(has_post_thumbnail($page_id)): // return html featured image shop page
		?>
			<div class="sns-shop-page-thumbnail"><?php echo get_the_post_thumbnail($page_id, 'full')?></div>
		<?php
		endif;
	}
}

if( !function_exists('snsbiamuc_yith_woocompare') ){
	function snsbiamuc_yith_woocompare(){
		global $product;
		if( class_exists( 'YITH_Woocompare' ) ) {
                $action_add = 'yith-woocompare-add-product';
                $url_args = array(
                    'action' => $action_add,
                    'id' => $product->get_id()
                );
                ?>
                <a data-original-title="<?php echo esc_html( get_option('yith_woocompare_button_text') ); ?>" data-toggle="tooltip" href="<?php echo esc_url( wp_nonce_url( add_query_arg( $url_args ), $action_add ) ); ?>" class="compare btn btn-primary-outline" data-product_id="<?php echo esc_attr( $product->get_id() ); ?>">
                </a>
        <?php }
	}
}

if( !function_exists('snsbiamuc_yith_wcwl_add_to_wishlist') ){
	function snsbiamuc_yith_wcwl_add_to_wishlist(){
		if( class_exists( 'YITH_WCWL' ) ) {
			echo do_shortcode( '[yith_wcwl_add_to_wishlist]' );
		}
	}
}

function snsbiamuc_single_post_meta_content(){?>
	 <div class="meta-content">
        <span class="byline">
        <?php
        printf( wp_kses(__( '<i class="fa fa-user" aria-hidden="true"></i><a class="author-link" href="%s" rel="author">%s</a>', 'snsbiamuc' ), array(
                        'a' => array(
                            'href' => array(),
                            'class' => array(),
                            'ref' => array()
                        ),
                        'i' => array(
                            'class' => array(),
                            'aria-hidden' => array()
                        ),
                        ) ), esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ),  get_the_author_meta('display_name') ); ?>
        </span>
        <?php if(has_post_thumbnail()){ ?>
        <span class="post-view-count"><i class="fa fa-eye" aria-hidden="true"></i><?php echo snsbiamuc_get_post_views(get_the_ID());?></span>
        <?php
        if (  comments_open() || get_comments_number() ) {
            $icon_comment_alt = '<i class="fa fa-comments-o" aria-hidden="true"></i>';
            echo '<span class="post-comments-number">';
            /* translators: %s: post title */
            comments_popup_link( $icon_comment_alt . '0 ' . esc_html__('comment', 'snsbiamuc' ),  $icon_comment_alt . '1 ' . esc_html__('comment', 'snsbiamuc' ), $icon_comment_alt. '% ' . esc_html__('comments', 'snsbiamuc' ));
            echo '</span>';
        }
    	}
        ?>
    </div>
<?php
}