<?php
/**
 * Registering meta boxes
 *
 * All the definitions of meta boxes are listed below with comments.
 * Please read them CAREFULLY.
 *
 * You also should read the changelog to know what has been changed before updating.
 *
 * For more information, please visit:
 * @link http://metabox.io/docs/registering-meta-boxes/
 */
add_filter( 'rwmb_meta_boxes', 'snsbiamuc_register_meta_boxes' );
/**
 * Register meta boxes
 *
 * Remember to change "your_prefix" to actual prefix in your project
 *
 * @param array $meta_boxes List of meta boxes
 *
 * @return array
 */
function snsbiamuc_register_meta_boxes( $meta_boxes ){
	/**
	 * prefix of meta keys (optional)
	 * Use underscore (_) at the beginning to make keys hidden
	 * Alt.: You also can make prefix empty to disable it
	 */
	// Better has an underscore as last sign
	wp_enqueue_script('sns-imgselect', SNSBIAMUC_THEME_URI . '/framework/meta-box/sns-metabox.js', array('jquery'), '', true);
	$prefix = 'snsbiamuc_';
	global $wpdb, $snsbiamuc_opt;
	$revsliders =array();
	$revsliders[0] = 'Select a slider';
	if ( ! function_exists( 'is_plugin_active' ) ) {
        require_once ABSPATH . 'wp-admin/includes/plugin.php';
    }
	if (is_plugin_active('revslider/revslider.php')) {
		$query = $wpdb->prepare("
			SELECT * 
			FROM {$wpdb->prefix}revslider_sliders 
			ORDER BY %s"
			, "ASC");
	    $get_sliders = $wpdb->get_results($query);
	    if($get_sliders) {
		    foreach($get_sliders as $slider) {
			   $revsliders[$slider->alias] = $slider->title;
		   }
	    }
	}
	//
	$default_layout = 'm-r';
	if ( isset($snsbiamuc_opt['blog_layout']) ) $default_layout = $snsbiamuc_opt['blog_layout'];
	//
	$siderbars = array();
	foreach ($GLOBALS['wp_registered_sidebars'] as $sidebars) {
		$siderbars[ $sidebars['id']] = $sidebars['name'];
	}
	// Layout config
	$meta_boxes[] = array(
		// Meta box id, UNIQUE per meta box. Optional since 4.1.5
		'id'         => 'sns_layout',
		// Meta box title - Will appear at the drag and drop handle bar. Required.
		'title'      => esc_html__( 'Layout Config', 'snsbiamuc' ),
		// Post types, accept custom post types as well - DEFAULT is 'post'. Can be array (multiple post types) or string (1 post type). Optional.
		'post_types' => array( 'page' ),
		// Where the meta box appear: normal (default), advanced, side. Optional.
		'context'    => 'normal',
		// Order of meta box: high (default), low. Optional.
		'priority'   => 'high',
		// Auto save: true, false (default). Optional.
		// 'autosave'   => true,
		// List of meta fields

		'fields'     => array(
			
			array(
				'name'        => esc_html__( 'Config layout for this page', 'snsbiamuc' ),
				'id'          => "{$prefix}enablelayoutconfig",
				'type'    => 'radio',
				'options' => array(
					'1' => esc_html__( 'Yes', 'snsbiamuc' ),
					'2' => esc_html__( 'No', 'snsbiamuc' ),
				),
				'std'         => '2',
				'desc'		  => esc_html__( 'Sellect Yes if you want config layout for this page', 'snsbiamuc' ),
			),
			// Layout Type
			array(
				'name'        => esc_html__( 'Layout Type', 'snsbiamuc' ),
				'id'          => "{$prefix}layouttype",
				'type'        => 'layouttype',
				// Array of 'value' => 'Label' pairs for select box
				'options'     => array(
					'm' => esc_html__( 'Without Sidebar', 'snsbiamuc' ),
					'm-r' => esc_html__( 'Use Right Sidebar', 'snsbiamuc' ),
				),
				// Select multiple values, optional. Default is false.
				'multiple'    => false,
				'std'         => $default_layout,
				'placeholder' => esc_html__( '--- Select a layout type ---', 'snsbiamuc' ),
			),
			// Right Sidebar
			array(
				'name'  => esc_html__( 'Right Sidebar', 'snsbiamuc' ),
				'id'    => "{$prefix}rightsidebar",
				//'desc'  => esc_html__( 'Text description', 'snsbiamuc' ),
				'type'  => 'select',
				'options'	=> $siderbars,
				'multiple'	=> false,
				'std'		=> 'right-sidebar',
				'placeholder' => esc_html__( '--- Select a sidebar ---', 'snsbiamuc' ),
			),
		)
	);
	
	$menus = get_terms('nav_menu', array( 'hide_empty' => false ));
	$menu_options[''] = __('Default Menu...', 'snsbiamuc');
	foreach ( $menus as $menu ){
		$menu_options[$menu->term_id] = $menu->name;
	}
	
	// Page config
	$meta_boxes[] = array(
		// Meta box id, UNIQUE per meta box. Optional since 4.1.5
		'id'         => 'sns_pageconfig',
		// Meta box title - Will appear at the drag and drop handle bar. Required.
		'title'      => esc_html__( 'Page Config', 'snsbiamuc' ),
		// Post types, accept custom post types as well - DEFAULT is 'post'. Can be array (multiple post types) or string (1 post type). Optional.
		'post_types' => array( 'page' ),
		// Where the meta box appear: normal (default), advanced, side. Optional.
		'context'    => 'normal',
		// Order of meta box: high (default), low. Optional.
		'priority'   => 'high',
		// Auto save: true, false (default). Optional.
		// 'autosave'   => true,
		// List of meta fields

		'fields'     => array(
			array(
				'name'    => esc_html__( 'Main sidebar style', 'snsbiamuc' ),
				'id'      => "{$prefix}main_sb_style",
				'type'    => 'select',
				'options' => array(
					'' => esc_html__( 'Default', 'snsbiamuc' ),
					'1' => esc_html__( 'Alway show in lelft', 'snsbiamuc' ),
					'2' => esc_html__( 'Just show(in left) when you click to Sidebar icon', 'snsbiamuc' ),
				),
				'std'         => '',
			),
			array(
				'name'    => esc_html__( 'Show Top Header', 'snsbiamuc' ),
				'id'      => "{$prefix}show_top_header",
				'type'    => 'radio',
				'options' => array(
					'1' => esc_html__( 'Yes', 'snsbiamuc' ),
					'2' => esc_html__( 'No', 'snsbiamuc' ),
				),
				'std'         => '2',
			),
			array(
				'name'    => esc_html__( 'Header\'s Slideshow', 'snsbiamuc' ),
				'id'      => "{$prefix}revolutionslider",
				'type'    => 'select',
				'options' =>  $revsliders ,
				'std'         => '',
			),
			array(
				'name'    => esc_html__( 'Show Title', 'snsbiamuc' ),
				'id'      => "{$prefix}showtitle",
				'type'    => 'radio',
				'options' => array(
					'1' => esc_html__( 'Yes', 'snsbiamuc' ),
					'2' => esc_html__( 'No', 'snsbiamuc' ),
				),
				'std'         => '1',
			),
			array(
				'name'    => esc_html__( 'Show Breadcrumbs', 'snsbiamuc' ),
				'id'      => "{$prefix}showbreadcrump",
				'type'    => 'radio',
				'options' => array(
					'1' => esc_html__( 'Yes', 'snsbiamuc' ),
					'2' => esc_html__( 'No', 'snsbiamuc' ),
				),
				'std'         => '1',
				'desc' => esc_html__( 'Dont apply for Front page. Because breadcrumbs dont sense in Front page.', 'snsbiamuc' ),
			),
			array(
				'name'    => esc_html__( 'Config Theme Color for this page?', 'snsbiamuc' ),
				'id'      => "{$prefix}page_themecolor",
				'type'    => 'radio',
				'options' => array(
					'1' => esc_html__( 'Yes', 'snsbiamuc' ),
					'2' => esc_html__( 'No', 'snsbiamuc' ),
				),
				'std'         => '2',
			),
			array(
				'name' => esc_html__( 'Sellect Theme Color', 'snsbiamuc' ),
				'id'   => "{$prefix}theme_color",
				'type' => 'color',
				'desc' => esc_html__( 'It will priority than Theme Color in Theme Option panel', 'snsbiamuc' ),
			),
			array(
				'name'    => esc_html__( 'Hide Footer Area', 'snsbiamuc' ),
				'id'      => "{$prefix}hide_footer",
				'type'    => 'radio',
				'options' => array(
					'1' => esc_html__( 'Yes', 'snsbiamuc' ),
					'2' => esc_html__( 'No', 'snsbiamuc' ),
				),
				'std'         => '2',
			),
		)
	);

	// Page Comming soon config
	$meta_boxes[] = array(
		// Meta box id, UNIQUE per meta box. Optional since 4.1.5
		'id'         => 'sns_commingsoon',
		// Meta box title - Will appear at the drag and drop handle bar. Required.
		'title'      => esc_html__( 'Page Comming Soon Config', 'snsbiamuc' ),
		// Post types, accept custom post types as well - DEFAULT is 'post'. Can be array (multiple post types) or string (1 post type). Optional.
		'post_types' => array( 'page' ),
		// Where the meta box appear: normal (default), advanced, side. Optional.
		'context'    => 'normal',
		// Order of meta box: high (default), low. Optional.
		'priority'   => 'high',
		// Auto save: true, false (default). Optional.
		// 'autosave'   => true,
		// List of meta fields
		'fields'     => array(
			array(
				'name' => esc_html__( "Logo", 'snsbiamuc' ),
				'id'   => "{$prefix}cms_logo",
				'type' => 'image_advanced',
				'max_file_uploads' => 1,
			),
			array(
				'name' => esc_html__( "Background Image", 'snsbiamuc' ),
				'id'   => "{$prefix}cms_bg",
				'type' => 'image_advanced',
				'max_file_uploads' => 1,
			),
		)
	);

	// Post format - Gallery
	$meta_boxes[] = array(
	    	'id' => 'sns-post-gallery',
		    'title' =>  esc_html__('Gallery Settings','snsbiamuc'),
	    	'description' => '',
    		'pages'      => array( 'post' ), // Post type
	    	'context'    => 'normal',
		    'priority'   => 'high',
	    	'fields' => array(
			     array(
			        'name'		=> 'Gallery Images',
			        'desc'	    => 'Upload Images for post Gallery ( Limit is 15 Images ).',
			        'type'      => 'image_advanced',
			        'id'	    => "{$prefix}post_gallery",
	         		'max_file_uploads' => 15 
	        	)
			)
	);
	// Post format - Video
    $meta_boxes[] = array(
		'id' => 'sns-post-video',
		'title' => esc_html__('Featured Video','snsbiamuc'),
		'description' => '',
		'pages'      => array( 'post' ), // Post type
		'context'    => 'normal',
		'priority'   => 'high',
		'fields' => array( 
		    array(
				'id'    => "{$prefix}post_video",
				'name'  => esc_html__( 'Video', 'snsbiamuc' ),
				'type'  => 'oembed',
				// Allow to clone? Default is false
				'clone' => false,
				// Input size
				'size'  => 50,
			)
		)
	);
	// Post format - Audio
    $meta_boxes[] = array(
		'id' => 'sns-post-audio',
		'title' => esc_html__('Featured Audio','snsbiamuc'),
		'description' => '',
		'pages'      => array( 'post' ), // Post type
		'context'    => 'normal',
		'priority'   => 'high',
		'fields' => array( 
		    array(
				'id'    => "{$prefix}post_audio",
				'name'  => esc_html__( 'Audio', 'snsbiamuc' ),
				'type'  => 'oembed',
				// Allow to clone? Default is false
				'clone' => false,
				// Input size
				'size'  => 50,
			)
		)
	);
	// Post format - quote
    $meta_boxes[] = array(
		'id' => 'sns-post-quote',
		'title' => esc_html__('Featured Quote','snsbiamuc'),
		'description' => '',
		'pages'      => array( 'post' ), // Post type
		'context'    => 'normal',
		'priority'   => 'high',
		'fields' => array( 
		    array(
				'id'    => "{$prefix}post_quotecontent",
				'name'  => esc_html__( 'Quote Content', 'snsbiamuc' ),
				'type'  => 'textarea',
				// Allow to clone? Default is false
				'clone' => false,
			),
			array(
				'id'      => "{$prefix}post_quoteauthor",
				'name'    => esc_html__( 'Quote author', 'snsbiamuc' ),
				'type'    => 'text',
				'clone' => false,
			),
		)
	);
	// Post format - Link
    $meta_boxes[] = array(
		'id' => 'sns-post-link',
		'title' => esc_html__('Link Settings','snsbiamuc'),
		'description' => '',
		'pages'      => array( 'post' ), // Post type
		'context'    => 'normal',
		'priority'   => 'high',
		'fields' => array( 
		    array(
				'id'    => "{$prefix}post_linkurl",
				'name'  => esc_html__( 'Link URL', 'snsbiamuc' ),
				'type'  => 'text',
				// Allow to clone? Default is false
				'clone' => false,
			),
			array(
				'id'      => "{$prefix}post_linktitle",
				'name'    => esc_html__( 'Link Title', 'snsbiamuc' ),
				'type'    => 'text',
				'clone' => false,
			),
		)
	);
	// Brand config
	$meta_boxes[] = array(
		'id'         => 'sns_brandconfig',
		'title'      => esc_html__( 'Brand Config', 'snsbiamuc' ),
		'post_types' => array( 'brand' ),
		'context'    => 'normal',
		'priority'   => 'high',
		'fields'     => array(
			array(
				'name'    => esc_html__( 'Link for brand', 'snsbiamuc' ),
				'id'      => "{$prefix}brandlink",
				'type'    => 'text'
			),
		)
	);
	
	// Agency config
	$meta_boxes[] = array(
		'id'         => 'sns_agencyaddress',
		'title'      => esc_html__( 'Agency Info', 'snsbiamuc' ),
		'post_types' => array( 'agency' ),
		'context'    => 'normal',
		'priority'   => 'high',
		'fields'     => array(
			array(
				'name'    => esc_html__( 'Address:', 'snsbiamuc' ),
				'id'      => "{$prefix}agencyaddress",
				'type'    => 'text'
			),
			
			array(
			'name'    => esc_html__( 'Phone:', 'snsbiamuc' ),
			'id'      => "{$prefix}agencyphone",
			'type'    => 'text'
			),
			
			array(
			'name'    => esc_html__( 'Mail:', 'snsbiamuc' ),
			'id'      => "{$prefix}agencymail",
			'type'    => 'text'
			),
			
			array(
				'name'    => esc_html__( 'Link for Agency on thumbnail(Featured image)', 'snsbiamuc' ),
				'id'      => "{$prefix}agencylink",
				'type'    => 'text'
			),
		)
	);
	
	// Infobox config
	$meta_boxes[] = array(
		'id'         => 'sns_infoboxconfig',
		'title'      => esc_html__( 'Infobox Config', 'snsbiamuc' ),
		'post_types' => array( 'infobox' ),
		'context'    => 'normal',
		'priority'   => 'high',
		'fields'     => array(
			array(
				'name'    => esc_html__( 'Icon font', 'snsbiamuc' ),
				'id'      => "{$prefix}infobox_icon",
				'type'    => 'text'
				),
			array(
				'name'    => esc_html__( 'Description', 'snsbiamuc' ),
				'id'      => "{$prefix}infobox_desc",
				'type'    => 'text'
				),
			array(
				'name'    => esc_html__( 'Link for infobox', 'snsbiamuc' ),
				'id'      => "{$prefix}infobox_link",
				'type'    => 'text'
				),
		)
	);
	
	// Testimonial subtitle
	$meta_boxes[] = array(
		'id'         => 'sns_testisub',
		'title'      => esc_html__( 'Job', 'snsbiamuc' ),
		'post_types' => array( 'testimonial' ),
		'context'    => 'normal',
		'priority'   => 'high',
		'fields'     => array(
			array(
				'name'    => esc_html__( 'Job', 'snsbiamuc' ),
				'id'      => "{$prefix}testisub",
				'type'    => 'text',
				'desc'	  => esc_html__('Ex: display your job.', 'snsbiamuc')
			),
		),
	);

	// Product page config
	$meta_boxes[] = array(
	    	'id' => 'sns-product-config',
		    'title' =>  esc_html__('Product Config','snsbiamuc'),
	    	'description' => '',
    		'pages'      => array( 'product' ), // type product
	    	'context'    => 'normal',
		    'priority'   => 'high',
	    	'fields' => array(
	    		array(
					'name'    => esc_html__( 'Single Product Layout', 'snsbiamuc' ),
					'id'       => "{$prefix}woo_single_layout",
					'type'     => 'select',
					'std'  => 'def',
					'options'  => array(
						'def'  => esc_html__( 'Default', 'snsbiamuc' ),
						'layout1'   	=> esc_html__( 'Layout 1', 'snsbiamuc' ),
	                    'layout2'   	=> esc_html__( 'Layout 2', 'snsbiamuc' ), 
					),
					'desc'		=> esc_html__('Single Product layout. Select "Default" to use in Theme Options.', 'snsbiamuc'),
				),
			     array(
					'name'    => esc_html__( 'Product Sidebar', 'snsbiamuc' ),
					'id'       => "{$prefix}product_sidebar",
					'type'     => 'select',
					'std'  => 'def',
					'options'  => array(
						'def'  => esc_html__( 'Default', 'snsbiamuc' ),
						'0'  => esc_html__( 'No', 'snsbiamuc' ),
						'1'  => esc_html__( 'Yes', 'snsbiamuc' ),
					),
					'desc'		=> esc_html__('Product page with Sidebar. Select "Default" to use in Theme Options.', 'snsbiamuc'),
				),
			    array(
					'name'    => esc_html__( 'Zoom Type for Cloud Zoom', 'snsbiamuc' ),
					'id'       => "{$prefix}woo_zoomtype",
					'type'     => 'select',
					'std'  => '',
					'options'  => array(
						''  => esc_html__( 'Default', 'snsbiamuc' ),
						'window'  => esc_html__( 'window', 'snsbiamuc' ),
						'lens'  => esc_html__( 'lens', 'snsbiamuc' ),
						'inner'  => esc_html__( 'Inner', 'snsbiamuc' ),
					),
					'desc'		=> '',
				),
			     array(
					'id'    => "{$prefix}product_video",
					'name'  => esc_html__( 'Product Video', 'snsbiamuc' ),
					'type'  => 'oembed',
					// Allow to clone? Default is false
					'clone' => false,
					'desc'		  => esc_html__( 'Enter your video url(youtube, video)', 'snsbiamuc' ),
					// Input size
					'size'  => 50,
				)
			)
	);
	
	return $meta_boxes;
}


if ( class_exists( 'RWMB_Field' ) ) {
	class RWMB_Layouttype_Field extends RWMB_Select_Field {
		static function admin_enqueue_scripts(){
			wp_enqueue_style( 'sns-imgselect', SNSBIAMUC_THEME_URI . '/framework/meta-box/img-select.css' );
		}
	}
}
