<?php
if ( ! class_exists( 'SnsBiaMuc_Options' ) ) {
class SnsBiaMuc_Options {
	public $args = array();
	public $sections = array();
	public $theme;
	public $ReduxFramework;

	public function __construct() {
		if ( ! class_exists( 'ReduxFramework' ) ) {
		 return;
		}
		if ( true == Redux_Helpers::isTheme( SNSBIAMUC_THEME_DIR . '/framework/sns-options.php' ) ) {
			$this->initSettings();
		} else {
			add_action( 'plugins_loaded', array( $this, 'initSettings' ), 10 );
		}
	}

	public function initSettings(){
	    // Set the default arguments
	    $this->setArguments();
	    // Set a few help tabs so you can see how it's done
	    $this->setHelpTabs();
	    // Create the sections and fields
	    $this->setSections();
	    if ( ! isset( $this->args['opt_name'] ) ) {
	        return;
	    }
	    $this->ReduxFramework = new ReduxFramework( $this->sections, $this->args );
	}

	public function setArguments() {
	    $theme = wp_get_theme();
	    $this->args = array(
            'opt_name'  			=> 'snsbiamuc_themeoptions',
            'display_version' 		=> $theme->get( 'Version' ),
            'display_name' 			=> $theme->get( 'Name' ),
            'menu_type'          	=> 'menu',
	        'allow_sub_menu'     	=> true,
	        'menu_title'         	=> esc_html__( 'SNS BIAMUC', 'snsbiamuc' ),
	        'page_title'         	=> esc_html__( 'SNS BIAMUC', 'snsbiamuc' ),
	        'customizer' 			=> true,
	        'page_priority'      	=> 50,
	        'menu_icon' 			=> '',
	        'hints'              	=> array(
	            'icon'          => 'icon-question-sign',
	            'icon_position' => 'right',
	            'icon_color'    => 'lightgray',
	            'icon_size'     => 'normal',
	            'tip_style'     => array(
	                'color'   	=> 'light',
	                'shadow'  	=> true,
	                'rounded' 	=> false,
	                'style'   	=> '',
	            ),
	            'tip_position'  => array(
	                'my' => 'top left',
	                'at' => 'bottom right',
	            ),
	            'tip_effect'    => array(
	                'show' => array(
	                    'effect'   => 'slide',
	                    'duration' => '500',
	                    'event'    => 'mouseover',
	                ),
	                'hide' => array(
	                    'effect'   => 'slide',
	                    'duration' => '500',
	                    'event'    => 'click mouseleave',
	                ),
	            ),
	        ),
	        'dev_mode' 				=> false,
	        //'forced_dev_mode_off'	=> false,
	        'show_options_object'   => false
	    );
	}

	public function setHelpTabs() {
	    $this->args['help_tabs'][] = array(
	        'id'      => 'redux-help-tab-1',
	        'title'   => esc_html__( 'Theme Information 1', 'snsbiamuc' ),
	        'content' => wp_kses(__( '<p>This is the tab content, HTML is allowed.</p>', 'snsbiamuc' ), array(
							'p' => array()
						 ))
	    );
	    $this->args['help_tabs'][] = array(
	        'id'      => 'redux-help-tab-2',
	        'title'   => esc_html__( 'Theme Information 2', 'snsbiamuc' ),
	        'content' => wp_kses(__( '<p>This is the tab content, HTML is allowed.</p>', 'snsbiamuc' ), array(
							'p' => array()
						 ))
	    );
	    $this->args['help_sidebar'] = wp_kses(__( '<p>This is the sidebar content, HTML is allowed.</p>', 'snsbiamuc' ), array(
										'p' => array()
									  ));
	}
	public function setSections() {
		$this->sections[] = $this->importSampleData();
	    $this->sections[] = $this->getGeneralCfg();
	    $this->sections[] = $this->getHeaderCfg();
	    $this->sections[] = $this->getFooterCfg();
	    $this->sections[] = $this->getBlogCfg();
	    $this->sections[] = $this->getPageNotFoundCfg();
	    $this->sections[] = $this->getWooCfg();
	    $this->sections[] = $this->getSocialCfg();
	    $this->sections[] = $this->getAdvanceCfg();
	}
	public function getPatterns(){
		$patterns = array();
		$path = SNSBIAMUC_THEME_DIR . '/assets/img/patterns';
		$regex = '/(\.gif)|(.jpg)|(.png)|(.bmp)$/i';
		if( !is_dir($path) ) return;
		
		$dk =  opendir ( $path );
		$files = array();
		while ( false !== ($filename = readdir ( $dk )) ) {
			if (preg_match ( $regex, $filename )) {
				$files[] = $filename;
			}
		}
		foreach( $files as $p ) $patterns[] = $p;
		return $patterns;
	}
	public function importSampleData(){
		$desc = ''; $i_message = '';
		if ( ! function_exists( 'is_plugin_active' ) ) {
			require_once ABSPATH . 'wp-admin/includes/plugin.php';
        }
        if( !is_plugin_active('wordpress-importer/wordpress-importer.php') ){
        	$i_message .= '<li><i class="fa fa-angle-double-right"></i> Need install and active plugin <a href="'.esc_url("https://wordpress.org/plugins/wordpress-importer/").'" target="_blank">WordPress Importer</a></li>';
        }
        if( !defined('WP_LOAD_IMPORTERS') ){
        	$i_message .= "<li><i class='fa fa-angle-double-right'></i> Need add <code>define('WP_LOAD_IMPORTERS', true);</code> to file wp-config.php</li>";
        }
        if ( $i_message !='' ){
        	$subtitle = '
				<p><label><i class="fa fa-exclamation-circle"></i>  Please follow the check list bellow to enable import function:</label></p>
				<ul class="i_message">'.$i_message.'</ul>
			';
        }else{
        	$subtitle = '<input type=\'button\' class=\'button\' name=\'btn_sampledata\' id=\'btn_sampledata\' value=\'Import\' />';
        	$subtitle .= '
		    	<div class=\'sns-importprocess\'>
		    		<div  class=\'sns-importprocess-width\'></div>
		    	</div>
		    	<span id=\'sns-importmsg\'><span class=\'status\'></span></span>
	    		<div id="sns-import-tablecontent">
					<label>List contents will import:</label>
					<ul>
					  <li class="theme-cfg"><i class="fa fa-hand-pointer-o"></i>Theme config</li>
					  <li class="revslider-cfg"><i class="fa fa-hand-pointer-o"></i>Revolution Slider config</li>
					  <li class="all-content"><i class="fa fa-hand-pointer-o"></i>All contents</li>
					  <li class="widget-cfg"><i class="fa fa-hand-pointer-o"></i>Widget config</li>
					</ul>
				</div>
	    	';
        }
		return  array(
		    'icon' => 'el-icon-briefcase',
		    'title' => esc_html__('Demo content', 'snsbiamuc'),
		    'subsection' => true,
		    'fields' => array(
		        array(
		        	'title' => '',
		            'subtitle' => $subtitle,
		            'desc'	=> $desc,
		            'id' => 'theme_data',
		            'icon' => true,
		            'type' => 'image_select',
		            'default' => 'sns_logo',
		            'options' => array(
		                'sns_logo' => get_template_directory_uri().'/assets/img/logo.png',
		            ),
		        )
		    )
		);
	}
	public function getGeneralCfg() {
		$patterns = $this->getPatterns();
		$pattern_opt = array();
		foreach($patterns as $pattern)
			$pattern_opt[$pattern] = array('img' => SNSBIAMUC_THEME_URI . '/assets/img/patterns/' . $pattern, 'alt' => $pattern);
		
	    return array(
	        'title'		=> esc_html__( 'General', 'snsbiamuc' ),
	        'icon'		=> 'el-icon-cog',
	        'fields'	=> array(
	            array(
	                'id'       => 'theme_color',
	                'type'     => 'color',
	                'output'   => array( '.site-title' ),
	                'title'    => esc_html__( 'Theme Color', 'snsbiamuc' ),
	                'default'  => '#333333',
	        		'transparent'	=> false
	            ),
	            array(
	                'id'          => 'body_font',
	                'type'        => 'typography',
	                'title'       => esc_html__( 'Body font', 'snsbiamuc' ),
	                'line-height'   => false,
	                'text-align'   => false,
	                'color'         => true,
	                'all_styles'  => true,
	                'units'       => 'px',
	                // 'subsets'       => true,
	                'default'     => array(
	                    'font-size'   => '13px',
	                    'font-family' => 'Lato',
	                    'font-weight' => '400',
	                    'color'		  => '#888888'
	                ),
	            ),
	            array(
	                'id'          => 'secondary_font',
	                'type'        => 'typography',
	                'title'       => esc_html__( 'Secondary font', 'snsbiamuc' ),
	                'line-height'   => false,
	                'text-align'   => false,
	                'color'         => false,
	                'all_styles'  => true,
	                'units'       => 'px',
                	'font-size'     => false,
	                // 'subsets'       => true,
	                'default'     => array(
	                    'font-family' => 'Lato',
	                    'font-weight' => '400',
	                ),
	            ),
	            array(
	                'id'       => 'secondary_font_target',
	                'type'     => 'textarea',
	                'title'    => esc_html__( 'Secondary font target', 'snsbiamuc' ),
	                'default'  => 'h1, h2, h3, h4, h5, h6,.font-2,#sns_mainmenu > ul > li.menu-item > a',
	                'validate' => 'no_html'
	            ),
	            array( 
		        	'title' => esc_html__( 'Main sidebar style', 'snsbiamuc'),
					'id' => 'main_sb_style',
					'default' => '1',
					'type' => 'select',
					'multiselect' => false ,
					'options' => array(
						'1' 		=> esc_html__( 'Alway show in lelft', 'snsbiamuc'),
						'2' 		=> esc_html__( 'Just show(in left) when you click to Sidebar icon', 'snsbiamuc'),
					)
				),
	        )
	    );
	}
	public function getHeaderCfg() {
		global $wpdb;
		$revsliders =array();
		$revsliders[0] = esc_html__('Select a slider', 'snsbiamuc');
		if (is_plugin_active('revslider/revslider.php')) {
			$query = $wpdb->prepare("
				SELECT *
				FROM {$wpdb->prefix}revslider_sliders
				ORDER BY %s"
				, "ASC");
					$get_sliders = $wpdb->get_results($query);
					if($get_sliders) {
						foreach($get_sliders as $slider) {
							$revsliders[$slider->alias] = $slider->title;
						}
					}
		}
	    return array(
	        'title'		=> esc_html__( 'Header', 'snsbiamuc' ),
	        'icon'		=> 'el el-brush',
	        'fields'	=> array(
	        	
			    array(
			        'id'		=> 'header_logo',
			        'type'		=> 'media',
			        'default'	=> '',
			        'title'		=> esc_html__( 'Logo', 'snsbiamuc' ),
                	'subtitle' => esc_html__( 'If this is not selected, This theme will be display logo with "theme/snsbiamuc/img/logo.png"', 'snsbiamuc' ),
			        'desc'		=> esc_html__( 'Image that you want to use as logo', 'snsbiamuc' ),
			    ),
	             array(
	                'id'       => 'show_settings_switcher',
	                'type'     => 'switch',
	                'title'    => 'Show Setting switcher',
	                'subtitle' => '',
	                'default'  => false,
	                'on'       => 'Yes',
                    'off'      => 'No',
	            ),
	            array(
	                'id'       => 'show_language_currency_switcher',
	                'type'     => 'switch',
	                'title'    => 'Show Language - Currency switcher',
	                'subtitle' => '',
	                'default'  => false,
	                'on'       => 'Yes',
                    'off'      => 'No',
                    'required' => array( 'show_settings_switcher', '=', true ),
	            ),
	            array(
	                'id'       => 'show_top_header',
	                'type'     => 'switch',
	                'title'    => esc_html__( 'Show Top Header', 'snsbiamuc' ),
	                'subtitle' => esc_html__( 'Apply for Home Page or the special page setting.', 'snsbiamuc' ),
	                'desc'		=> esc_html__( 'Include trending product and contact number.', 'snsbiamuc' ),
	                'default'  => false,
	                'on'       => 'Yes',
                    'off'      => 'No',
	            ),
	             array(
	        		'id'       => 'post_slider_number',
	        		'type'     => 'text',
	        		'title'    => esc_html__( 'Number of latest posts to get', 'snsbiamuc' ),
	        		'default'  => '10',
	        		'required' => array( 'show_top_header', '=', true ),
	        	),
	             array(
	        		'id'       => 'contact_number',
	        		'type'     => 'text',
	        		'title'    => esc_html__( 'Contact number', 'snsbiamuc' ),
	        		'default'  => '',
	        		'required' => array( 'show_top_header', '=', true ),
	        	),
	        )
	    );
	}
	public function  getFooterCfg(){
		return array(
	        'title'		=> esc_html__( 'Footer', 'snsbiamuc' ),
	        'icon'		=> 'el el-link',
	        'fields'	=> array(
	        	array(
			        'id'		=> 'payment_img',
			        'type'		=> 'media',
			        'title'		=> esc_html__( "Payment method's image", 'snsbiamuc' ),
			    	'default'	=> array(
			    					'url' => get_template_directory_uri() . '/assets/img/default/payment.png',
			    	),
			    ),
			    array(
			        'id'		=> 'copyright',
			        'type'		=> 'textarea',
			        'title'		=> esc_html__( "Copyright", 'snsbiamuc' ),
			        'default' => '© 2017 <a href="http://snstheme.com" title="SNSTheme">SNSTheme</a>. All Rights Reserved',
			    ),
	        )
	    );
	}
	public function getBlogCfg() {
		$siderbars = array(
		    'widget-area' => esc_html__( 'Main Area', 'snsbiamuc' ),
		    'right-sidebar' => esc_html__( 'Right Sidebar', 'snsbiamuc' ),
			'woo-sidebar' => esc_html__( 'Woo Sidebar', 'snsbiamuc' ),
		);
		//if( is_admin() ) wp_enqueue_style('sns-admin-css', SNSBIAMUC_THEME_URI . '/assets/css/admin-theme-option.css');
	    return array(
	        'title'		=> esc_html__( 'Blog', 'snsbiamuc' ),
	        'icon'		=> 'el el-file-edit',
	        'fields'	=> array(
				array(
				    'id'       => 'layouttype',
				    'type'     => 'image_select',
				    'title'    => esc_html__('Default Blog Layout', 'snsbiamuc'), 
				    'options'  => array(
				        'm'      => array(
				            'alt'   => esc_html__( 'Without Sidebar', 'snsbiamuc' ), 
				            'img'   => SNSBIAMUC_THEME_URI.'/assets/img/admin/m.jpg'
				        ),
				        'm-r'      => array(
				            'alt'  => esc_html__( 'Use Right Sidebar', 'snsbiamuc' ), 
				            'img'  => SNSBIAMUC_THEME_URI.'/assets/img/admin/m-r.jpg'
				        ),
				    ),
				    'default' => 'm-r'
				),
				// Right Sidebar
				array(
					'title'  => esc_html__( 'Right Sidebar', 'snsbiamuc' ),
					'id'    => "rightsidebar",
					//'desc'  => esc_html__( 'Text description', 'snsbiamuc' ),
					'type'  => 'select',
					'options'	=> $siderbars,
					'multiselect'	=> false,
					'required' => array( 'layouttype', '=', array( 'm-r', 'l-m-r' ) )
				),
				array( 
		        	'title' => esc_html__( 'Blog Style', 'snsbiamuc'),
					'id' => 'blog_type',
					'default' => '',
					'type' => 'select',
					'multiselect' => false ,
					'options' => array(
						'' 				=> esc_html__( 'Blog Layout 1', 'snsbiamuc'),
						'layout2' 		=> esc_html__( 'Blog Layout 2', 'snsbiamuc'),
					)
				),
				array(
			        'id'		=> 'breadcrumbs_img',
			        'type'		=> 'media',
			        'title'		=> esc_html__( "Breadcrumb's background image", 'snsbiamuc' ),
			    	'default'	=> array(
			    					'url' => get_template_directory_uri() . '/assets/img/default/breadcrumbs.jpg',
			    	),
			    ),
				array(
				    'id'   =>'divider_blog',
				    'type' => 'divide'
				),
				array(
	                'id'       => 'show_date',
	                'type'     => 'switch',
	                'title'    => esc_html__( 'Show Date for Blog Entries Page', 'snsbiamuc' ),
	                'default'  => true,
	                'on'       => 'Yes',
	                'off'      => 'No',
	            ),
	            array(
	                'id'       => 'show_categories',
	                'type'     => 'switch',
	                'title'    => esc_html__( 'Show Categories for Blog Entries Page', 'snsbiamuc' ),
	                'default'  => true,
	                'on'       => 'Yes',
	                'off'      => 'No',
	            ),
	        	
	        	array(
	        		'id'       => 'show_tags',
	        		'type'     => 'switch',
	        		'title'    => esc_html__( 'Show Tags for Blog Entries Page', 'snsbiamuc' ),
	        		'default'  => true,
	        		'on'       => 'Yes',
	        		'off'      => 'No',
	        	),
	        	array(
	        		'id'       => 'show_comment_count',
	        		'type'     => 'switch',
	        		'title'    => esc_html__( 'Show Comment Count', 'snsbiamuc' ),
	        		'default'  => true,
	        		'on'       => 'Yes',
	        		'off'      => 'No',
	        	),
	        	
	        	array(
	        		'id'       => 'excerpt_length',
	        		'type'     => 'text',
	        		'title'    => esc_html__( 'Blog Excerpt Length', 'snsbiamuc' ),
	        		'default'  => '35',
	        	),
	        	array(
	        		'id'       => 'show_readmore',
	        		'type'     => 'switch',
	        		'title'    => esc_html__( 'Enable Read More Button', 'snsbiamuc' ),
	        		'default'  => false,
	        		'on'       => 'Yes',
	        		'off'      => 'No',
	        	),
	        	
	            array(
				    'id'   =>'divider_post',
				    //'desc' => esc_html__('Options for blog page', 'snsbiamuc'),
				    'type' => 'divide'
				),
	            array(
	                'id'       => 'show_postauthor',
	                'type'     => 'switch',
	                'title'    => esc_html__( 'Enable Author Info on Post Detail', 'snsbiamuc' ),
	                'default'  => false,
	                'on'       => 'Yes',
	                'off'      => 'No',
	            ),
	            array(
	                'id'       => 'enalble_related',
	                'type'     => 'switch',
	                'title'    => esc_html__( 'Enable Related Posts on Post Detail', 'snsbiamuc' ),
	                'default'  => true,
	                'on'       => 'Yes',
	                'off'      => 'No',
	            ),
	        	array(
	        		'id' 		=> 'related_posts_by',
	        		'title' 	=> esc_html__( 'Related Post By', 'snsbiamuc'),
	        		'desc'		=> esc_html__('Get related post by Categories or Tags', 'snsbiamuc'),
	        		'default' 	=> 'cat',
	        		'type' 		=> 'select',
	        		'multiselect' => false ,
	        		'options'	=> array(
	        			'cat' 	=> 'Categories',
	        			'tag' 	=>  'Tags',
	        		),
	        		'required' => array( 'enalble_related', '=', true )
	        	),
	            array(
	                'id'       => 'related_num',
	                'type'     => 'text',
	                'title'    => esc_html__( 'Related Posts Number', 'snsbiamuc' ),
	                'default'  => '5',
	                'required' => array( 'enalble_related', '=', true )
	            ),
	            array(
	                'id'       => 'show_postsharebox',
	                'type'     => 'switch',
	                'title'    => esc_html__( 'Enable Share Box on Post Detail', 'snsbiamuc' ),
	                'default'  => true,
	                'on'       => 'Yes',
	                'off'      => 'No',
	            ),
	            array(
				    'id'       => 'show_facebook_sharebox',
				    'type'     => 'checkbox',
				    'title'    => esc_html__('Show Facebook in Sharing Box', 'snsbiamuc'),
				    'required' => array( 'show_postsharebox', '=', true ),
				    'default'  => '1'// 1 = on | 0 = off
				),
	            array(
				    'id'       => 'show_twitter_sharebox',
				    'type'     => 'checkbox',
				    'title'    => esc_html__('Show Twitter in Sharing Box', 'snsbiamuc'), 
				    'required' => array( 'show_postsharebox', '=', true ),
				    'default'  => '1'// 1 = on | 0 = off
				),
				array(
				    'id'       => 'show_gplus_sharebox',
				    'type'     => 'checkbox',
				    'title'    => esc_html__('Show G + in Sharing Box', 'snsbiamuc'),
				    'required' => array( 'show_postsharebox', '=', true ), 
				    'default'  => '1'// 1 = on | 0 = off
				),
				array(
				    'id'       => 'show_linkedin_sharebox',
				    'type'     => 'checkbox',
				    'title'    => esc_html__('Show Linkedin in Sharing Box', 'snsbiamuc'), 
				    'required' => array( 'show_postsharebox', '=', true ),
				    'default'  => '1'// 1 = on | 0 = off
				),
				array(
				    'id'       => 'show_pinterest_sharebox',
				    'type'     => 'checkbox',
				    'title'    => esc_html__('Show Pinterest in Sharing Box', 'snsbiamuc'), 
				    'required' => array( 'show_postsharebox', '=', true ),
				    'default'  => '1'// 1 = on | 0 = off
				),
				array(
				    'id'       => 'show_tumblr_sharebox',
				    'type'     => 'checkbox',
				    'title'    => esc_html__('Show Tumblr in Sharing Box', 'snsbiamuc'), 
				    'required' => array( 'show_postsharebox', '=', true ),
				    'default'  => '1'// 1 = on | 0 = off
				),
				array(
				    'id'       => 'show_email_sharebox',
				    'type'     => 'checkbox',
				    'title'    => esc_html__('Show Send Email in Sharing Box', 'snsbiamuc'), 
				    'required' => array( 'show_postsharebox', '=', true ),
				    'default'  => '1'// 1 = on | 0 = off
				),
	        	array(
	        		'id' 		=> 'pagination',
	        		'title' 	=> esc_html__( 'Page Navigation', 'snsbiamuc'),
	        		'desc'		=> esc_html__('Choose Type of navigation for blog and any listing page.', 'snsbiamuc'),
	        		'default' 	=> 'def',
	        		'type' 		=> 'select',
	        		'multiselect' => false ,
	        		'options'	=> array(
	        			'def' 	=> esc_html__('Default PageNavi', 'snsbiamuc'),
	        			'ajax' 	=>  esc_html__('Ajax', 'snsbiamuc'),
	        		),
	        	),

	            
	        )
	    );
	}
	public function getPageNotFoundCfg(){
		return array(
			'title'		=> esc_html__( 'Page Not Found', 'snsbiamuc' ),
			'icon'		=> 'el el-warning-sign',
			'fields'	=> array(
				array(
	                'id'       => 'notfound_title',
	                'type'     => 'text',
	                'title'    => esc_html__( 'Title', 'snsbiamuc' ),
	                'default'  => esc_html__('PAGE NOT FOUND', 'snsbiamuc'),
	            ),
				array(
					'id'       => 'notfound_content',
					'type'     => 'textarea',
					'title'    => esc_html__( 'Content', 'snsbiamuc' ),
					'default'  => esc_html__('Sory but the page you are looking for does not exit, have been removed or name changed. Go back Home page or enter the key words to search, please!', 'snsbiamuc'),
				),
			  )
			);
	}
	public function getWooCfg() {
		return array(
	        'title'		=> esc_html__( 'WooCommerce', 'snsbiamuc' ),
	        'icon'		=> 'el el-shopping-cart',
	        'fields'	=> array(
	        	array(
	                'id'       => 'woo_uselazyload',
	                'type'     => 'switch',
	                'title'    => esc_html__( 'Use lazyload for Product Image', 'snsbiamuc' ),
	                'default'  => true,
	                'on'       => 'Yes',
	                'off'      => 'No',
	            ),
	            array(
	                'id'		=> 'woo_list_modeview',
	                'type'		=> 'select',
	                'title'		=> esc_html__( 'Default mode view for listing page', 'snsbiamuc' ),
	                'options'  => array(
	                    'grid' => 'Grid',
	                    'list' => 'List',
	                ),
	                'default'  => 'grid'
			    ),
			    array(
	                'id'       => 'woo_grid_spacing',
	                'type'     => 'select',
	                'title'    => esc_html__( 'Item Grid Spacing', 'snsbiamuc' ),
	                'desc'	   => esc_html__( 'Choose the spacing of the products in grid view', 'snsbiamuc' ),
	                'default'  => '',
	                'options'  => array(
		                    ''    	=> '0px',
		                    '10'  	=> '10px',
		                    '20'  	=> '20px',
		                    '30'  	=> '30px',
	                )
	            ),

	            array(
	                'id'       => 'woo_grid_col',
	                'type'     => 'select',
	                'title'    => esc_html__( 'Grid columns', 'snsbiamuc' ),
	                'subtitle'  => esc_html__( 'We are using grid bootstap - 12 cols layout', 'snsbiamuc' ),
	                'default'  => '4',
	                'options'  => array(
	                    '1' => '1',
	                    '2' => '2',
	                    '3' => '3',
	                    '4' => '4',
	                    '6' => '6',
	                ),
	            ),
	            array(
	                'id'       => 'woo_number_perpage',
	                'type'     => 'text',
	                'title'    => esc_html__( 'Number products per listing page', 'snsbiamuc' ),
	                'default'  => '12',
	            ),
	        	
	            array(
				    'id'   =>'divider_blog',
				    'type' => 'divide'
				),
				array(
	                'id'       => 'woo_single_layout',
	                'type'     => 'select',
	                'title'    => esc_html__( 'Single Product Layout', 'snsbiamuc' ),
	                'options'  => array(
	                    'layout1'   	=> esc_html__( 'Layout 1', 'snsbiamuc' ),
	                    'layout2'   	=> esc_html__( 'Layout 2', 'snsbiamuc' ),               		                   
	                ),
	                'default'  => 'layout1',
	            ),
				array(
	                'id'       => 'single_product_sidebar',
	                'type'     => 'switch',
	                'title'    => esc_html__( 'Show Single Product Sidebar', 'snsbiamuc' ),
	                'default'  => false,
	                'on'       => 'Yes',
	                'off'      => 'No',
	            ),
	            array(
	                'id'       => 'woo_usecloudzoom',
	                'type'     => 'switch',
	                'title'    => esc_html__( 'Enable Cloud Zoom for Product Image', 'snsbiamuc' ),
	                'default'  => true,
	                'on'       => 'Yes',
	                'off'      => 'No',
	            ),
	            array(
	                'id'       => 'woo_zoomtype',
	                'type'     => 'select',  
	                'title'    => esc_html__( 'Zoom Type for Cloud Zoom', 'snsbiamuc' ),
	                'options'  => array(
	                    'window'   	=> 'Window',
	                    'lens'   	=> 'Lens',
	                    'inner'   	=> 'Inner',                    		                   
	                ),
	                'default'  => 'window',       
	                'required' => array( 'woo_usecloudzoom', '=', true ) 	
	            ),
	            array(
	                'id'       => 'woo_sharebox',
	                'type'     => 'switch',
	                'title'    => esc_html__( 'Enable Share box', 'snsbiamuc' ),
	                'default'  => true,
	                'on'       => 'Yes',
	                'off'      => 'No',
	            ),
	            array(
	                'id'       => 'woo_related',
	                'type'     => 'switch',
	                'title'    => esc_html__( 'Enable Related Products', 'snsbiamuc' ),
	                'default'  => true,
	                'on'       => 'Yes',
	                'off'      => 'No',
	            ),
	            array(
	            	'id'       => 'woo_related_num',
                 	'type'     => 'text',
                 	'title'    => esc_html__( 'Number Related Products to display', 'snsbiamuc' ),
                 	'required' => array( 'woo_related', '=', '1' ),
                 	'default'  => '6',
                )
	        )
	    );
	}
	public function getSocialCfg() {
	    return array(
	        'title'		=> esc_html__( 'Social Accounts', 'snsbiamuc' ),
	        'icon'		=> 'el el-address-book',
	        'fields'	=> array(
	            array(
	        		'id'		=> 'facebook',
	        		'type'		=> 'text',
	        		'default'	=> '',
	        		'title'		=> esc_html__( 'Facebook', 'snsbiamuc' ),
	        	),
	        	array(
	        		'id'		=> 'twitter',
	        		'type'		=> 'text',
	        		'default'	=> '',
	        		'title'		=> esc_html__( 'Twitter', 'snsbiamuc' ),
	        	),
	        	array(
	        		'id'		=> 'flickr',
	        		'type'		=> 'text',
	        		'default'	=> '',
	        		'title'		=> esc_html__( 'Flickr', 'snsbiamuc' ),
	        	),
	        	array(
	        		'id'		=> 'google-plus',
	        		'type'		=> 'text',
	        		'default'	=> '',
	        		'title'		=> esc_html__( 'Google Plus', 'snsbiamuc' ),
	        	),
	        	array(
	        		'id'		=> 'pinterest',
	        		'type'		=> 'text',
	        		'default'	=> '',
	        		'title'		=> esc_html__( 'Pinterest', 'snsbiamuc' ),
	        	),
	        	array(
	        		'id'		=> 'instagram',
	        		'type'		=> 'text',
	        		'default'	=> '',
	        		'title'		=> esc_html__( 'Instagram', 'snsbiamuc' ),
	        	),
	        	array(
	        		'id'		=> 'youtube-play',
	        		'type'		=> 'text',
	        		'default'	=> '',
	        		'title'		=> esc_html__( 'Youtute', 'snsbiamuc' ),
	        	),
	        )
	    );
	}

	public function getAdvanceCfg() {
	    return array(
	        'title'		=> esc_html__( 'Advance', 'snsbiamuc' ),
	        'icon'		=> 'el el-wrench',
	        'fields'	=> array(
	        	array(
	                'id'       => 'use_pathloader',
	                'type'     => 'switch',
	                'title'    => esc_html__( 'Use Preloading Effect', 'snsbiamuc' ),
	                'default'  => false,
	                'on'       => 'Yes',
	                'off'      => 'No',
	            ),
	            array(
	                'id'       => 'advance_tooltip',
	                'type'     => 'switch',
	                'title'    => esc_html__( 'Enable Tooltip', 'snsbiamuc' ),
	                'default'  => false,
	                'on'       => 'Yes',
	                'off'      => 'No',
	            ),
	            array(
	                'id'       => 'advance_cpanel',
	                'type'     => 'switch',
	                'title'    => esc_html__( 'Enable Cpanel', 'snsbiamuc' ),
	                'default'  => false,
	                'on'       => 'Yes',
	                'off'      => 'No',
	            ),
	            array(
	                'id'       => 'advance_scrolltotop',
	                'type'     => 'switch',
	                'title'    => esc_html__( 'Enable Button Scroll To Top', 'snsbiamuc' ),
	                'default'  => true,
	                'on'       => 'Yes',
	                'off'      => 'No',
	            ),
	            array(
	                'id'		=> 'advance_scss_compile',
	                'type'		=> 'select',
	                'title'		=> esc_html__( 'SCSS Compile', 'snsbiamuc' ),
	                'options'  => array(
	                    '1' => 'Only compile when don\'t have the css file',
	                    '2' => 'Alway compile'
	                ),
	                'default'  => '1'
			    ),
	            array(
	                'id'		=> 'advance_scss_format',
	                'type'		=> 'select',
	                'title'		=> esc_html__( 'CSS Format', 'snsbiamuc' ),
	                'options'  => array(
	                    'scss_formatter' => 'scss_formatter',
	                    'scss_formatter_nested' => 'scss_formatter_nested',
	                    'scss_formatter_compressed' => 'scss_formatter_compressed',
	                ),
	                'default'  => 'scss_formatter_compressed'
			    ),
	            array(
	                'id'       => 'advance_customcss',
	                'type'     => 'ace_editor',
	                'title'    => esc_html__( 'Custom CSS', 'snsbiamuc' ),
	                'subtitle' => esc_html__( 'Paste your CSS code here. EX: .class{font-size:13px}', 'snsbiamuc' ),
	                'mode'     => 'css',
	                'theme'    => 'monokai',
	                'default'  => ""
	            ),
	            array(
	                'id'       => 'advance_customjs',
	                'type'     => 'ace_editor',
	                'title'    => esc_html__( 'Custom JS', 'snsbiamuc' ),
	                'subtitle' => esc_html__( 'Enter your JS code here.', 'snsbiamuc' ),
	                'theme'    => 'chrome',
	                'default'  => ""
	            ),
	        )
	    );
	}
}
}

?>