<?php
/**
 * SNSBIAMUC_Social_Accounts widget class
 */
class SNSBIAMUC_Social_Accounts extends WP_Widget {

	function __construct(){
		parent::__construct(
			'SNSBIAMUC_Social_Accounts',
			esc_html__( 'SNS - Social Accounts', 'snsbiamuc' ),
			array( "description" => esc_html__("Display a list of social accounts", 'snsbiamuc') )
		);
	}

	function widget( $args, $instance ) {
		$output = '';

		$title = ( ! empty( $instance['title'] ) ) ? $instance['title'] : esc_html__( 'Follow us on','snsbiamuc' );
		$layout = ( ! empty( $instance['layout'] ) ) ? $instance['layout'] : 'layout_1';

		/** This filter is documented in wp-includes/default-widgets.php */
		$title = apply_filters( 'widget_title', $title, $instance, $this->id_base );

		$output .= $args['before_widget'];
		if ( $title ) {
			$output .= $args['before_title'] . esc_html($title) . $args['after_title'];
		}
		$about_author 	= ( ! empty( $instance['about_author'] ) ) ? ( $instance['about_author'] ) : '';

		$author_socials = array(
			'facebook' => ( ! empty( $instance['facebook'] ) ) ? strip_tags($instance['facebook']) : '',
			'instagram' => ( ! empty( $instance['instagram'] ) ) ? strip_tags($instance['instagram']) : '',
			'twitter' => ( ! empty( $instance['twitter'] ) ) ? strip_tags($instance['twitter']) : '',
			'googleplus' => ( ! empty( $instance['googleplus'] ) ) ? strip_tags($instance['googleplus']) : '',
			'pinterest' => ( ! empty( $instance['pinterest'] ) ) ? strip_tags($instance['pinterest']) : '',
			'youtube' => ( ! empty( $instance['youtube'] ) ) ? strip_tags($instance['youtube']) : '',
			'linkedin' => ( ! empty( $instance['linkedin'] ) ) ? strip_tags($instance['linkedin']) : '',
			'tumblr' => ( ! empty( $instance['tumblr'] ) ) ? strip_tags($instance['tumblr']) : '',
			'flickr' => ( ! empty( $instance['flickr'] ) ) ? strip_tags($instance['flickr']) : ''
		);

		// Return HTML
		ob_start();
		?>
		<div class="block-sns-socials <?php echo esc_attr($layout);?>">
			
			<div class="sns-socials-content">
				<?php if( trim($about_author) != '' ) echo '<p>' . esc_html($about_author). '</p>';?>
				
				<div class="sns-socials-account">
					<?php 
                    	foreach ($author_socials as $key => $value){
                    		if( $value )
                    		echo '<a href="'.esc_url($value).'" target="blank"><i class="social_'.$key.'"></i>'.$key.'</a>';
                    	}
                    ?>
				</div>
				
			</div>
        </div><!-- /.block-sns-socials -->
		<?php 
		$output .= ob_get_contents();
		ob_end_clean();
		
		$output .= $args['after_widget'];

		echo $output;
	}

	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		$instance['title'] 			= strip_tags($new_instance['title']);
		$instance['layout'] 		= strip_tags($new_instance['layout']);
		
		$instance['facebook'] 		=  $new_instance['facebook'];
		$instance['instagram'] 		=  $new_instance['instagram'];
		$instance['twitter'] 		=  $new_instance['twitter'];
		$instance['googleplus'] 	=  $new_instance['googleplus'];
		$instance['pinterest'] 		=  $new_instance['pinterest'];
		$instance['youtube'] 		=  $new_instance['youtube'];
		$instance['linkedin'] 		=  $new_instance['linkedin'];
		$instance['tumblr'] 		=  $new_instance['tumblr'];
		$instance['flickr'] 		=  $new_instance['flickr'];

		return $instance;
	}

	function form( $instance ) {
		$title  = isset( $instance['title'] ) ? esc_attr( $instance['title'] ) : 'Follow us on';
		$layout  = isset( $instance['layout'] ) ? esc_attr( $instance['layout'] ) : 'layout_1';
		
		// 
		$author_socials = array(
			'facebook' => isset( $instance['facebook'] ) ? strip_tags($instance['facebook']) : '',
			'instagram' => isset( $instance['instagram'] ) ? strip_tags($instance['instagram']) : '',
			'twitter' => isset( $instance['twitter'] ) ? strip_tags($instance['twitter']) : '',
			'googleplus' => isset( $instance['googleplus'] ) ? strip_tags($instance['googleplus']) : '',
			'pinterest' => isset( $instance['pinterest'] ) ? strip_tags($instance['pinterest']) : '',
			'youtube' => isset( $instance['youtube'] ) ? strip_tags($instance['youtube']) : '',
			'linkedin' => isset( $instance['linkedin'] ) ? strip_tags($instance['linkedin']) : '',
			'tumblr' => isset( $instance['tumblr'] ) ? strip_tags($instance['tumblr']) : '',
			'flickr' => isset( $instance['flickr'] ) ? strip_tags($instance['flickr']) : ''
		);
		
?>
		<p><label for="<?php echo esc_attr($this->get_field_id( 'title' )); ?>"><?php esc_html_e( 'Title:', 'snsbiamuc' ); ?></label>
			<input class="widefat" id="<?php echo esc_attr($this->get_field_id( 'title' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'title' )); ?>" type="text" value="<?php echo esc_html($title); ?>" /></p>
		
		<p><label for="<?php echo esc_attr($this->get_field_id( 'layout' )); ?>"><?php esc_html_e( 'Layout:', 'snsbiamuc' ); ?></label>
			<select  class="widefat" name="<?php echo esc_attr($this->get_field_name( 'layout' )); ?>" id="<?php echo esc_attr($this->get_field_id( 'layout' )); ?>">
				<option value="layout_1" <?php selected($layout, 'layout_1', true)?>><?php esc_html_e('Layout 1', 'snsbiamuc') ?></option>
				<option value="layout_2" <?php selected($layout, 'layout_2', true)?>><?php esc_html_e('Layout 2', 'snsbiamuc') ?></option>
			</select>
		</p>
		
		<?php // Social accounts text fields
		foreach ( $author_socials as $key => $value ): ?>
		
			<p><label for="<?php echo esc_attr($this->get_field_id( $key )); ?>" style="text-transform:capitalize;" ><?php echo esc_attr( $key ). ' URL:'; ?></label>
				<input class="widefat" id="<?php echo esc_attr($this->get_field_id( $key )); ?>" name="<?php echo esc_attr($this->get_field_name( $key )); ?>" type="text" value="<?php echo esc_html($value); ?>" /></p>
		
		<?php
		endforeach;
		?>
<?php
	}
}
/*
 * Register Wiget
*/
function SNSBIAMUC_Social_Accounts_Register(){
	register_widget('SNSBIAMUC_Social_Accounts');
}
add_action('widgets_init', 'SNSBIAMUC_Social_Accounts_Register');


/**
 * SNSBIAMUC_Widget_Infobox widget class
 */
class SNSBIAMUC_Widget_Infobox extends WP_Widget {

	function __construct(){
		parent::__construct(
			'SNSBIAMUC_Widget_Infobox',
			esc_html__( 'SNS - Infobox', 'snsbiamuc' ),
			array( "description" => esc_html__("Display Infobox custom postype", 'snsbiamuc') )
		);
	}

	function widget( $args, $instance ) {
		
		$output = '';

		$title = ( ! empty( $instance['title'] ) ) ? $instance['title'] : '';

		/** This filter is documented in wp-includes/default-widgets.php */
		$title = apply_filters( 'widget_title', $title, $instance, $this->id_base );

		$output .= $args['before_widget'];
		if ( $title ) {
			$output .= $args['before_title'] . esc_html($title) . $args['after_title'];
		}

		$uq = rand().time();
		$args_infobox = array(
			'post_type' => 'infobox',
			'posts_per_page' => -1
		);
		$infobox = new WP_Query($args_infobox);

		if ( $infobox->have_posts() ) :
		ob_start();
		?>
			<div class="sns-infobox-widget">
					<ul class="clearfix">
						<?php 
						while ( $infobox->have_posts() ) : $infobox->the_post(); ?>
						<li>
							<?php
							$title 	= get_the_title();
							$icon  	= get_post_meta(get_the_ID(), 'snsbiamuc_infobox_icon', true);
							$desc  	= get_post_meta(get_the_ID(), 'snsbiamuc_infobox_desc', true);
							$link	= get_post_meta(get_the_ID(), 'snsbiamuc_infobox_link', true);
							if( $link != ''):?>
							<a href="<?php echo esc_url($link); ?>" title="<?php echo esc_attr($title); ?>">
							<?php
							endif;
							?>
							
							<?php if(!empty($icon)):?>
							<div class="sns-info-icon">
								<i class="<?php echo esc_attr( $icon ); ?>"></i>
							</div>
							<?php endif; ?>
							
							<div class="sns-info-content">
								<h3><?php echo esc_html($title); ?></h3>
								<p><?php echo esc_html($desc); ?></p>
							</div>
							
							<?php
							if( $link != ''):?>
							</a>
							<?php
							endif;
							?>
						</li>
						<?php 
						endwhile;?>
					</ul>
				</div>
			<?php
			$output .= ob_get_clean();
			wp_reset_postdata();
		endif;
		
		$output .= $args['after_widget'];

		echo $output;
	}

	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		$instance['title'] 	= strip_tags($new_instance['title']);
		
		return $instance;
	}

	function form( $instance ) {
		$title  = isset( $instance['title'] ) ? esc_attr( $instance['title'] ) : '';
?>
		<p><label for="<?php echo esc_attr($this->get_field_id( 'title' )); ?>"><?php esc_html_e( 'Title:', 'snsbiamuc' ); ?></label>
			<input class="widefat" id="<?php echo esc_attr($this->get_field_id( 'title' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'title' )); ?>" type="text" value="<?php echo esc_html($title); ?>" /></p>
		
<?php
	}
}
/*
 * Register Wiget
*/
function SNSBIAMUC_Widget_Infobox_Register(){
	register_widget('SNSBIAMUC_Widget_Infobox');
}
add_action('widgets_init', 'SNSBIAMUC_Widget_Infobox_Register');

/**
 * SNSBIAMUC_Widget_Testimonial widget class
 */
class SNSBIAMUC_Widget_Testimonial extends WP_Widget {

	function __construct(){
		parent::__construct(
			'SNSBIAMUC_Widget_Testimonial',
			esc_html__( 'SNS - Testimonial', 'snsbiamuc' ),
			array( "description" => esc_html__("Display Testimonial", 'snsbiamuc') )
		);
	}

	function widget( $args, $instance ) {
		$output = '';

		$title = ( ! empty( $instance['title'] ) ) ? $instance['title'] : esc_html__( 'Testimonial','snsbiamuc' );

		/** This filter is documented in wp-includes/default-widgets.php */
		$title = apply_filters( 'widget_title', $title, $instance, $this->id_base );
		$posts_per_page = ( ! empty( $instance['posts_per_page'] ) ) ? absint($instance['posts_per_page']) : 4;
		$autoplay 	= ( ! empty( $instance['autoplay'] ) ) ? $instance['autoplay'] : 'false';

		$output .= $args['before_widget'];
		if ( $title ) {
			$output .= $args['before_title'] . esc_html($title) . $args['after_title'];
		}
		
		$uq = rand().time();
		$args_testi = array(
			'post_type' => 'testimonial',
			'posts_per_page' => $posts_per_page
		);
		$brand = new WP_Query($args_testi);
		
		if ( $brand->have_posts() ) :
			ob_start();
			?>
				<div id="sns_testimonial_widget<?php echo esc_attr($uq); ?>" class="sns-testimonial-widget">
					<div class="testimonial-widget-content sns-preload">
						<ul class="clearfix">
							<?php 
							while ( $brand->have_posts() ) : $brand->the_post(); ?>
							<li>
								<div class="quote-content"><i class="fa fa-quote-left"></i><?php the_content(); ?><i class="fa fa-quote-right"></i></div>
								<div class="quote-info">
									<div class="sns-avartar">
										<?php the_post_thumbnail('snsbiamuc_testimonial_avatar');?>
									</div>
									<div class="sns-test-title">
										<?php
										$title = get_the_title();
										$sub_title = get_post_meta(get_the_ID(), 'snsbiamuc_testisub', true);
										?>
										<h2><?php echo esc_html($title); ?></h2>
										<span><?php echo esc_html($sub_title); ?></span>
									</div>
								</div>
							</li>
							<?php 
							endwhile;?>
						</ul>
						<div class="sns-owl-dots"></div>
					</div>
					<script type="text/javascript">
						jQuery(document).ready(function(){
							jQuery('#sns_testimonial_widget<?php echo $uq;?> .testimonial-widget-content').removeClass('sns-preload');
							jQuery('#sns_testimonial_widget<?php echo $uq;?> .testimonial-widget-content ul').owlCarousel({
								items: 1,
								loop: true,
					            dots: true,
					            dotsContainer: '#sns_testimonial_widget<?php echo $uq;?> .sns-owl-dots',
							    autoplay: <?php echo ($autoplay == 'true') ? true : false ; ?>,
					            slideSpeed : 700
							});
						});
					</script>
				</div>
			<?php
			$output .= ob_get_clean();
			wp_reset_postdata();
		endif;
		
		$output .= $args['after_widget'];

		echo $output;
	}

	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		$instance['title'] 	= strip_tags($new_instance['title']);
		$instance['posts_per_page'] 	= absint($new_instance['posts_per_page']);
		$instance['autoplay']  = $new_instance['autoplay'];
		
		return $instance;
	}

	function form( $instance ) {
		$title  = isset( $instance['title'] ) ? esc_attr( $instance['title'] ) : 'Testimonial';
		$posts_per_page  = isset( $instance['posts_per_page'] ) ? absint( $instance['posts_per_page'] ) : 4;
		$autoplay  = isset( $instance['autoplay'] ) ? esc_attr( $instance['autoplay'] ) : 'true';
?>
		<p><label for="<?php echo esc_attr($this->get_field_id( 'title' )); ?>"><?php esc_html_e( 'Title:', 'snsbiamuc' ); ?></label>
			<input class="widefat" id="<?php echo esc_attr($this->get_field_id( 'title' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'title' )); ?>" type="text" value="<?php echo esc_html($title); ?>" /></p>

		<p><label for="<?php echo esc_attr($this->get_field_id( 'posts_per_page' )); ?>"><?php esc_html_e( 'Number Display:', 'snsbiamuc' ); ?></label>
			<input class="widefat" id="<?php echo esc_attr($this->get_field_id( 'posts_per_page' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'posts_per_page' )); ?>" type="text" value="<?php echo esc_html($posts_per_page); ?>" /></p>
		
		<p><label for="<?php echo esc_attr($this->get_field_id( 'autoplay' )); ?>"><?php esc_html_e( 'Autoplay:', 'snsbiamuc' ); ?></label>
			<select  class="widefat" name="<?php echo esc_attr($this->get_field_name( 'autoplay' )); ?>" id="<?php echo esc_attr($this->get_field_id( 'autoplay' )); ?>">
				<option value="true" <?php selected($autoplay, 'true', true)?>><?php esc_html_e('Yes', 'snsbiamuc')?></option>
				<option value="false" <?php selected($autoplay, 'false', true)?>><?php esc_html_e('No', 'snsbiamuc')?></option>
			</select>
		</p>
<?php
	}
}
/*
 * Register Wiget
*/
function SNSBIAMUC_Widget_Testimonial_Register(){
	register_widget('SNSBIAMUC_Widget_Testimonial');
}
//add_action('widgets_init', 'SNSBIAMUC_Widget_Testimonial_Register');


/**
 * SNSBIAMUC_Widget_Products widget class
 */
class SNSBIAMUC_Widget_Products extends WP_Widget {

	function __construct(){
		parent::__construct(
			'SNSBIAMUC_Widget_Products',
			esc_html__( 'SNS - Products', 'snsbiamuc' ),
			array( "description" => esc_html__("Display a list of your products", 'snsbiamuc') )
		);
	}

	function widget( $args, $instance ) {
		$output = '';
		$uq = rand().time();

		$title = ( ! empty( $instance['title'] ) ) ? $instance['title'] : esc_html__( 'Latest products','snsbiamuc' );

		/** This filter is documented in wp-includes/default-widgets.php */
		$title = apply_filters( 'widget_title', $title, $instance, $this->id_base );
		
		$type 	= ( ! empty( $instance['type'] ) ) ? $instance['type'] : 'recent';
		$layout = ( ! empty( $instance['layout'] ) ) ? $instance['layout'] : 'list';
		$number_display 	= ( ! empty( $instance['number_display'] ) ) ? (int)$instance['number_display'] : 4;

		$output .= $args['before_widget'];
		
		$output .= $args['before_title'] . esc_html($title) . $args['after_title'];

		if( class_exists('WooCommerce') ){
			global $product, $woocommerce;
			
			if( $type == 'related_products' ){
				if ( empty( $product ) || ! $product->exists() ) {
					return;
				}
				$related = $product->get_related( $number_display );
				 
				if ( sizeof( $related ) == 0 ) return;
				 
				$args_r = apply_filters( 'woocommerce_related_products_args', array(
					'post_type'            => 'product',
					'ignore_sticky_posts'  => 1,
					'no_found_rows'        => 1,
					'posts_per_page'       => $number_display,
					'orderby'              => 'rand',
					'post__in'             => $related,
					'post__not_in'         => array( $product->get_id() )
				) );
				
				$loop = new WP_Query($args_r);
			}else{
			$loop = snsbiamuc_woo_query($type, $number_display);
			}
		
			$uq = rand().time();
			if( $loop->have_posts() ) :
				$output .= '<div id="sns_widget_products'.esc_attr( $uq ).'" class="sns-widget-products woocommerce '.esc_attr( $layout ).'">';
					ob_start();
					?>
					<div class="widget_products">
						<?php
						while ( $loop->have_posts() ) : $loop->the_post();
						    	wc_get_template( 'vc/item-widget.php', array( 'layout' => $layout ));
						endwhile; ?>
					</div>
					<?php
					$output .= ob_get_clean();
				$output .= '</div>';
			endif;
			wp_reset_postdata();
		}
		
		$output .= $args['after_widget'];

		echo $output;
	}

	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		$instance['title'] 			= strip_tags($new_instance['title']);
		$instance['type'] 			=  $new_instance['type'];
		$instance['layout'] 		=  $new_instance['layout'];
		$instance['number_display'] =  (int)$new_instance['number_display'] == 0 ? 4 : (int)$new_instance['number_display'];
		

		return $instance;
	}

	function form( $instance ) {
		$title 	 		= isset( $instance['title'] ) ? esc_attr( $instance['title'] ) : 'Latest Products';
		$typer 			= isset( $instance['type'] ) ? esc_attr( $instance['type'] ) : 'recent';
		$layout 		= isset( $instance['layout'] ) ? esc_attr( $instance['layout'] ) : 'list';
		$number_display = isset( $instance['number_display'] ) ? esc_attr( $instance['number_display'] ) : '4';
		
		
?>
		<p><label for="<?php echo esc_attr($this->get_field_id( 'title' )); ?>"><?php esc_html_e( 'Title:', 'snsbiamuc' ); ?></label>
			<input class="widefat" id="<?php echo esc_attr($this->get_field_id( 'title' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'title' )); ?>" type="text" value="<?php echo esc_html($title); ?>" /></p>

		<p><label for="<?php echo esc_attr($this->get_field_id( 'type' )); ?>"><?php esc_html_e( 'Type:', 'snsbiamuc' ); ?></label>
			<select  class="widefat" name="<?php echo esc_attr($this->get_field_name( 'type' )); ?>" id="<?php echo esc_attr($this->get_field_id( 'type' )); ?>">
				<option value="recent" <?php selected($typer, 'recent', true)?>><?php esc_html_e('Latest Products', 'snsbiamuc') ?></option>
				<option value="best_selling" <?php selected($typer, 'best_selling', true)?>><?php esc_html_e('BestSeller Products', 'snsbiamuc') ?></option>
				<option value="top_rate" <?php selected($typer, 'top_rate', true)?>><?php esc_html_e('Top Rated Products', 'snsbiamuc') ?></option>
				<option value="on_sale" <?php selected($typer, 'on_sale', true)?>><?php esc_html_e('Special Products', 'snsbiamuc') ?></option>
				<option value="featured_product" <?php selected($typer, 'featured_product', true)?>><?php esc_html_e('Featured Products', 'snsbiamuc') ?></option>
				<option value="recent_review" <?php selected($typer, 'recent_review', true)?>><?php esc_html_e('Recent Review', 'snsbiamuc') ?></option>
			</select>
		</p>

		<p><label for="<?php echo esc_attr($this->get_field_id( 'layout' )); ?>"><?php esc_html_e( 'Layout:', 'snsbiamuc' ); ?></label>
			<select  class="widefat" name="<?php echo esc_attr($this->get_field_name( 'layout' )); ?>" id="<?php echo esc_attr($this->get_field_id( 'layout' )); ?>">
				<option value="list" <?php selected($layout, 'list', true)?>><?php esc_html_e('List', 'snsbiamuc') ?></option>
				<option value="grid" <?php selected($layout, 'grid', true)?>><?php esc_html_e('Grid', 'snsbiamuc') ?></option>
			</select>
		</p>

		<p><label for="<?php echo esc_attr($this->get_field_id( 'number_display' )); ?>"><?php esc_html_e( 'Number of products to show:', 'snsbiamuc' ); ?></label>
			<input class="widefat" id="<?php echo esc_attr($this->get_field_id( 'number_display' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'number_display' )); ?>" type="text" value="<?php echo esc_html($number_display); ?>" /></p>
		
<?php
	}
}
/*
 * Register Wiget
*/
function SNSBIAMUC_Widget_Products_Register(){
	register_widget('SNSBIAMUC_Widget_Products');
}
add_action('widgets_init', 'SNSBIAMUC_Widget_Products_Register');

/**
 * SNSBIAMUC_Widget_Product_Countdown widget class
 */
class SNSBIAMUC_Widget_Product_Countdown extends WP_Widget {

	function __construct(){
		parent::__construct(
			'SNSBIAMUC_Widget_Product_Countdown',
			esc_html__( 'SNS - Product Sale Countdown', 'snsbiamuc' ),
			array( "description" => esc_html__("Display the sale will end at the beginning of the set date.", 'snsbiamuc') )
		);
	}

	function widget( $args, $instance ) {
		$output = '';
		$uq = rand().time();

		$title = ( ! empty( $instance['title'] ) ) ? $instance['title'] : esc_html__( 'Deal of day','snsbiamuc' );

		/** This filter is documented in wp-includes/default-widgets.php */
		$title = apply_filters( 'widget_title', $title, $instance, $this->id_base );
		$product_id = ( ! empty( $instance['product_id'] ) ) ? (int)$instance['product_id'] : '';
		
		// Get the Sale Price Date To of the product
		$sale_price_dates_to 	= ( $date = get_post_meta( $product_id, '_sale_price_dates_to', true ) ) ? date_i18n( 'Y/m/d', $date ) : '';
		
		/** set sale price date to default 10 days for http://demo.snstheme.com/ */
		if($_SERVER['SERVER_NAME'] == 'demo.snstheme.com' || $_SERVER['SERVER_NAME'] == 'dev.snsgroup.me' ){
			if($sale_price_dates_to == 0)
				$sale_price_dates_to = date('Y/m/d', strtotime('+10 days'));
		}
		
		$output .= $args['before_widget'];

		$output .= $args['before_title'] . esc_html($title) . $args['after_title'];

		if( class_exists('WooCommerce') ){
			if($sale_price_dates_to == ''){ // Return if is blank
				echo '<div style="color: red">'.esc_html__('May be the Scheduled Sale End Date of this product is not set.', 'snsbiamuc') . '</div>';
				return '';
			}
			
			$uq = rand().time();
			
			$output .= '<div id="sns_widget_product_sale_countdown'.esc_attr( $uq ).'" class="sns_widget_product_sale_countdown">';
			ob_start();
			?>		<div class="sns_sale_countdown_thumb">
						<?php
						if( has_post_thumbnail($product_id) ):?>
							<a href="<?php echo esc_url(get_permalink($product_id)); ?>" title="<?php echo esc_attr( get_the_title($product_id) );?>">
								<?php
								echo get_the_post_thumbnail($product_id);
								?>
							</a>
							<?php
						endif;
						?>
					</div>
					<div class="sns_sale_countdown">
						<div class="sns_sale_clock"></div>
						<div class="sns_sale_more"><a href="<?php echo esc_url(get_permalink($product_id)); ?>" title="<?php esc_attr_e('Click here', 'snsbiamuc');?>"><?php esc_html_e('Click here', 'snsbiamuc');?></a></div>
					</div>
					<div class="sns_sale_countdown_title">
						<div class="sns_sale_title"><a href="<?php echo esc_url(get_permalink($product_id)); ?>" title="<?php echo esc_attr(get_the_title($product_id)); ?>"><?php echo get_the_title($product_id); ?></a></div>
						<div class="sns_sale_price">
							<?php
							$product = new WC_Product( $product_id );
							echo $product->get_price_html();
							?>
						</div>
					</div>
					<script type="text/javascript">
					jQuery(document).ready(function($){
						$('#sns_widget_product_sale_countdown<?php echo $uq;?> .sns_sale_clock').countdown('<?php echo $sale_price_dates_to; ?>', function(event) {
							$(this).html(event.strftime('%-D day%!D : %H : %M : %S'));
						});
					});
					</script>
			<?php
			$output .= ob_get_clean();
			$output .= '</div>';
			wp_reset_postdata();
		}
		
		$output .= $args['after_widget'];

		echo $output;
	}

	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		$instance['title'] 			= strip_tags($new_instance['title']);
		$instance['product_id'] 	= esc_attr($new_instance['product_id']);
		

		return $instance;
	}

	function form( $instance ) {
		$title 	 		= isset( $instance['title'] ) ? esc_attr( $instance['title'] ) : 'Deal of day';
		$product_id		= isset( $instance['product_id'] ) ? esc_attr( $instance['product_id'] ) : '';
		
?>
		<p><label for="<?php echo esc_attr($this->get_field_id( 'title' )); ?>"><?php esc_html_e( 'Title:', 'snsbiamuc' ); ?></label>
			<input class="widefat" id="<?php echo esc_attr($this->get_field_id( 'title' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'title' )); ?>" type="text" value="<?php echo esc_html($title); ?>" /></p>
		
		<p><label for="<?php echo esc_attr($this->get_field_id( 'product_id' )); ?>"><?php esc_html_e( 'Product ID:', 'snsbiamuc' ); ?></label>
			<input class="widefat" id="<?php echo esc_attr($this->get_field_id( 'product_id' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'product_id' )); ?>" type="text" value="<?php echo esc_html($product_id); ?>" />
			<span class="description"><?php esc_html_e('The ID of the product to get the form Sale Price Date To.', 'snsbiamuc'); ?></span>
		</p>

<?php
	}
}
/*
 * Register Wiget
*/
function SNSBIAMUC_Widget_Product_Countdown_Register(){
	register_widget('SNSBIAMUC_Widget_Product_Countdown');
}
//add_action('widgets_init', 'SNSBIAMUC_Widget_Product_Countdown_Register');


/**
 * SNSBIAMUC_Widget_Latest_Posts widget class
 */
class SNSBIAMUC_Widget_Latest_Posts extends WP_Widget {

	function __construct(){
		parent::__construct(
			'SNSBIAMUC_Widget_Latest_Posts',
			esc_html__( 'SNS - Latest Posts Slider', 'snsbiamuc' ),
			array( "description" => esc_html__("Display latest posts", 'snsbiamuc') )
		);
	}

	function widget( $args, $instance ) {
		$output = '';
		$uq = rand().time();
		
		$title = ( ! empty( $instance['title'] ) ) ? $instance['title'] : esc_html__( 'Latest posts','snsbiamuc' );

		/** This filter is documented in wp-includes/default-widgets.php */
		$title = apply_filters( 'widget_title', $title, $instance, $this->id_base );
		
		$show_author 	= ( ! empty( $instance['show_author'] ) ) ? $instance['show_author'] : 'show';
		$show_date 	= ( ! empty( $instance['show_date'] ) ) ? $instance['show_date'] : 'show';
		$number 	= ( ! empty( $instance['number'] ) ) ? $instance['number'] : 3;
		$autoplay 	= ( ! empty( $instance['autoplay'] ) ) ? $instance['autoplay'] : 'false';

		$output .= $args['before_widget'];
		if ( $title ) {
			$output .= $args['before_title'] . esc_html($title) . $args['after_title'];
		}
		
		$my_query = array(
			'post_type'      => 'post',
			'posts_per_page' => $number ,
			'order'          => 'DESC',
			'orderby'        => 'date',
			'ignore_sticky_posts' => true,
			'post_status'    => 'publish'
		);
		$latest_posts = new WP_Query($my_query);
		
		
		if( $latest_posts->have_posts() ) :
			$output .= '<div id="sns_latestpost_wd'.esc_attr( $uq ).'" class="sns-latest-posts-widget">';
				$output .= '<ul>';
					while ( $latest_posts->have_posts() ) : $latest_posts->the_post();
						$output .= '<li class="item-post">';
							if(has_post_thumbnail()):
								$output .= '<div class="post-thumb">';
									$output .= '<a class="post-author" href="'. esc_url(get_permalink()).'">';
										$output .= get_the_post_thumbnail(get_the_ID(), 'snsbiamuc_latest_posts');
									$output .= '</a>';
								$output .= '</div>';
							endif;
							$output .= '<div class="post-info">';
							if ( $show_date == 'show' )
								$output .= '<div class="item-date date"><span class="d-day">'. esc_html(get_the_date('j')) .'</span><span class="d-month">'. esc_html(get_the_date('M')) .'</span>'.
								'</div>';
							$output .= '<div class="info-inner">';
							if ( $show_author == 'show' )
								$output .= '<a class="post-author" href="'.esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) )) .'">'.get_the_author_meta('nickname').'</a>';
							
							$output .= '<h4 class="post-title"><a href="'.esc_url(get_permalink()).'">'.get_the_title().'</a></h4>';
							$output .= '</div>';
							$output .= '</div>';
						$output .= '</li>';
					endwhile;
				
				$output .= '</ul>';
				$output .= '<div class="navslider" style="display:none"><span class="prev"><i class="fa fa-long-arrow-left"></i></span><span class="next"><i class="fa fa-long-arrow-right"></i></span></div>';
			$output .= '</div>';
			ob_start();
			?>
			<script type="text/javascript">
			jQuery(document).ready(function(){
				jQuery('#sns_latestpost_wd<?php echo $uq;?> ul').owlCarousel({
					items: 1,
					loop:true,
			        dots: false,
				   	autoplay: <?php echo esc_js($autoplay); ?>,
			        onInitialized: callback,
			        slideSpeed : 600
				});
				function callback(event) {
						if(this._items.length > this.options.items){
				        jQuery('#sns_latestpost_wd<?php echo $uq;?> .navslider').show();
				    }else{
				        jQuery('#sns_latestpost_wd<?php echo $uq;?> .navslider').hide();
				    }
				}
				jQuery('#sns_latestpost_wd<?php echo $uq;?> .navslider .prev').on('click', function(e){
					e.preventDefault();
					jQuery('#sns_latestpost_wd<?php echo $uq;?> ul').trigger('prev.owl.carousel');
				});
				jQuery('#sns_latestpost_wd<?php echo $uq;?> .navslider .next').on('click', function(e){
					e.preventDefault();
					jQuery('#sns_latestpost_wd<?php echo $uq;?> ul').trigger('next.owl.carousel');
				});
			});
			</script>
			<?php
			$output .= ob_get_clean();
		endif;
		/* Restore original Post Data */
		wp_reset_postdata();
		$output .= $args['after_widget'];

		echo $output;
	}

	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		$instance['title'] 			= strip_tags($new_instance['title']);
		$instance['show_author'] 	=  $new_instance['show_author'];
		$instance['show_date'] 		=  $new_instance['show_date'];
		$instance['number'] 		=  (int)$new_instance['number'] == 0 ? 3 : (int)$new_instance['number'];
		$instance['autoplay'] 		=  $new_instance['autoplay'];

		return $instance;
	}

	function form( $instance ) {
		$title 	 		= isset( $instance['title'] ) ? esc_attr( $instance['title'] ) : 'Latest posts';
		$show_author 	= isset( $instance['show_author'] ) ? esc_attr( $instance['show_author'] ) : 'show';
		$show_date 		= isset( $instance['show_date'] ) ? esc_attr( $instance['show_date'] ) : 'show';
		$number 		= isset( $instance['number'] ) ? esc_attr( $instance['number'] ) : '3';
		$autoplay  = isset( $instance['autoplay'] ) ? esc_attr( $instance['autoplay'] ) : 'true';
		
?>
		<p><label for="<?php echo esc_attr($this->get_field_id( 'title' )); ?>"><?php esc_html_e( 'Title:', 'snsbiamuc' ); ?></label>
			<input class="widefat" id="<?php echo esc_attr($this->get_field_id( 'title' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'title' )); ?>" type="text" value="<?php echo esc_html($title); ?>" /></p>

		<p><label for="<?php echo esc_attr($this->get_field_id( 'show_author' )); ?>"><?php esc_html_e( 'Show Author:', 'snsbiamuc' ); ?></label>
			<select  class="widefat" name="<?php echo esc_attr($this->get_field_name( 'show_author' )); ?>" id="<?php echo esc_attr($this->get_field_id( 'show_author' )); ?>">
				<option value="show" <?php selected($show_author, 'show', true)?>><?php esc_html_e('Show', 'snsbiamuc')?></option>
				<option value="hide" <?php selected($show_author, 'hide', true)?>><?php esc_html_e('Hide', 'snsbiamuc')?></option>
			</select>
		</p>
		
		<p><label for="<?php echo esc_attr($this->get_field_id( 'show_date' )); ?>"><?php esc_html_e( 'Show Date:', 'snsbiamuc' ); ?></label>
			<select  class="widefat" name="<?php echo esc_attr($this->get_field_name( 'show_date' )); ?>" id="<?php echo esc_attr($this->get_field_id( 'show_date' )); ?>">
				<option value="show" <?php selected($show_date, 'show', true)?>><?php esc_html_e('Show', 'snsbiamuc')?></option>
				<option value="hide" <?php selected($show_date, 'hide', true)?>><?php esc_html_e('Hide', 'snsbiamuc')?></option>
			</select>
		</p>
		
		<p><label for="<?php echo esc_attr($this->get_field_id( 'number' )); ?>"><?php esc_html_e( 'Number Posts:', 'snsbiamuc' ); ?></label>
			<input class="widefat" id="<?php echo esc_attr($this->get_field_id( 'number' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'number' )); ?>" type="text" value="<?php echo esc_html($number); ?>" /></p>
		
		<p><label for="<?php echo esc_attr($this->get_field_id( 'autoplay' )); ?>"><?php esc_html_e( 'Autoplay:', 'snsbiamuc' ); ?></label>
			<select  class="widefat" name="<?php echo esc_attr($this->get_field_name( 'autoplay' )); ?>" id="<?php echo esc_attr($this->get_field_id( 'autoplay' )); ?>">
				<option value="true" <?php selected($autoplay, 'true', true)?>><?php esc_html_e('Yes', 'snsbiamuc')?></option>
				<option value="false" <?php selected($autoplay, 'false', true)?>><?php esc_html_e('No', 'snsbiamuc')?></option>
			</select>
		</p>
<?php
	}
}
/*
 * Register Wiget
*/
function SNSBIAMUC_Widget_Latest_Posts_Register(){
	register_widget('SNSBIAMUC_Widget_Latest_Posts');
}
//add_action('widgets_init', 'SNSBIAMUC_Widget_Latest_Posts_Register');


class SNSBIAMUC_Widget_Facebook extends WP_Widget {
	public function __construct() {
		$widget_ops = array('description' => esc_html__( 'Display your facebook like box', 'snsbiamuc' ) );
		parent::__construct('sns_facebook', esc_html__('SNS - Facebook', 'snsbiamuc'), $widget_ops);
	}
	public function widget( $args, $instance ) {
		$title = apply_filters( 'widget_title', empty( $instance['title'] ) ? '' : $instance['title'], $instance, $this->id_base );
		echo wp_kses( $args['before_widget'], array(
				                                'aside' => array(
				                                    'id' => array(),
				                                    'class' => array()
				                                ),
				                            ) );
		if ( $title ) echo wp_kses( $args['before_title'] . esc_html($title) . $args['after_title'], array(
				                                'h3' => array(
				                                    'class' => array()
				                                ),
				                                'h4' => array(
				                                    'class' => array()
				                                ),
				                                'span' => array(
				                                    'class' => array()
				                                ),
				                            ) );

		$fanpageName = empty( $instance['fanpageName'] ) ? 'snstheme' : esc_html($instance['fanpageName']);
		?>
		<div class="content">
			<div id="fb-root"></div>
			<script>(function(d, s, id) {
			  var js, fjs = d.getElementsByTagName(s)[0];
			  if (d.getElementById(id)) return;
			  js = d.createElement(s); js.id = id;
			  js.src = "//connect.facebook.net/en_GB/sdk.js#xfbml=1&version=v2.4";
			  fjs.parentNode.insertBefore(js, fjs);
			}(document, 'script', 'facebook-jssdk'));</script>
			<div class="fb-page" 
			data-href="https://www.facebook.com/<?php echo esc_html($fanpageName); ?>" 
			data-small-header="true" 
			data-adapt-container-width="true" 
			data-hide-cover="false" 
			data-show-facepile="true" 
			data-show-posts="false">
				<div class="fb-xfbml-parse-ignore">
					<blockquote cite="https://www.facebook.com/<?php echo esc_html($fanpageName); ?>">
						<a href="https://www.facebook.com/<?php echo esc_html($fanpageName); ?>"><?php echo esc_html($fanpageName); ?></a>
					</blockquote>
				</div>
			</div>
		</div>
		<?php
		echo wp_kses( $args['after_widget'], array(
				                                'aside' => array()
				                            ) );
	}
	public function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		$new_instance = wp_parse_args((array) $new_instance, array( 
			'title' => 'SNS Facebook',
			'fanpageName' => 'snstheme',
			'numberDisplay' => '12',
		));
		$instance['title'] = strip_tags($new_instance['title']);
		$instance['fanpageName'] = strip_tags($new_instance['fanpageName']);
		$instance['numberDisplay'] = strip_tags($new_instance['numberDisplay']);
		return $instance;
	}
	public function form( $instance ) {
		$instance = wp_parse_args( (array) $instance, array( 
			'title' => 'SNS Facebook',
			'fanpageName' => 'snstheme',
			'numberDisplay' => '12',
		) );
		$title = $instance['title'];
		$fanpageName = $instance['fanpageName'];
		$numberDisplay = $instance['numberDisplay'];
?>
	<p>
		<label for="<?php echo esc_attr($this->get_field_id('title')); ?>">
			<?php esc_html_e('Title:', 'snsbiamuc'); ?>
			<input class="widefat" id="<?php echo esc_attr($this->get_field_id('title')); ?>" name="<?php echo esc_attr( $this->get_field_name('title') ); ?>" type="text" value="<?php echo esc_attr($title); ?>" />
		</label>
	</p>
	<p>
		<label for="<?php echo esc_attr($this->get_field_id('fanpageName')); ?>">
			<?php esc_html_e('Fanpage Name:', 'snsbiamuc'); ?>
			<input class="widefat" id="<?php echo esc_attr($this->get_field_id('fanpageName')); ?>" name="<?php echo esc_attr($this->get_field_name('fanpageName')); ?>" type="text" value="<?php echo esc_attr($fanpageName); ?>" />
		</label>
	</p>
<?php
	}
}

class SNSBIAMUC_Widget_Recent_Post extends WP_Widget {
	
	function __construct(){
		$widget_ops = array('description' => esc_html__( 'Display recent posts', 'snsbiamuc' ) );
		parent::__construct('snsbiamuc_recentpost', esc_html__('SNS - Recent Post', 'snsbiamuc'), $widget_ops);
	}
	
	function widget($args, $instance){
		extract($args);
		$title = apply_filters('widget_title', $instance['title']);
		$number = esc_attr($instance['number']);
		$template = ( !empty( $instance['template'] ) ) ? $instance['template'] : 'list';
		
		echo wp_kses( $before_widget, array(
				                                'aside' => array(
				                                	'class' => array('asdf')
				                                )
				                            ) );

		if($title) {
			echo wp_kses( $before_title . esc_html($title) . $after_title, array(
				                                'h3' => array(
				                                    'class' => array()
				                                ),
				                                'h4' => array(
				                                    'class' => array()
				                                ),
				                                'span' => array(
				                                    'class' => array()
				                                ),
				                            ) );
		}
		?>
		<?php
		$args = array(
			'post_type'      => 'post',
			'posts_per_page' => $number ,
			'order'          => 'DESC',
		    'orderby'        => 'date',
		    'ignore_sticky_posts' => true,
		    'post_status'    => 'publish'
		);
		$recent_posts = new WP_Query($args);
		if($recent_posts->have_posts()):
			switch($template):
				case 'accordion':
					?>
					<ul class="tpl-accordion pre-load">
						<?php 
						$i = 0;
						while($recent_posts->have_posts()): $recent_posts->the_post(); $i++; ?>
						<li>
							<a href="#" class="sns-recentp-acc <?php echo ($i == 1) ? 'active' : ''; ?>" title="<?php the_title(); ?>"><?php the_title(); ?></a>
							<div class="sns-recentp-content">
								<?php if(has_post_thumbnail()): ?>
								<div class="post-img">
									<a href="<?php the_permalink(); ?>" title="<?php the_title(); ?>">
								    <?php the_post_thumbnail('snsbiamuc_latest_posts_widget_accordion'); ?>
									</a>
									<div class="post-date"><span class="sns-j"><?php echo get_the_date('j');?></span><span class="sns-m"><?php echo get_the_date('M');?></span></div>
								</div>
								<?php endif; ?>
								<div class="post-excerpt">
									<?php echo get_the_excerpt(); ?>
					       		</div>
					       		<a href="<?php the_permalink(); ?>" class="read-more" title="<?php the_title(); ?>"><?php echo esc_html__('Read More', 'snsbiamuc'); ?></a>
							</div>
				        </li>
						<?php endwhile; ?>
					</ul>
					<script type="text/javascript">
						jQuery(document).ready(function($){
							$('.widget_snsbiamuc_recentpost').each(function(){
								var $_this_wg = $(this);
								$($_this_wg).find('.tpl-accordion').removeClass('pre-load');

								$($_this_wg).find('.tpl-accordion > li:not(:first) .sns-recentp-content').hide();

								$($_this_wg).find('.tpl-accordion > li .sns-recentp-acc').click(function(){
									if( !$(this).hasClass('active') ){
										$($_this_wg).find('.tpl-accordion > li .sns-recentp-content:visible').slideUp('slow');
										$($_this_wg).find('.tpl-accordion > li .sns-recentp-acc').removeClass('active');
										$(this).next().slideDown('slow');
										$(this).addClass('active');
									}
									return false;
								});
							});
						});
					</script>
					<?php
					break;
				default: 
					?>
			        <ul class="widget-posts">
					<?php while($recent_posts->have_posts()): $recent_posts->the_post(); ?>
				        <li class="post-item">
							<?php if(has_post_thumbnail()): ?>
							<div class="post-img">
								<a href="<?php the_permalink(); ?>" title="<?php the_title(); ?>">
							    <?php the_post_thumbnail('snsbiamuc_latest_posts_widget'); ?>
								</a>
							</div>
							<?php endif; ?>
					        <div class="post-title"><a href="<?php the_permalink(); ?>" title="<?php the_title(); ?>"><?php the_title() ?></a>
					        	<span class="post-date"><?php echo get_the_date();?></span>
					        </div>
				        </li>
			        <?php endwhile; ?>
			        </ul>
					<?php
					break;
			endswitch;
			
		wp_reset_postdata();
		endif; ?>
     
		<?php echo wp_kses( $after_widget, array(
				                                'aside' => array()
				                            ) );
	}
	
	function update($new_instance, $old_instance){
		$instance = $old_instance;

		$instance['title'] = esc_attr($new_instance['title']);
		$instance['template'] = esc_attr($new_instance['template']);
		$instance['number'] = esc_attr($new_instance['number']);
		
		return $instance;
	}

	function form($instance){
		$defaults = array(
			'title' => 'Recent posts', 
			'template' => 'list', 
			'number' => 4);
		$instance = wp_parse_args((array) $instance, $defaults); ?>
		<p>
			<label for="<?php echo esc_attr($this->get_field_id('title')); ?>"><?php esc_html_e('Title:', 'snsbiamuc'); ?></label>
			<input class="widefat" type="text"  id="<?php echo esc_attr($this->get_field_id('title')); ?>" name="<?php echo esc_attr($this->get_field_name('title')); ?>" value="<?php echo esc_attr($instance['title']); ?>" />
		</p>
		<p>
			<label for="<?php echo esc_attr( $this->get_field_id('template') ); ?>"><?php esc_html_e('Template:', 'snsbiamuc'); ?></label>
			<select class="widefat" id="<?php echo esc_attr( $this->get_field_id('template') ); ?>" name="<?php echo esc_attr( $this->get_field_name('template') ); ?>">
				<option value="list" <?php selected($instance['template'], 'list', true) ?>><?php esc_html_e('List', 'snsbiamuc'); ?></option>
				<option value="accordion" <?php selected($instance['template'], 'accordion', true) ?>><?php esc_html_e('Accordion', 'snsbiamuc'); ?></option>
			</select>
		</p>
		<p>
			<label for="<?php echo esc_attr($this->get_field_id('number')); ?>"><?php esc_html_e('Number of items to show:', 'snsbiamuc'); ?></label>
			<input class="widefat" type="text"  id="<?php echo esc_attr($this->get_field_id('number')); ?>" name="<?php echo esc_attr($this->get_field_name('number')); ?>" value="<?php echo esc_attr($instance['number']); ?>" />
		</p>
	<?php
	}
}

class SNSBIAMUC_Widget_Icon_Box extends WP_Widget{

	function __construct(){
		parent::__construct(
			'SNSBIAMUC_Widget_Icon_Box',
			esc_html__('SNS - Icon Box', 'snsbiamuc'),
			array('description' => esc_html__('Display a box with Awesome Icon, Title, Description.','snsbiamuc'))
		);
	}

	function widget($args, $instance){
		$html = '';

		$title = ( !empty( $instance['title'] ) ) ? $instance['title'] : esc_html__('Your Title Here...', 'snsbiamuc');
		$url = ( !empty( $instance['url'] ) ) ? $instance['url'] : '#';
		$icon = ( !empty( $instance['icon'] ) ) ? $instance['icon'] : 'fa fa-home';
		$desc = ( !empty( $instance['desc'] ) ) ? $instance['desc'] : '';

		/** This filter is documented in wp-includes/default-widgets.php */
		$title = apply_filters( 'widget_title', $title, $instance, $this->id_base );

		$html .= $args['before_widget'];
		
		ob_start();
		?>
		<div class="sns_icon_box">
			<div class="sns_icon_left">
				<div><a href="<?php echo esc_url($url) ?>" target="_blank"><i class="<?php echo esc_attr($icon); ?>"></i></a></div>
			</div>
			<div class="sns_icon_content_right">
				<div>
					<?php 
					if($title){
						echo $args['before_title'] . '<a href="'.esc_url($url).'" target="_blank">'. esc_html($title) . '</a>' . $args['after_title'];
					}
					echo esc_html($desc);
					?>
				</div>
			</div>
		</div>
		<?php
		$html .= ob_get_contents();
		ob_end_clean();

		$html .= $args['after_widget'];

			
		echo $html;

	}

	function update($new_instance, $old_instance){
		$instance 			= $old_instance;
		$instance['title'] 	= strip_tags($new_instance['title']);
		$instance['icon'] 	= esc_attr($new_instance['icon']);
		$instance['url'] 	= esc_attr($new_instance['url']);
		$instance['desc'] 	= $new_instance['desc'];

		return $instance;
	}

	function form($instance){
		$instance = wp_parse_args( (array) $instance, array( 'title' => '', 'url' => '#', 'icon' => 'fa fa-home', 'desc' => '' ) );
		$title = $instance['title'] ? strip_tags($instance['title']) : 'Your Title Here';
		$url = strip_tags($instance['url']);
		$icon = strip_tags($instance['icon']);
		$desc = esc_textarea($instance['desc']);
		?>
		<p><label for="<?php echo esc_attr($this->get_field_id( 'title' )); ?>"><?php echo esc_html__( 'Title:', 'snsbiamuc' ); ?></label>
		<input class="widefat" id="<?php echo esc_attr($this->get_field_id( 'title' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'title' )); ?>" type="text" value="<?php echo esc_html($title); ?>" /></p>
		
		<p><label for="<?php echo esc_attr($this->get_field_id( 'url' )); ?>"><?php echo esc_html__( 'URL:', 'snsbiamuc' ); ?></label>
		<input class="widefat" id="<?php echo esc_attr($this->get_field_id( 'url' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'url' )); ?>" type="text" value="<?php echo esc_html($url); ?>" /></p>
		<p class="description"><?php echo esc_html__('External url for Title', 'snsbiamuc');?></p>
		</p>
		
		<p><label for="<?php echo esc_attr($this->get_field_id( 'icon' )); ?>"><?php echo esc_html__( 'Icon:', 'snsbiamuc' ); ?></label>
		<input class="widefat" id="<?php echo esc_attr($this->get_field_id( 'icon' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'icon' )); ?>" type="text" value="<?php echo esc_html($icon); ?>" />
		<p class="description"><?php echo esc_html__('Use Font Awesome Icon. EX: fa fa-home', 'snsbiamuc');?></p>
		</p>
		
		<p><label for="<?php echo esc_attr($this->get_field_id( 'desc' )); ?>"><?php echo esc_html__( 'Description:', 'snsbiamuc'); ?></label>
		<textarea class="widefat" rows="16" cols="20" id="<?php echo esc_attr($this->get_field_id('desc')); ?>" name="<?php echo esc_attr($this->get_field_name('desc')); ?>"><?php echo esc_html($desc); ?></textarea></p>
		
	<?php
	}
	
}


class SNSBIAMUC_Widget_Twitter extends WP_Widget {
	public function __construct() {
		$widget_ops = array('description' => esc_html__( 'Display your tweets', 'snsbiamuc' ) );
		parent::__construct('sns_twitter', esc_html__('SNS - Twitter', 'snsbiamuc'), $widget_ops);
	}
	public function widget( $args, $instance ) {
   		wp_enqueue_script('twitter-js', SNSBIAMUC_THEME_URI . '/assets/js/twitterfetcher.min.js', array('jquery'), '', true );
   		
		$title 			= apply_filters( 'widget_title', empty( $instance['title'] ) ? '' : $instance['title'], $instance, $this->id_base );
		$limit 			= isset($instance['limit']) ? $instance['limit'] : 3;
		$follow_link 	= isset($instance['follow_link']) ? $instance['follow_link'] : true;
		$account_name 	= isset($instance['account_name']) ? $instance['account_name'] : 'snstheme';
		$avartar 		= isset($instance['avartar']) ? $instance['avartar'] : false;
		$interact_link 	= isset($instance['interact_link']) ? $instance['interact_link'] : true;
		$date 			= isset($instance['date']) ? $instance['date'] : false;
		
		$uq = rand().time();
		$class  = "";
		$class .= ($avartar)?'':' no-avartar';
		$class .= ($follow_link)?'':' no-follow-link';
		$class .= ($interact_link)?'':' no-interact-link';
		$class .= ($date)?'':' no-date';
		
		echo wp_kses( $args['before_widget'], array(
				                                'aside' => array(
				                                	'class' => array(),
				                                	'id' => array()
				                                )
				                            ) );
		if ( $title ) echo wp_kses( $args['before_title'] . esc_html($title) . $args['after_title'], array(
				                                'h3' => array(
				                                    'class' => array()
				                                ),
				                                'h4' => array(
				                                    'class' => array()
				                                ),
				                                'span' => array(
				                                    'class' => array()
				                                ),
				                            ) );
		
		if($follow_link && $account_name != ''){ ?>
		<a class="follow-link" href="http://twitter.com/follow?user=<?php echo esc_attr($account_name); ?>">
			<span><?php echo esc_html__("Follow", 'snsbiamuc'); ?></span>
		</a>
		<?php
		}
		?>
		<div class="content">
			<div id="sns_twitter_<?php echo esc_attr( $uq ); ?>" data-name="<?php echo $account_name; ?>" data-limit="<?php echo $limit; ?>" class="sns-tweets <?php echo esc_attr($class); ?>"></div>
		</div>
		<?php
		
		echo wp_kses( $args['after_widget'], array(
				                                'aside' => array()
				                            ) );
	}
	public function update( $new_instance, $old_instance ) {
		$new_instance = (array) $new_instance;
		$instance = array( 
			'follow_link' => 0,
			'avartar' => 0,
			'interact_link' => 0,
			'date' => 0,
		);
		foreach ( $instance as $field => $val )
			if ( isset($new_instance[$field]) )
				$instance[$field] = 1;

		$instance['title'] = ! empty( $new_instance['title'] ) ? $new_instance['title'] : 'SNS Twitter';
		$instance['limit'] = ! empty( $new_instance['limit'] ) ? intval( $new_instance['limit'] ) : 3;
		$instance['account_name'] = ! empty( $new_instance['account_name'] ) ? $new_instance['account_name'] : 'snstheme';

		return $instance;
	}
	public function form( $instance ) {
		$instance = wp_parse_args( (array) $instance, array( 
			'title' => 'SNS Twitter',
			'limit' => 2,
			'follow_link' => false,
			'account_name' => 'snstheme',
			'avartar' => true,
			'interact_link' => false,
			'date' => true
		) );
		$title = $instance['title'];
		$limit = $instance['limit'];
		$follow_link = $instance['follow_link'];
		$account_name = $instance['account_name'];
		$avartar = $instance['avartar'];
		$interact_link = $instance['interact_link'];
		$date = $instance['date'];
?>
	<p>
		<label for="<?php echo esc_attr($this->get_field_id('title')); ?>">
			<?php esc_html_e('Title:', 'snsbiamuc'); ?>
			<input class="widefat" id="<?php echo esc_attr($this->get_field_id('title')); ?>" name="<?php echo esc_attr($this->get_field_name('title')); ?>" type="text" value="<?php echo esc_attr($title); ?>" />
		</label>
	</p>
	<p>
		<label for="<?php echo esc_attr($this->get_field_id('limit')); ?>">
			<?php esc_html_e('Tweets Count:', 'snsbiamuc'); ?>
			<input class="widefat" id="<?php echo esc_attr($this->get_field_id('limit')); ?>" name="<?php echo esc_attr($this->get_field_name('limit')); ?>" type="text" value="<?php echo esc_attr($limit); ?>" />
		</label>
	</p>
	<p>
		<input class="checkbox" type="checkbox" <?php checked($instance['follow_link'], true) ?> id="<?php echo esc_attr($this->get_field_id('follow_link')); ?>" name="<?php echo esc_attr( $this->get_field_name('follow_link') ); ?>" />
		<label for="<?php echo esc_attr($this->get_field_id('follow_link')); ?>"><?php esc_html_e('Show follow link', 'snsbiamuc'); ?></label>
	</p>
	<p>
		<label for="<?php echo esc_attr( $this->get_field_id('account_name') ); ?>">
			<?php esc_html_e('Account Name:', 'snsbiamuc'); ?>
			<input class="widefat" id="<?php echo esc_attr( $this->get_field_id('account_name')); ?>" name="<?php echo esc_attr( $this->get_field_name('account_name')); ?>" type="text" value="<?php echo esc_attr($account_name); ?>" />
		</label>
	</p>
	<?php /*?>
	<p style="margin: 0;">
		<input class="checkbox" type="checkbox" <?php checked($instance['avartar'], true) ?> id="<?php echo esc_attr( $this->get_field_id('avartar') ); ?>" name="<?php echo esc_attr( $this->get_field_name('avartar') ); ?>" />
		<label for="<?php echo esc_attr( $this->get_field_id('avartar') ); ?>"><?php esc_html_e('Show avartar', 'snsbiamuc'); ?></label>
	</p>
	<?php */ ?>
	<p style="margin: 0;">
		<input class="checkbox" type="checkbox" <?php checked($instance['interact_link'], true) ?> id="<?php echo esc_attr( $this->get_field_id('interact_link') ); ?>" name="<?php echo esc_attr( $this->get_field_name('interact_link') ); ?>" />
		<label for="<?php echo esc_attr( $this->get_field_id('interact_link') ); ?>"><?php esc_html_e('Show interact link', 'snsbiamuc'); ?></label>
	</p>
	<p style="margin: 0;">
		<input class="checkbox" type="checkbox" <?php checked($instance['date'], true) ?> id="<?php echo esc_attr( $this->get_field_id('date') ); ?>" name="<?php echo esc_attr( $this->get_field_name('date') ); ?>" />
		<label for="<?php echo esc_attr( $this->get_field_id('date') ); ?>"><?php esc_html_e('Show date', 'snsbiamuc'); ?></label>
	</p>
	<br />

	<?php
	}
}


if ( class_exists('YITH_Woocompare_Widget') ){
	class SNSBIAMUC_Woocompare_Widget extends YITH_Woocompare_Widget {
		function widget( $args, $instance ) {
            global $yith_woocompare;

            /**
             * WPML Support
             */
            $lang = defined( 'ICL_LANGUAGE_CODE' ) ? ICL_LANGUAGE_CODE : false;

            extract( $args );

            $localized_widget_title = function_exists( 'icl_translate' ) ? icl_translate( 'Widget', 'widget_yit_compare_title_text', $instance['title'] ) : $instance['title'];

            echo wp_kses( $before_widget . $before_title . $localized_widget_title . $after_title, array(
            									'div' => array(
				                                    'class' => array()
				                                ),
				                                'h3' => array(
				                                    'class' => array()
				                                ),
				                                'h4' => array(
				                                    'class' => array()
				                                ),
				                                'span' => array(
				                                    'class' => array()
				                                ),
				                            ) );
            ?>

            <ul class="products-list" data-lang="<?php echo esc_attr( $lang ); ?>">
                <?php echo $yith_woocompare->obj->list_products_html(); ?>
            </ul>

            <a href="<?php echo esc_url( $yith_woocompare->obj->remove_product_url('all') ) ?>" data-product_id="all" class="clear-all"><?php esc_html_e( 'Clear all', 'snsbiamuc' ) ?></a>
            <a href="<?php echo esc_url( add_query_arg( array( 'iframe' => 'true' ), $yith_woocompare->obj->view_table_url() ) ) ?>" class="compare button"><?php esc_html_e( 'Compare', 'snsbiamuc' ) ?></a>

            <?php echo wp_kses( $after_widget, array(
            									'div' => array()
				                            ) );
        }
	}
}

if( class_exists('WooCommerce') ){
	
	/**
	 * SNS Tag Cloud Widget.
	 */
	class SNSBIAMUC_Widget_Product_Tag_Cloud extends WC_Widget {

		/**
		 * Constructor.
		 */
		public function __construct() {
			$this->widget_cssclass    = 'woocommerce snsbiamuc_widget_product_tag_cloud';
			$this->widget_description = esc_html__( 'Your most used product tags in cloud format.', 'snsbiamuc' );
			$this->widget_id          = 'sns_woocommerce_product_tag_cloud';
			$this->widget_name        = esc_html__( 'SNS Product Tags', 'snsbiamuc' );
			$this->settings           = array(
				'title'  => array(
					'type'  => 'text',
					'std'   => '',
					'label' => esc_html__( 'Title', 'snsbiamuc' )
				),
				'cutom_label'  => array(
					'type'  => 'text',
					'std'   => esc_html__( 'Tags:', 'snsbiamuc' ),
					'label' => esc_html__( 'Label', 'snsbiamuc' )
				)
			);

			parent::__construct();
		}

		/**
		 * Output widget.
		 *
		 * @see WP_Widget
		 *
		 * @param array $args
		 * @param array $instance
		 */
		public function widget( $args, $instance ) {
			$current_taxonomy = $this->_get_current_taxonomy( $instance );

			if ( empty( $instance['cutom_label'] ) ) {
				$instance['cutom_label'] = esc_html__( 'Tags:' , 'snsbiamuc');
			}

			$this->widget_start( $args, $instance );

			echo '<div class="tagcloud">';

			echo '<label>'. esc_html( $instance['cutom_label'] ) .'</label>';

			wp_tag_cloud( apply_filters( 'woocommerce_product_tag_cloud_widget_args', array(
				'taxonomy' => $current_taxonomy,
				'topic_count_text_callback' => array( $this, '_topic_count_text' ),
			) ) );

			echo '</div>';

			$this->widget_end( $args );
		}

		/**
		 * Return the taxonomy being displayed.
		 *
		 * @param  object $instance
		 * @return string
		 */
		public function _get_current_taxonomy( $instance ) {
			return 'product_tag';
		}

		/**
		 * Retuns topic count text.
		 *
		 * @since 2.6.0
		 * @param int $count
		 * @return string
		 */
		public function _topic_count_text( $count ) {
			/* translators: %s for product quantity, e.g. 1 product and 2 products */
			return sprintf( _n( '%s product', '%s products', $count, 'snsbiamuc' ), number_format_i18n( $count ) );
		}
	}


	/**
	 * SNS - Layered Navigation Widget
	 *
	 */
	class SNSBIAMUC_Widget_Layered_Nav extends WC_Widget {
	
		/**
		 * Constructor
		 */
		public function __construct() {
			$this->widget_cssclass    = 'woocommerce sns_widget_layered_nav widget_layered_nav';
			$this->widget_description = esc_html__( 'Shows a custom attribute in a widget which lets you narrow down the list of products when viewing product categories.', 'snsbiamuc' );
			$this->widget_id          = 'sns_woo_layered_nav';
			$this->widget_name        = esc_html__( 'SNS - Woo Layered Nav', 'snsbiamuc' );
			
			add_action('wp_ajax_sns_wcan_select_type', array( $this, 'ajax_print_terms') );
			
			parent::__construct();
		}
	
		
		public function update( $new_instance, $old_instance ) {
			
			$instance               = $old_instance;
            $instance['title']      = strip_tags( $new_instance['title'] );
            $instance['attribute']  = stripslashes( $new_instance['attribute'] );
            $instance['display_type']       = stripslashes( $new_instance['display_type'] );
            $instance['query_type'] = stripslashes( $new_instance['query_type'] );
            $instance['colors']     = ! empty( $new_instance['colors'] ) ? $new_instance['colors'] : array();

            return $instance;
		}
	
		
		public function form( $instance ) {
			$defaults = array(
				'title'      => '',
				'attribute'  => '',
				'display_type' => 'list',
				'query_type' => 'and',
				'colors' => array(),
			);
			
			$instance = wp_parse_args( (array) $instance, $defaults );
			
			$title 			= $instance['title'] ? strip_tags($instance['title']) : 'Your Title Here';
			$attribute 		= $instance['attribute'];
			$display_type 	= $instance['display_type'];
			$query_type 	= $instance['query_type'];
			$colors 		= $instance['colors'];
			
			$attribute_array      = array();
			$attribute_taxonomies = wc_get_attribute_taxonomies();
			
			if ( $attribute_taxonomies ) {
				foreach ( $attribute_taxonomies as $tax ) {
					if ( taxonomy_exists( wc_attribute_taxonomy_name( $tax->attribute_name ) ) ) {
						$attribute_array[ $tax->attribute_name ] = $tax->attribute_name;
					}
				}
			}
			?>
			<p>
				<label for="<?php echo esc_attr( $this->get_field_id('title')); ?>"><?php esc_html_e('Title:', 'snsbiamuc'); ?></label>
				<input class="widefat" type="text"  id="<?php echo esc_attr( $this->get_field_id('title') ); ?>" name="<?php echo esc_attr( $this->get_field_name('title') ); ?>" value="<?php echo esc_attr($instance['title']); ?>" />
			</p>
			
			<p class="sns-wcan-attribute-list">
				<label for="<?php echo esc_attr( $this->get_field_id('attribute') ); ?>"><?php esc_html_e('Attribute:', 'snsbiamuc'); ?></label>
				<select class="sns_wcan_attributes widefat" id="<?php echo esc_attr( $this->get_field_id('attribute') ); ?>" name="<?php echo esc_attr( $this->get_field_name('attribute') ); ?>">
					<?php 
						foreach ($attribute_array as $key => $value){
						?>
						<option value="<?php echo esc_attr( $value ); ?>" <?php selected($attribute, $value, true) ?>><?php echo esc_html($value); ?></option>
						<?php
						}
					?>
				</select>
			</p>
			
			<p>
				<label for="<?php echo esc_attr( $this->get_field_id('display_type') ); ?>"><?php esc_html_e('Display type:', 'snsbiamuc'); ?></label>
				<select class="sns_wcan_type widefat" id="<?php echo esc_attr( $this->get_field_id('display_type') ); ?>" name="<?php echo esc_attr( $this->get_field_name('display_type') ); ?>">
						<option value="list" <?php selected($display_type, 'list', true) ?>><?php esc_html_e('List', 'snsbiamuc'); ?></option>
						<option value="color" <?php selected($display_type, 'color', true) ?>><?php esc_html_e('Color', 'snsbiamuc'); ?></option>
						<option value="dropdown" <?php selected($display_type, 'dropdown', true) ?>><?php esc_html_e('Dropdown', 'snsbiamuc'); ?></option>
				</select>
			</p>
			
			<p>
				<label for="<?php echo esc_attr( $this->get_field_id('query_type') ); ?>"><?php esc_html_e('Query type:', 'snsbiamuc'); ?></label>
				<select class="widefat" id="<?php echo esc_attr( $this->get_field_id('query_type') ); ?>" name="<?php echo esc_attr( $this->get_field_name('query_type') ); ?>">
						<option value="and" <?php selected($query_type, 'and', true) ?>><?php esc_html_e('AND', 'snsbiamuc'); ?></option>
						<option value="or" <?php selected($query_type, 'or', true) ?>><?php esc_html_e('OR', 'snsbiamuc'); ?></option>
				</select>
			</p>
			
			<div class="sns_wcan_placeholder">
				<?php
                $values = array();

                if ( $instance['display_type'] == 'color' ) {
                    $values = $instance['colors'];
                }

                $this->sns_wcan_attributes_table(
                    $instance['display_type'],
                    $instance['attribute'],
                    'widget-' . $this->id . '-',
                    'widget-' . $this->id_base . '[' . $this->number . ']',
                    $values
                );
                ?>
			</div>
			
			<input type="hidden" name="widget_id" value="widget-<?php echo esc_attr( $this->id )?>-" />
        	<input type="hidden" name="widget_name" value="widget-<?php echo esc_attr( $this->id_base ) ?>[<?php echo esc_attr( $this->number ) ?>]" />

            <script>jQuery(document).trigger('sns_colorpicker');</script>
			<?php
		}
		
		/**
		 * Print terms for the element selected
		 */
		public function ajax_print_terms() {
			$type      = $_POST['value'];
			$attribute = $_POST['attribute'];
			$return    = array( 'message' => '', 'content' => $_POST );
		
			$terms = get_terms( 'pa_' . $attribute, array( 'hide_empty' => '0' ) );
		
			$settings        = $this->get_settings();
			$widget_settings = $settings[ $this->number ];
			$value           = '';
		
			if( 'color' == $type ){
				$value = $widget_settings['colors'];
			}
		
			if ( $type ) {
				$return['content'] = $this->sns_wcan_attributes_table(
					$type,
					$attribute,
					$_POST['id'],
					$_POST['name'],
					$value,
					false
				);
			}
			
			echo json_encode( $return );
			die();
		}
		
		/**
		 * Print the widgets options already filled
		 *
		 * @param $type      string list|colors|label
		 * @param $attribute woocommerce taxonomy
		 * @param $id        id used in the <input />
		 * @param $name      base name used in the <input />
		 * @param $values    array of values (could be empty if this is an ajax call)
		 *
		 * @return string
		 */
		public function sns_wcan_attributes_table( $type, $attribute, $id, $name, $values = array(), $echo = true ){
			$return = '';
			
			$terms = get_terms( 'pa_' . $attribute, array( 'hide_empty' => '0' ) );
			
			if ( 'list' == $type ) {
				$return = '<input type="hidden" name="' . esc_attr( $name ) . '[colors]" value="" /><input type="hidden" name="' . esc_attr( $name ). '[labels]" value="" />';
			}
			
			elseif ( 'color' == $type ) {
				if ( ! empty( $terms ) ) {
					$return = sprintf( '<table><tr><th>%s</th><th>%s</th></tr>', esc_html__( 'Term', 'snsbiamuc' ), esc_html__( 'Color', 'snsbiamuc' ) );
			
					foreach ( $terms as $term ) {
						$return .= "<tr><td><label for='{$id}{$term->term_id}'>{$term->name}</label></td><td><input type='text' id='{$id}{$term->term_id}' name='{$name}[colors][{$term->term_id}]' value='" . ( isset( $values[$term->term_id] ) ? $values[$term->term_id] : '' ) . "' size='3' class='sns-colorpicker' /></td></tr>";
					}
			
					$return .= '</table>';
				}
			
				$return .= '<input type="hidden" name="' . esc_attr( $name ) . '[labels]" value="" />';
			}
			
			
			if ( $echo ) {
				echo $return;
			}
			
			return $return;
		}
	
		/**
		 * widget function.
		 *
		 * @see WP_Widget
		 *
		 * @param array $args
		 * @param array $instance
		 */
		public function widget( $args, $instance ) {
			global $_chosen_attributes;
	
			if ( ! is_post_type_archive( 'product' ) && ! is_tax( get_object_taxonomies( 'product' ) ) ) {
				return;
			}
	
			$current_term = is_tax() ? get_queried_object()->term_id : '';
			$current_tax  = is_tax() ? get_queried_object()->taxonomy : '';
			$taxonomy     = isset( $instance['attribute'] ) ? wc_attribute_taxonomy_name( $instance['attribute'] ) : '';
			$query_type   = isset( $instance['query_type'] ) ? $instance['query_type'] : 'and';
			$display_type = isset( $instance['display_type'] ) ? $instance['display_type'] : 'list';
	
			if ( ! taxonomy_exists( $taxonomy ) ) {
				return;
			}
	
			$get_terms_args = array( 'hide_empty' => '1' );
	
			$orderby = wc_attribute_orderby( $taxonomy );
	
			switch ( $orderby ) {
				case 'name' :
					$get_terms_args['orderby']    = 'name';
					$get_terms_args['menu_order'] = false;
					break;
				case 'id' :
					$get_terms_args['orderby']    = 'id';
					$get_terms_args['order']      = 'ASC';
					$get_terms_args['menu_order'] = false;
					break;
				case 'menu_order' :
					$get_terms_args['menu_order'] = 'ASC';
					break;
			}
	
			$terms = get_terms( $taxonomy, $get_terms_args );
	
			if ( 0 < count( $terms ) ) {
	
				ob_start();
	
				$found = false;
	
				$this->widget_start( $args, $instance );
	
				// Force found when option is selected - do not force found on taxonomy attributes
				if ( ! is_tax() && is_array( $_chosen_attributes ) && array_key_exists( $taxonomy, $_chosen_attributes ) ) {
					$found = true;
				}
	
				if ( 'dropdown' == $display_type ) {
	
					// skip when viewing the taxonomy
					if ( $current_tax && $taxonomy == $current_tax ) {
	
						$found = false;
	
					} else {
	
						$taxonomy_filter = str_replace( 'pa_', '', $taxonomy );
	
						$found = false;
	
						echo '<select class="dropdown_layered_nav_' . $taxonomy_filter . '">';
	
						echo '<option value="">' . sprintf( esc_html__( 'Any %s', 'snsbiamuc' ), wc_attribute_label( $taxonomy ) ) . '</option>';
	
						foreach ( $terms as $term ) {
	
							// If on a term page, skip that term in widget list
							if ( $term->term_id == $current_term ) {
								continue;
							}
	
							// Get count based on current view - uses transients
							$transient_name = 'wc_ln_count_' . md5( sanitize_key( $taxonomy ) . sanitize_key( $term->term_taxonomy_id ) );
	
							if ( false === ( $_products_in_term = get_transient( $transient_name ) ) ) {
	
								$_products_in_term = get_objects_in_term( $term->term_id, $taxonomy );
	
								set_transient( $transient_name, $_products_in_term, DAY_IN_SECONDS * 30 );
							}
	
							$option_is_set = ( isset( $_chosen_attributes[ $taxonomy ] ) && in_array( $term->term_id, $_chosen_attributes[ $taxonomy ]['terms'] ) );
	
							// If this is an AND query, only show options with count > 0
							if ( 'and' == $query_type ) {
	
								$count = sizeof( array_intersect( $_products_in_term, WC()->query->filtered_product_ids ) );
	
								if ( 0 < $count ) {
									$found = true;
								}
	
								if ( 0 == $count && ! $option_is_set ) {
									continue;
								}
	
								// If this is an OR query, show all options so search can be expanded
							} else {
	
								$count = sizeof( array_intersect( $_products_in_term, WC()->query->unfiltered_product_ids ) );
	
								if ( 0 < $count ) {
									$found = true;
								}
	
							}
	
							echo '<option value="' . esc_attr( $term->term_id ) . '" ' . selected( isset( $_GET[ 'filter_' . $taxonomy_filter ] ) ? $_GET[ 'filter_' . $taxonomy_filter ] : '' , $term->term_id, false ) . '>' . esc_html( $term->name ) . '</option>';
						}
	
						echo '</select>';
	
						wc_enqueue_js( "
						jQuery( '.dropdown_layered_nav_$taxonomy_filter' ).change( function() {
						var term_id = parseInt( jQuery( this ).val(), 10 );
						location.href = '" . preg_replace( '%\/page\/[0-9]+%', '', str_replace( array( '&amp;', '%2C' ), array( '&', ',' ), esc_js( add_query_arg( 'filtering', '1', remove_query_arg( array( 'page', 'filter_' . $taxonomy_filter ) ) ) ) ) ) . "&filter_$taxonomy_filter=' + ( isNaN( term_id ) ? '' : term_id );
					});
					" );
	
					}
	
					} else {
	
					// List display, include color type
						if( $display_type == 'color' ){
							echo '<ul class="sns_layered_nav_color">';
						}else{
							echo '<ul>';
						}
						
	
						foreach ( $terms as $term ) {
	
						// Get count based on current view - uses transients
							$transient_name = 'wc_ln_count_' . md5( sanitize_key( $taxonomy ) . sanitize_key( $term->term_taxonomy_id ) );
	
							if ( false === ( $_products_in_term = get_transient( $transient_name ) ) ) {
	
							$_products_in_term = get_objects_in_term( $term->term_id, $taxonomy );
	
							set_transient( $transient_name, $_products_in_term );
							}
	
							$option_is_set = ( isset( $_chosen_attributes[ $taxonomy ] ) && in_array( $term->term_id, $_chosen_attributes[ $taxonomy ]['terms'] ) );
	
							// skip the term for the current archive
							if ( $current_term == $term->term_id ) {
								continue;
							}
	
							// If this is an AND query, only show options with count > 0
							if ( 'and' == $query_type ) {
	
								$count = sizeof( array_intersect( $_products_in_term, WC()->query->filtered_product_ids ) );
	
								if ( 0 < $count && $current_term !== $term->term_id ) {
									$found = true;
								}
	
								if ( 0 == $count && ! $option_is_set ) {
									continue;
								}
	
								// If this is an OR query, show all options so search can be expanded
							} else {
	
								$count = sizeof( array_intersect( $_products_in_term, WC()->query->unfiltered_product_ids ) );
	
								if ( 0 < $count ) {
									$found = true;
								}
							}
	
							$arg = 'filter_' . sanitize_title( $instance['attribute'] );
	
							$current_filter = ( isset( $_GET[ $arg ] ) ) ? explode( ',', $_GET[ $arg ] ) : array();
	
							if ( ! is_array( $current_filter ) ) {
								$current_filter = array();
							}
	
							$current_filter = array_map( 'esc_attr', $current_filter );
	
							if ( ! in_array( $term->term_id, $current_filter ) ) {
								$current_filter[] = $term->term_id;
							}
	
							// Base Link decided by current page
							if ( defined( 'SHOP_IS_ON_FRONT' ) ) {
								$link = esc_url( home_url( '/' ) );
							} elseif ( is_post_type_archive( 'product' ) || is_page( wc_get_page_id('shop') ) ) {
								$link = get_post_type_archive_link( 'product' );
							} else {
								$link = get_term_link( get_query_var('term'), get_query_var('taxonomy') );
							}
	
							// All current filters
							if ( $_chosen_attributes ) {
								foreach ( $_chosen_attributes as $name => $data ) {
									if ( $name !== $taxonomy ) {
	
										// Exclude query arg for current term archive term
										while ( in_array( $current_term, $data['terms'] ) ) {
											$key = array_search( $current_term, $data );
											unset( $data['terms'][$key] );
										}
	
										// Remove pa_ and sanitize
										$filter_name = sanitize_title( str_replace( 'pa_', '', $name ) );
	
										if ( ! empty( $data['terms'] ) ) {
											$link = add_query_arg( 'filter_' . $filter_name, implode( ',', $data['terms'] ), $link );
										}
	
										if ( 'or' == $data['query_type'] ) {
											$link = add_query_arg( 'query_type_' . $filter_name, 'or', $link );
										}
									}
								}
							}
	
							// Min/Max
							if ( isset( $_GET['min_price'] ) ) {
								$link = add_query_arg( 'min_price', $_GET['min_price'], $link );
							}
	
							if ( isset( $_GET['max_price'] ) ) {
								$link = add_query_arg( 'max_price', $_GET['max_price'], $link );
							}
	
							// Orderby
							if ( isset( $_GET['orderby'] ) ) {
								$link = add_query_arg( 'orderby', $_GET['orderby'], $link );
							}
	
							// Current Filter = this widget
							if ( isset( $_chosen_attributes[ $taxonomy ] ) && is_array( $_chosen_attributes[ $taxonomy ]['terms'] ) && in_array( $term->term_id, $_chosen_attributes[ $taxonomy ]['terms'] ) ) {
	
								$class = 'class="chosen"';
	
								// Remove this term is $current_filter has more than 1 term filtered
								if ( sizeof( $current_filter ) > 1 ) {
									$current_filter_without_this = array_diff( $current_filter, array( $term->term_id ) );
									$link = add_query_arg( $arg, implode( ',', $current_filter_without_this ), $link );
								}
	
							} else {
	
								$class = '';
								$link = add_query_arg( $arg, implode( ',', $current_filter ), $link );
	
							}
	
							// Search Arg
							if ( get_search_query() ) {
								$link = add_query_arg( 's', get_search_query(), $link );
							}
	
							// Post Type Arg
							if ( isset( $_GET['post_type'] ) ) {
								$link = add_query_arg( 'post_type', $_GET['post_type'], $link );
							}
	
							// Query type Arg
							if ( $query_type == 'or' && ! ( sizeof( $current_filter ) == 1 && isset( $_chosen_attributes[ $taxonomy ]['terms'] ) && is_array( $_chosen_attributes[ $taxonomy ]['terms'] ) && in_array( $term->term_id, $_chosen_attributes[ $taxonomy ]['terms'] ) ) ) {
								$link = add_query_arg( 'query_type_' . sanitize_title( $instance['attribute'] ), 'or', $link );
							}
							
							if( $display_type == 'color' && !empty( $instance['colors'][$term->term_id] )){
								$li_style = apply_filters( "{$args['widget_id']}-li_style", 'background-color:' . $instance['colors'][$term->term_id] . ';', $instance );
								
								echo '<li ' . $class . '>';
								
								echo ( $count > 0 || $option_is_set ) ? '<span class="sns_nav_color" style="' . $li_style . '"></span><a href="' . esc_url( apply_filters( 'woocommerce_layered_nav_link', $link ) ) . '" title="' . esc_attr( $term->name ) . '" >' : '<span style="background-color:' . $instance['colors'][$term->term_id] . ';" >';
								
								echo esc_html($term->name);
								
								echo ( $count > 0 || $option_is_set ) ? '</a>' : '</span>';
								
								echo ' <span class="count">(' . $count . ')</span></li>';
							}else{
								echo '<li ' . $class . '>';
								
								echo ( $count > 0 || $option_is_set ) ? '<a href="' . esc_url( apply_filters( 'woocommerce_layered_nav_link', $link ) ) . '">' : '<span>';
								
								echo $term->name;
								
								echo ( $count > 0 || $option_is_set ) ? '</a>' : '</span>';
								
								echo ' <span class="count">(' . $count . ')</span></li>';
							}
							
						}
	
						echo '</ul>';
	
					} // End display type conditional
	
					$this->widget_end( $args );
	
					if ( ! $found ) {
						ob_end_clean();
					} else {
						echo ob_get_clean();
					}
			}
		}
	}
	
}// End check class exxit WooCommerce


/**
 * SNSBIAMUC_Widget_Text class
 */

/**
 * Core class used to implement a SNS Text widget.
 */
class SNSBIAMUC_Widget_Text extends WP_Widget {
	
	function __construct(){
		parent::__construct(
			'SNSBIAMUC_Widget_Text',
			esc_html__( 'SNS Text', 'snsbiamuc' ),
			array( "description" => esc_html__("Allow set image replace Title and Arbitrary text or HTML in content.", 'snsbiamuc') )
		);
	}

	
	public function widget( $args, $instance ) {

		/** This filter is documented in wp-includes/widgets/class-wp-widget-pages.php */
		$title = apply_filters( 'widget_title', empty( $instance['title'] ) ? '' : $instance['title'], $instance, $this->id_base );
		
		$image_url = ! empty( $instance['url'] ) ? $instance['url'] : '';
		
		$widget_text = ! empty( $instance['text'] ) ? $instance['text'] : '';

		/**
		 * Filter the content of the Text widget.
		 *
		 * @since 2.3.0
		 * @since 4.4.0 Added the `$this` parameter.
		 *
		 * @param string         $widget_text The widget content.
		 * @param array          $instance    Array of settings for the current widget.
		 * @param WP_Widget_Text $this        Current Text widget instance.
		 */
		$text = apply_filters( 'widget_text', $widget_text, $instance, $this );

		echo $args['before_widget'];
		if ( ! empty($image_url) ){
			echo $args['before_title'] . '<img src="'. esc_url($image_url) .'" alt="'.esc_attr($title).'"/>' . $args['after_title'];
		}
		elseif ( ! empty( $title ) ) {
			echo $args['before_title'] . $title . $args['after_title'];
		} ?>
			<div class="textwidget"><?php echo !empty( $instance['filter'] ) ? wpautop( $text ) : $text; ?></div>
		<?php
		echo $args['after_widget'];
	}

	public function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		$instance['title'] = sanitize_text_field( $new_instance['title'] );
		$instance['url'] = sanitize_text_field( $new_instance['url'] );
		if ( current_user_can('unfiltered_html') )
			$instance['text'] =  $new_instance['text'];
		else
			$instance['text'] = wp_kses_post( stripslashes( $new_instance['text'] ) );
		$instance['filter'] = ! empty( $new_instance['filter'] );
		return $instance;
	}

	public function form( $instance ) {
		$instance = wp_parse_args( (array) $instance, array( 'title' => '', 'url' => '', 'text' => '' ) );
		$filter = isset( $instance['filter'] ) ? $instance['filter'] : 0;
		$title = sanitize_text_field( $instance['title'] );
		$url = sanitize_text_field( $instance['url'] );
		
		?>
		<p><label for="<?php echo esc_attr($this->get_field_id('title')); ?>"><?php esc_html_e('Title:', 'snsbiamuc'); ?></label>
		<input class="widefat" id="<?php echo esc_attr($this->get_field_id('title')); ?>" name="<?php echo esc_attr($this->get_field_name('title')); ?>" type="text" value="<?php echo esc_attr($title); ?>" /></p>
		
		<p><label for="<?php echo esc_attr($this->get_field_id('url')); ?>"><?php esc_html_e('Image URL:', 'snsbiamuc'); ?></label>
		<input class="widefat" id="<?php echo esc_attr($this->get_field_id('url')); ?>" name="<?php echo esc_attr($this->get_field_name('url')); ?>" type="text" value="<?php echo esc_url($url); ?>" /></p>

		<p><label for="<?php echo esc_attr($this->get_field_id( 'text' )); ?>"><?php esc_html_e( 'Content:', 'snsbiamuc' ); ?></label>
		<textarea class="widefat" rows="16" cols="20" id="<?php echo esc_attr($this->get_field_id('text')); ?>" name="<?php echo esc_attr($this->get_field_name('text')); ?>"><?php echo esc_textarea( $instance['text'] ); ?></textarea></p>

		<p><input id="<?php echo esc_attr($this->get_field_id('filter')); ?>" name="<?php echo esc_attr($this->get_field_name('filter')); ?>" type="checkbox"<?php checked( $filter ); ?> />&nbsp;<label for="<?php echo esc_attr($this->get_field_id('filter')); ?>"><?php esc_html_e('Automatically add paragraphs', 'snsbiamuc'); ?></label></p>
		<?php
	}
}

function snsbiamuc_load_widgets() {
    register_widget( 'SNSBIAMUC_Widget_Facebook');
    register_widget( 'SNSBIAMUC_Widget_Twitter');
    register_widget( 'SNSBIAMUC_Widget_Recent_Post');
    //register_widget( 'SNSBIAMUC_Widget_Icon_Box');
    register_widget( 'SNSBIAMUC_Widget_Text');
    if ( class_exists('WooCommerce') && class_exists('YITH_Woocompare_Widget') ) register_widget( 'SNSBIAMUC_Woocompare_Widget');
    
    if ( class_exists('WooCommerce')){
    	register_widget('SNSBIAMUC_Widget_Product_Tag_Cloud');
    	register_widget('SNSBIAMUC_Widget_Layered_Nav');
    }
}
add_action('widgets_init', 'snsbiamuc_load_widgets');

