<?php
if(class_exists('WooCommerce')){
	class SnsBiaMuc_Woocommerce{
		public static function getInstance(){
			static $_instance;
			if( !$_instance ){
				$_instance = new SnsBiaMuc_Woocommerce();
			}
			return $_instance;
		}
		public function __construct(){
			// Add Scripts
			add_action( 'wp_enqueue_scripts', array($this,'snsbiamuc_getscripts') );
			// Number product per page
			add_filter( 'loop_shop_columns', array($this, 'snsbiamuc_woo_shop_columns') );
			// Grid cols per row
			add_filter( 'loop_shop_per_page', array($this, 'snsbiamuc_woo_shop_perpage') );
			// Remove each style one by one
			add_filter( 'woocommerce_enqueue_styles', array($this, 'snsbiamuc_dequeue_woostyles') );
			// Set modeview
			add_action( 'wp_ajax_sns_setmodeview', array($this,'snsbiamuc_set_modeview') );
			add_action( 'wp_ajax_nopriv_sns_setmodeview', array($this,'snsbiamuc_set_modeview') );
			// Ajax load more
			add_action('wp_ajax_sns_wooloadmore', array($this, 'snsbiamuc_woo_loadmore'));
			add_action('wp_ajax_nopriv_sns_wooloadmore', array($this, 'snsbiamuc_woo_loadmore'));
			
			// Ajax load more
			add_action('wp_ajax_sns_wootabloadproducts', array($this, 'snsbiamuc_woo_tab_load_products'));
			add_action('wp_ajax_nopriv_sns_wootabloadproducts', array($this, 'snsbiamuc_woo_tab_load_products'));
			add_action('wp_ajax_sns_woo_sub_tabs', array($this, 'snsbiamuc_woo_sub_tabs'));
			add_action('wp_ajax_nopriv_sns_woo_sub_tabs', array($this, 'snsbiamuc_woo_sub_tabs'));
			
			// Add Taxonomy product_cat custom meta fields
			add_action('product_cat_add_form_fields', array(&$this, 'snsbiamuc_product_cat_add_new_meta_field'), 20, 3);
			add_action('product_cat_edit_form_fields', array(&$this, 'snsbiamuc_product_cat_edit_meta_field'), 20, 3);
			// Save extra taxonomy fields callback function
			add_action( 'edit_term', array(&$this,'snsbiamuc_save_product_cat_custom_meta'), 10, 3 );
			add_action( 'created_term', array(&$this,'snsbiamuc_save_product_cat_custom_meta'), 10, 3 );

			// Add Taxonomy product_attributes custom meta fields
			$attribute_taxonomies = wc_get_attribute_taxonomies();
			if ( $attribute_taxonomies ) {
				foreach ( $attribute_taxonomies as $attribute) {
					add_action( 'pa_' . $attribute->attribute_name . '_add_form_fields', array(&$this, 'snsbiamuc_product_attribute_add_new_meta_field'), 20, 3 );
					add_action( 'pa_' . $attribute->attribute_name . '_edit_form_fields', array(&$this, 'snsbiamuc_product_attribute_edit_meta_field'), 20, 3);

					add_action( 'edit_term', array(&$this,'snsbiamuc_product_attribute_save_custom_meta'), 10, 3 );
					add_action( 'created_term', array(&$this,'snsbiamuc_product_attribute_save_custom_meta'), 10, 3 );
				}
			}
			// Variable Product
			add_action('wp_head', array(&$this, 'snsbiamuc_variable_product'), 1000);
			// Color attr
			add_action('wp_head', array(&$this, 'snsbiamuc_product_color_attr'), 1010);

			// Megamenu load products
			add_action('wp_ajax_sns_megamenu_load_products', array($this, 'snsbiamuc_megamenu_load_products'));
			add_action('wp_ajax_nopriv_sns_megamenu_load_products', array($this, 'snsbiamuc_megamenu_load_products'));
			
			// remove_action('woocommerce_before_shop_loop_item_title', 'woocommerce_template_loop_product_thumbnail', 10);
         	// add_action( 'woocommerce_before_shop_loop_item_title', 'snsbiamuc_product_thumbnail', 11 );
			
			remove_action( 'woocommerce_before_shop_loop_item', 'woocommerce_template_loop_product_link_open', 10 );
			remove_action( 'woocommerce_after_shop_loop_item', 'woocommerce_template_loop_product_link_close', 5 );
		}
		
		public function snsbiamuc_getscripts(){
            $optimize = '.min';
			wp_enqueue_script('snsbiamuc-woocommerce', SNSBIAMUC_THEME_URI.'/assets/js/sns-woocommerce.js', array('jquery'), '', true);
			// WooCommerce Ajax Navigation
			if ( class_exists( 'YITH_WCAN_Frontend' ) ) {
                wp_dequeue_script('yith-wcan-script');
                if ( is_product_category() || is_shop() ) {
                    wp_enqueue_script('snsbiamuc-wcan-script', SNSBIAMUC_THEME_URI.'/assets/js/yith-wcan-frontend.js', array('jquery'), '', true);
                    $args = apply_filters( 'yith_wcan_ajax_frontend_classes', array(
                                'container'             => yith_wcan_get_option( 'yith_wcan_ajax_shop_container', '.products' ),
                                'pagination'            => yith_wcan_get_option( 'yith_wcan_ajax_shop_pagination', 'nav.woocommerce-pagination' ),
                                'result_count'          => yith_wcan_get_option( 'yith_wcan_ajax_shop_result_container', '.woocommerce-result-count' ),
                                'wc_price_slider'       => array(
                                    'wrapper'   => '.price_slider',
                                    'min_price' => '.price_slider_amount #min_price',
                                    'max_price' => '.price_slider_amount #max_price',
                                )
                            )
                    );
                    wp_localize_script( 'snsbiamuc-wcan-script', 'yith_wcan', apply_filters( 'yith-wcan-frontend-args', $args ) );
                }
            }
            // producct page cloudzoom image
            wp_dequeue_script('prettyPhoto-init');
            if ( snsbiamuc_get_option('woo_usecloudzoom') && is_product() )
                wp_enqueue_script('elevatezoom-custom', SNSBIAMUC_THEME_URI.'/assets/js/elevatezoom-custom'.$optimize.'.js', array('jquery'), '', true);
		}
		public function snsbiamuc_product_color_attr () {
			if ( !is_shop() ) {
				return;
			}
			ob_start();?>
		    <script type="text/javascript">
		    	var snspd_color_code = {};
		    	<?php
			    $terms = get_terms("pa_colors");
				foreach ( $terms as $term ) { ?>
					snspd_color_code['<?php echo $term->slug ?>'] = '<?php echo get_woocommerce_term_meta( $term->term_id, 'snsbiamuc_product_attribute_color' ); ?>';
				<?php
				}
				?>
				//console.log(snspd_color_code);
	    	</script>
	        <?php
	        echo ob_get_clean();
		}
		public function snsbiamuc_variable_product(){
			$theID = get_the_id();
		 	$product = wc_get_product( $theID );
		   	if( !is_product() ){
            	return;
           	}
		    if( $product->get_type() === 'variable' ){
		        $attributes = $product->get_attributes();
		         ob_start();?>
		            <script type="text/javascript">
		                var sns_arr_attr = {};
		                <?php foreach ( $attributes as $attribute ) :
		                    if ( empty( $attribute['is_visible'] ) || ( $attribute['is_taxonomy'] && ! taxonomy_exists( $attribute['name'] ) ) ) {
		                        continue;
		                    } else {}
		                    
		                   $terms = wc_get_product_terms( $product->get_id(), $attribute['name'], array( 'fields' => 'all' ) );
		                    
		                    $type = '';
		                    $key_val = array();
		                    $i = 0;
		                    foreach ($terms as $term) { $i++;
		                        $type = get_woocommerce_term_meta( $term->term_id, 'snsbiamuc_product_attribute_type' );
		                        $type = ($type == '') ? 'text' : $type;
		                        switch ($type) {
		                            case 'color':
		                                $key_val[$term->slug] = get_woocommerce_term_meta( $term->term_id, 'snsbiamuc_product_attribute_color' );
		                                break;

		                            case 'image':
		                            	$att_image_id = get_woocommerce_term_meta( $term->term_id, 'snsbiamuc_product_attribute_image_id' );
		                            	$att_image = wp_get_attachment_image_src( $att_image_id, 'snsbiamuc_attribute_pa_images_size' );
		                            	$att_image_url = (isset($att_image['0'])) ? $att_image['0'] : '';

		                                $key_val[$term->slug] = $att_image_url;
		                                break;
		                            
		                            default: // type is text
		                                $key_val[$term->slug] = $term->name;
		                                break;
		                        }
		                    }
		                    ?>
		                    var attributeName = '<?php echo $attribute['name'] ?>';
		                    var data_type = '<?php echo $type; ?>';
		                    var key_val = {};
		                    <?php foreach ($key_val as $key => $value):?>
		                        key_val['<?php echo $key ?>'] = '<?php echo $value ?>';
		                    <?php endforeach;?>
		                    sns_arr_attr['attribute_' + attributeName] = {'type': data_type, key_val};
		                <?php endforeach; ?>
		                //console.log(sns_arr_attr);
		            </script>
		        <?php
		        echo ob_get_clean();
		    }
		}
		
		public function snsbiamuc_woo_loadmore(){
			$orderby        = $_POST['order'];
			$number_query   = $_POST['numberquery'];
			$start          = $_POST['start'];
			$list_cat       = $_POST['cat'];
			$col            = $_POST['col'];
			$eclass         = $_POST['eclass'];
			$loop = snsbiamuc_woo_query($orderby, $number_query, $list_cat, $start);
			while ( $loop->have_posts() ) : $loop->the_post();
			wc_get_template( 'vc/item-grid.php', array('col' => $col, 'animate' => 1, 'eclass' => $eclass) );
			endwhile;
			wp_die();
		}
		
		public function snsbiamuc_woo_tab_load_products(){
			
			$tab_args = array(
					'data_type'		=> $_POST['data_type'],
					'wrap_id'		=> $_POST['wrap_id'],
					'tab_id'		=> $_POST['tab_id'],
					'cat'			=> $_POST['cat'],
					'template'		=> $_POST['template'],
					'orderby'		=> $_POST['orderby'],
					'number_query'	=> $_POST['number_query'],
					'number_display'=> $_POST['number_display'],
					'number_limit'	=> $_POST['number_limit'],
					'effect_load'	=> $_POST['effect_load'],
					'row'			=> $_POST['row'],
					'col'			=> $_POST['col'],
					'uq'			=> $_POST['uq'],
					'number_load'	=> $_POST['number_load'],
					'eclass'		=> $_POST['eclass'],
					'animate'		=> 'yes',
				);
			
			wc_get_template( 'vc/template-tab.php', array('tab_args' => $tab_args) );
			wp_die();
		}
		
		public function snsbiamuc_woo_sub_tabs(){
			
			$tab_args = array(
					'orderby'		=> $_POST['orderby'],
					'wrap_id'		=> $_POST['wrap_id'],
					'tab_id'		=> $_POST['tab_id'],
					'cat'			=> $_POST['cat'],
					'number_query'	=> $_POST['number_limit'],
				);
			
			wc_get_template( 'vc/template-tab-2.php', array('tab_args' => $tab_args) );
			wp_die();
		}
		
		public function snsbiamuc_megamenu_load_products(){
			$uq = rand(1, 1000);
			
			$preview_content_id = $_POST['preview_content_id'];
			$data_type 			= $_POST['data_type'];
			$data_term 			= $_POST['data_term'];
			$posts_per_page 	= $_POST['posts_per_page'];
			
			$args = array(
				'post_type'             => 'product',
				'post_status'           => 'publish',
				'posts_per_page'        => $posts_per_page,
			);
			
			if($data_type == 'product_cat'){
				$args['tax_query']  = array(
				        array(
				            'taxonomy'      => 'product_cat',
				            'field' 		=> 'term_id', //This is optional, as it defaults to 'term_id'
				            'terms'         => $data_term,
				            'operator'      => 'IN' // Possible values are 'IN', 'NOT IN', 'AND'.
				        )
				    );
			}elseif($data_type == 'product_tag'){
				$args['tax_query']  = array(
					array(
						'taxonomy'      => 'product_tag',
						'field' 		=> 'term_id', //This is optional, as it defaults to 'term_id'
						'terms'         => $data_term,
						'operator'      => 'IN' // Possible values are 'IN', 'NOT IN', 'AND'.
					)
				);
			}
			
			$p = new WP_Query($args);
			if($p->have_posts()):
			?>
				<ul id="mega-ul-products-<?php echo esc_attr($uq); ?>">
				<?php 
					while ($p->have_posts()): $p->the_post();
					?>
					<li class="item">
						<div class="item-thumb">
							<a class="product-image" href="<?php the_permalink(); ?>">
							<?php if ( function_exists( 'woocommerce_template_loop_product_thumbnail' ) ) {
								woocommerce_template_loop_product_thumbnail();
							}?>
							</a>
						</div>
						<div class="item-content">
							<div class="item-title"><a class="product-name" href="<?php the_permalink(); ?>"><?php the_title(); ?></a></div>
							<div class="item-price">
							<?php if ( function_exists( 'woocommerce_template_loop_price' ) ) {
								woocommerce_template_loop_price();
							}?>
							</div>
						</div>
					</li>
					<?php
					endwhile;
				?>
				</ul>
				
				<script type="text/javascript">
                        jQuery(document).ready(function(){
                            jQuery('#mega-ul-products-<?php echo esc_attr($uq); ?>').owlCarousel({
                                items: 3,
                                loop:true,
                                dots: false,
                                // autoplay: true,
                                onInitialized: callback,
                                slideSpeed : 700
                            });
                            function callback(event) {
                                if(this._items.length > this.options.items){
                                    jQuery('#<?php echo $preview_content_id; ?>').find('.navslider').show();
                                }else{
                                    jQuery('#<?php echo $preview_content_id; ?>').find('.navslider').hide();
                                }
                            }
                            jQuery('#<?php echo $preview_content_id; ?>').find('.menu-preview-mode-content .navslider .prev').on('click', function(e){
                                e.preventDefault();
                                 jQuery('#mega-ul-products-<?php echo esc_attr($uq); ?>').trigger('prev.owl.carousel');
                            });
                            jQuery('#<?php echo $preview_content_id; ?>').find('.menu-preview-mode-content .navslider .next').on('click', function(e){
                                e.preventDefault();
                                jQuery('#mega-ul-products-<?php echo esc_attr($uq); ?>').trigger('next.owl.carousel');
                            });
                        });
                </script>
			<?php
			else:
				wc_get_template( 'loop/no-products-found.php' );
			endif;
			
			wp_reset_postdata();
			wp_die();
		}

		public function snsbiamuc_set_modeview(){
			setcookie('sns_woo_list_modeview', $_POST['mode'] , time()+3600*24*100, '/');
		}
		public function snsbiamuc_woo_shop_columns( $columns ) {
			global $snsbiamuc_opt;
			if(is_product_category()){
				$cat = get_queried_object();
				$snsbiamuc_product_cat_grid_col = get_woocommerce_term_meta( $cat->term_id, 'snsbiamuc_product_cat_grid_col' );
				if( $snsbiamuc_product_cat_grid_col != '' )
					return $snsbiamuc_product_cat_grid_col;
			}
		    return isset($snsbiamuc_opt['woo_grid_col']) ? $snsbiamuc_opt['woo_grid_col'] : '4';
		}
		public function snsbiamuc_woo_shop_perpage( $columns ) {
			global $snsbiamuc_opt;
		    return $snsbiamuc_opt['woo_number_perpage'];
		}
		
		public function snsbiamuc_dequeue_woostyles( $enqueue_styles ) {
			unset( $enqueue_styles['woocommerce-general'] );	// Remove the gloss
			unset( $enqueue_styles['woocommerce-layout'] );		// Remove the layout
			unset( $enqueue_styles['woocommerce-smallscreen'] );	// Remove the smallscreen optimisation
			return $enqueue_styles;
		}
		
		// Add term page
		public function snsbiamuc_product_cat_add_new_meta_field(){
			// This will add the custom meta field  to the add new term page
			?>
			<div class="form-field term-snsbiamuc_product_cat_layout">
				<label for="snsbiamuc_product_cat_layout"><?php esc_html_e( 'Layout', 'snsbiamuc' ); ?></label>
				<select name="snsbiamuc_product_cat_layout" id="snsbiamuc_product_cat_layout">
					<option value=""><?php esc_html_e('Default (Layout of Shop page)', 'snsbiamuc');?></option>
					<option value="m"><?php esc_html_e('Fullwidth', 'snsbiamuc');?></option>
					<option value="l-m"><?php esc_html_e('Left Sidebar', 'snsbiamuc');?></option>
					<option value="m-r"><?php esc_html_e('Right Sidebar', 'snsbiamuc');?></option>
				</select>
				<p class="description"><?php esc_html_e( 'Set the layout fullwidth or has sidebar (Woo Sidebar).','snsbiamuc' ); ?></p>
			</div>

			<div class="form-field term-snsbiamuc_product_cat_grid_col">
				<label for="snsbiamuc_product_cat_grid_col"><?php esc_html_e( 'Grid columns', 'snsbiamuc' ); ?></label>
				<select name="snsbiamuc_product_cat_grid_col" id="snsbiamuc_product_cat_grid_col">
					<option value=""><?php esc_html_e('Default', 'snsbiamuc');?></option>
					<option value="1">1</option>
					<option value="1">2</option>
					<option value="1">3</option>
					<option value="1">4</option>
					<option value="1">6</option>
				</select>
				<p class="description"><?php esc_html_e( 'We are using grid bootstap - 12 cols layout. Default use in Theme Options.','snsbiamuc' ); ?></p>
			</div>

			<div class="form-field term-snsbiamuc_product_cat_grid_spacing">
				<label for="snsbiamuc_product_cat_grid_spacing"><?php esc_html_e( 'Item Grid Spacing', 'snsbiamuc' ); ?></label>
				<select name="snsbiamuc_product_cat_grid_spacing" id="snsbiamuc_product_cat_grid_spacing">
					<option value="">0px</option>
					<option value="10">10px</option>
					<option value="20">20px</option>
					<option value="30">30px</option>
				</select>
				<p class="description"><?php esc_html_e( 'Choose the spacing of the products in grid view','snsbiamuc' ); ?></p>
			</div>
			
			<?php
		}
		// Edit term page
		public function snsbiamuc_product_cat_edit_meta_field($term, $taxonomy){
			$snsbiamuc_product_cat_layout = get_woocommerce_term_meta( $term->term_id, 'snsbiamuc_product_cat_layout' );
			$snsbiamuc_product_cat_grid_col = get_woocommerce_term_meta( $term->term_id, 'snsbiamuc_product_cat_grid_col' );
			$snsbiamuc_product_cat_grid_spacing = get_woocommerce_term_meta( $term->term_id, 'snsbiamuc_product_cat_grid_spacing' );
			?>
			
			<tr class="form-field snsbiamuc_product_cat_layout">
				<th scope="row"><label for="snsbiamuc_product_cat_layout"><?php esc_html_e( 'Layout', 'snsbiamuc' ); ?></label></th>
				<td>
					<select name="snsbiamuc_product_cat_layout" id="snsbiamuc_product_cat_layout">
						<option value="" <?php selected($snsbiamuc_product_cat_layout, '', true)?>><?php esc_html_e('Default (Layout of Shop page)', 'snsbiamuc');?></option>
						<option value="m" <?php selected($snsbiamuc_product_cat_layout, 'm', true)?>><?php esc_html_e('Fullwidth', 'snsbiamuc');?></option>
						<option value="m-r" <?php selected($snsbiamuc_product_cat_layout, 'm-r', true)?>><?php esc_html_e('Right Sidebar', 'snsbiamuc');?></option>
					</select>
					
					<p class="description"><?php esc_html_e( 'Set the layout fullwidth or has sidebar (Woo Sidebar).','snsbiamuc' ); ?></p>
				</td>
			</tr>

			<tr class="form-field snsbiamuc_product_cat_grid_col">
				<th scope="row"><label for="snsbiamuc_product_cat_grid_col"><?php esc_html_e( 'Grid columns', 'snsbiamuc' ); ?></label></th>
				<td>
					<select name="snsbiamuc_product_cat_grid_col" id="snsbiamuc_product_cat_grid_col">
						<option value="" <?php selected($snsbiamuc_product_cat_grid_col, '', true)?>><?php esc_html_e('Default', 'snsbiamuc');?></option>
						<option value="1" <?php selected($snsbiamuc_product_cat_grid_col, '1', true)?>>1</option>
						<option value="2" <?php selected($snsbiamuc_product_cat_grid_col, '2', true)?>>2</option>
						<option value="3" <?php selected($snsbiamuc_product_cat_grid_col, '3', true)?>>3</option>
						<option value="4" <?php selected($snsbiamuc_product_cat_grid_col, '4', true)?>>4</option>
						<option value="6" <?php selected($snsbiamuc_product_cat_grid_col, '6', true)?>>6</option>
					</select>
					
					<p class="description"><?php esc_html_e( 'We are using grid bootstap - 12 cols layout. Default use in Theme Options.','snsbiamuc' ); ?></p>
				</td>
			</tr>

			<tr class="form-field snsbiamuc_product_cat_grid_spacing">
				<th scope="row"><label for="snsbiamuc_product_cat_grid_spacing"><?php esc_html_e( 'Item Grid Spacing', 'snsbiamuc' ); ?></label></th>
				<td>
					<select name="snsbiamuc_product_cat_grid_spacing" id="snsbiamuc_product_cat_grid_spacing">
						<option value="" <?php selected($snsbiamuc_product_cat_grid_spacing, '', true)?>>0px</option>
						<option value="10" <?php selected($snsbiamuc_product_cat_grid_spacing, '10', true)?>>10px</option>
						<option value="20" <?php selected($snsbiamuc_product_cat_grid_spacing, '20', true)?>>20px</option>
						<option value="30" <?php selected($snsbiamuc_product_cat_grid_spacing, '30', true)?>>30px</option>
					</select>
					
					<p class="description"><?php esc_html_e( 'Choose the spacing of the products in grid view','snsbiamuc' ); ?></p>
				</td>
			</tr>
			<?php
		}
		// Save term page
		public function snsbiamuc_save_product_cat_custom_meta($term_id, $tt_id, $taxonomy){
			$fields = array(
				'snsbiamuc_product_cat_layout',
				'snsbiamuc_product_cat_grid_col',
				'snsbiamuc_product_cat_grid_spacing'
			);
			
			foreach ($fields as $field){
				if( isset($_POST[$field]) ){
					$value = !empty($_POST[$field]) ? $_POST[$field] : '';
					
					update_woocommerce_term_meta($term_id, $field, $value);
				}
			}
		}


		/*
		*	Add term page for product_attribute
		*/
		public function snsbiamuc_product_attribute_add_new_meta_field(){
			// This will add the custom meta field  to the add new term page
			?>
			<div class="form-field term-snsbiamuc_product_attribute_type">
				<label for="snsbiamuc_product_attribute_type"><?php esc_html_e( 'Type', 'snsbiamuc' ); ?></label>
				<select name="snsbiamuc_product_attribute_type" id="snsbiamuc_product_attribute_type">
					<option value="text"><?php esc_html_e('Text', 'snsbiamuc');?></option>
					<option value="color"><?php esc_html_e('Color Picker', 'snsbiamuc');?></option>
					<option value="image"><?php esc_html_e('Color Image', 'snsbiamuc');?></option>
				</select>
				<p class="description"></p>
			</div>

			<div class="form-field term-snsbiamuc_product_attribute_color">
				<label for="snsbiamuc_product_attribute_color"><?php esc_html_e( 'Color Picker', 'snsbiamuc' ); ?></label>
				<input type="text" class="colorpicker sns-colorpicker" value="" name="snsbiamuc_product_attribute_color"/>
				<p class="description"></p>
			</div>
			
			<div class="form-field term-snsbiamuc_product_attribute_image">
				<label for="snsbiamuc_product_attribute_image"><?php esc_html_e('Color Image', 'snsbiamuc'); ?></label>
				<div id="snsbiamuc_product_attribute_image" style="float: left; margin-right: 10px;">
					<img src="<?php echo wc_placeholder_img_src(); ?>" width="60px" height="60px">
				</div>
				<div style="line-height: 60px;">
					<input type="hidden" id="snsbiamuc_product_attribute_image_id" name="snsbiamuc_product_attribute_image_id">
					<button type="button" class="snscustom_upload_image_button button"><?php esc_html_e('Upload/Add image', 'snsbiamuc'); ?></button>
					<button type="button" class="snscustom_remove_image_button button" style="display: none;"><?php esc_html_e('Remove image', 'snsbiamuc'); ?></button>
				</div>
				<script type="text/javascript">
	
					// Only show the "remove image" button when needed
					if ( ! jQuery( '#snsbiamuc_product_attribute_image' ).val() ) {
						jQuery( '.snscustom_remove_image_button' ).hide();
					}
	
					// Uploading files
					var snscustom_file_frame;
	
					jQuery( document ).on( 'click', '.snscustom_upload_image_button', function( event ) {
	
						event.preventDefault();
	
						// If the media frame already exists, reopen it.
						if ( snscustom_file_frame ) {
							snscustom_file_frame.open();
							return;
						}
	
						// Create the media frame.
						snscustom_file_frame = wp.media.frames.downloadable_file = wp.media({
							title: 'Choose an image',
							button: {
								text: 'Use image'
							},
							multiple: false
						});
	
						// When an image is selected, run a callback.
						snscustom_file_frame.on( 'select', function() {
							var attachment = snscustom_file_frame.state().get( 'selection' ).first().toJSON();
	
							jQuery( '#snsbiamuc_product_attribute_image_id' ).val( attachment.id );
							jQuery( '#snsbiamuc_product_attribute_image' ).find( 'img' ).attr( 'src', attachment.sizes.thumbnail.url );
							jQuery( '.snscustom_remove_image_button' ).show();
						});
	
						// Finally, open the modal.
						snscustom_file_frame.open();
					});
	
					jQuery( document ).on( 'click', '.snscustom_remove_image_button', function() {
						var $wc_placeholder_img_src = '<?php echo wc_placeholder_img_src(); ?>';
						jQuery( '#snsbiamuc_product_attribute_image' ).find( 'img' ).attr( 'src', $wc_placeholder_img_src );
						jQuery( '#snsbiamuc_product_attribute_image_id' ).val( '' );
						jQuery( '.snscustom_remove_image_button' ).hide();
						return false;
					});
	
				</script>
				<div class="clear"></div>
				<p class="description"></p>
			</div>
			<script type="text/javascript">
			jQuery(document).ready(function(){
				jQuery('select[id="snsbiamuc_product_attribute_type"]').each(function(){
					var $thisSelected = jQuery(this).val();
					if( $thisSelected == 'color' ){
						jQuery('.term-snsbiamuc_product_attribute_color').stop(true, true).fadeIn(100);
						jQuery('.term-snsbiamuc_product_attribute_image').stop(true, true).fadeOut(0);
					}else if( $thisSelected == 'image' ){
						jQuery('.term-snsbiamuc_product_attribute_image').stop(true, true).fadeIn(100);
						jQuery('.term-snsbiamuc_product_attribute_color').stop(true, true).fadeOut(0);
					}else{
						jQuery('.term-snsbiamuc_product_attribute_color').stop(true, true).fadeOut(0);
						jQuery('.term-snsbiamuc_product_attribute_image').stop(true, true).fadeOut(0);
					}

					jQuery(this).on('change', function(){
						if( this.value == 'color' ){
							jQuery('.term-snsbiamuc_product_attribute_color').stop(true, true).fadeIn(100);
							jQuery('.term-snsbiamuc_product_attribute_image').stop(true, true).fadeOut(0);
						}else if( this.value == 'image' ){
							jQuery('.term-snsbiamuc_product_attribute_image').stop(true, true).fadeIn(100);
							jQuery('.term-snsbiamuc_product_attribute_color').stop(true, true).fadeOut(0);
						}else{
							jQuery('.term-snsbiamuc_product_attribute_color').stop(true, true).fadeOut(0);
							jQuery('.term-snsbiamuc_product_attribute_image').stop(true, true).fadeOut(0);
						}
					});
				});
			});
			</script>
			<?php
		}
		// Edit term page
		public function snsbiamuc_product_attribute_edit_meta_field($term, $taxonomy){
			$snsbiamuc_product_attribute_type = get_woocommerce_term_meta( $term->term_id, 'snsbiamuc_product_attribute_type' );
			$snsbiamuc_product_attribute_color = get_woocommerce_term_meta( $term->term_id, 'snsbiamuc_product_attribute_color' );
			$snsbiamuc_product_attribute_image_id = get_woocommerce_term_meta( $term->term_id, 'snsbiamuc_product_attribute_image_id' );
			$image_src = wc_placeholder_img_src(); // WC Thumbnail default
			if($snsbiamuc_product_attribute_image_id !==''){
				$image_src = wp_get_attachment_image_src($snsbiamuc_product_attribute_image_id);
				$image_src = $image_src[0];
			}
			?>
			
			<tr class="form-field snsbiamuc_product_attribute_type">
				<th scope="row"><label for="snsbiamuc_product_attribute_type"><?php esc_html_e( 'Type', 'snsbiamuc' ); ?></label></th>
				<td>
					<select name="snsbiamuc_product_attribute_type" id="snsbiamuc_product_attribute_type">
						<option value="text" <?php selected($snsbiamuc_product_attribute_type, 'text', true)?>><?php esc_html_e('Text', 'snsbiamuc');?></option>
						<option value="color" <?php selected($snsbiamuc_product_attribute_type, 'color', true)?>><?php esc_html_e('Color Picker', 'snsbiamuc');?></option>
						<option value="image" <?php selected($snsbiamuc_product_attribute_type, 'image', true)?>><?php esc_html_e('Color Image', 'snsbiamuc');?></option>
					</select>
					
					<p class="description"></p>
				</td>
			</tr>

			<tr class="form-field term-snsbiamuc_product_attribute_color">
				<th scope="row"><label for="snsbiamuc_product_attribute_color"><?php esc_html_e( 'Color Picker', 'snsbiamuc' ); ?></label></th>
				<td>
					<input type="text" class="colorpicker sns-colorpicker" value="<?php echo esc_attr( $snsbiamuc_product_attribute_color );?>" name="snsbiamuc_product_attribute_color"/>
					<p class="description"></p>
				</td>
			</tr>

			<tr class="form-field term-snsbiamuc_product_attribute_image">
				<th scope="row" valign="top">
					<label for="snsbiamuc_product_attribute_image"><?php esc_html_e('Color Image', 'snsbiamuc'); ?></label>
				</th>
				<td>
					<div id="snsbiamuc_product_attribute_image" style="float: left; margin-right: 10px;">
						<img src="<?php echo esc_url( $image_src ) ?>" width="60px" height="60px">
					</div>
					<div style="line-height: 60px;">
						<input type="hidden" id="snsbiamuc_product_attribute_image_id" name="snsbiamuc_product_attribute_image_id" value="<?php echo (int)$snsbiamuc_product_attribute_image_id; ?>">
						<button type="button" class="snscustom_upload_image_button button"><?php esc_html_e('Upload/Add image', 'snsbiamuc'); ?></button>
						<button type="button" class="snscustom_remove_image_button button"><?php esc_html_e('Remove image', 'snsbiamuc'); ?></button>
					</div>
					<script type="text/javascript">
						
						// Only show the "remove image" button when needed
						if ( '0' === jQuery( '#snsbiamuc_product_attribute_image_id' ).val() ) {
							jQuery( '.snscustom_remove_image_button' ).hide();
						}
	
						// Uploading files
						var snscustom_file_frame;
	
						jQuery( document ).on( 'click', '.snscustom_upload_image_button', function( event ) {
	
							event.preventDefault();
	
							// If the media frame already exists, reopen it.
							if ( snscustom_file_frame ) {
								snscustom_file_frame.open();
								return;
							}
	
							// Create the media frame.
							snscustom_file_frame = wp.media.frames.downloadable_file = wp.media({
								title: 'Choose an image',
								button: {
									text: 'Use image'
								},
								multiple: false
							});
	
							// When an image is selected, run a callback.
							snscustom_file_frame.on( 'select', function() {
								var attachment = snscustom_file_frame.state().get( 'selection' ).first().toJSON();
								jQuery( '#snsbiamuc_product_attribute_image_id' ).val( attachment.id );
								jQuery( '#snsbiamuc_product_attribute_image' ).find( 'img' ).attr( 'src', attachment.sizes.thumbnail.url );
								jQuery( '.snscustom_remove_image_button' ).show();
							});
	
							// Finally, open the modal.
							snscustom_file_frame.open();
						});
	
						jQuery( document ).on( 'click', '.snscustom_remove_image_button', function() {
							var $wc_placeholder_img_src = '<?php echo wc_placeholder_img_src(); ?>';
							jQuery( '#snsbiamuc_product_attribute_image' ).find( 'img' ).attr( 'src', $wc_placeholder_img_src );
							jQuery( '#snsbiamuc_product_attribute_image_id' ).val( '' );
							jQuery( '.snscustom_remove_image_button' ).hide();
							return false;
						});
		
					</script>
					<div class="clear"></div>
					<p class="description"></p>
				</td>
			</tr>
			<script type="text/javascript">
			jQuery(document).ready(function(){
				jQuery('select[id="snsbiamuc_product_attribute_type"]').each(function(){
					var $thisSelected = jQuery(this).val();
					if( $thisSelected == 'color' ){
						jQuery('.term-snsbiamuc_product_attribute_color').stop(true, true).fadeIn(100);
						jQuery('.term-snsbiamuc_product_attribute_image').stop(true, true).fadeOut(0);
					}else if( $thisSelected == 'image' ){
						jQuery('.term-snsbiamuc_product_attribute_image').stop(true, true).fadeIn(100);
						jQuery('.term-snsbiamuc_product_attribute_color').stop(true, true).fadeOut(0);
					}else{
						jQuery('.term-snsbiamuc_product_attribute_color').stop(true, true).fadeOut(0);
						jQuery('.term-snsbiamuc_product_attribute_image').stop(true, true).fadeOut(0);
					}

					jQuery(this).on('change', function(){
						if( this.value == 'color' ){
							jQuery('.term-snsbiamuc_product_attribute_color').stop(true, true).fadeIn(100);
							jQuery('.term-snsbiamuc_product_attribute_image').stop(true, true).fadeOut(0);
						}else if( this.value == 'image' ){
							jQuery('.term-snsbiamuc_product_attribute_image').stop(true, true).fadeIn(100);
							jQuery('.term-snsbiamuc_product_attribute_color').stop(true, true).fadeOut(0);
						}else{
							jQuery('.term-snsbiamuc_product_attribute_color').stop(true, true).fadeOut(0);
							jQuery('.term-snsbiamuc_product_attribute_image').stop(true, true).fadeOut(0);
						}
					});
				});
			});
			</script>
			<?php
		}
		// Save term page
		public function snsbiamuc_product_attribute_save_custom_meta($term_id, $tt_id, $taxonomy){
			$fields = array(
				'snsbiamuc_product_attribute_type',
				'snsbiamuc_product_attribute_color',
				'snsbiamuc_product_attribute_image_id'
			);
			
			foreach ($fields as $field){
				if( isset($_POST[$field]) ){
					$value = !empty($_POST[$field]) ? $_POST[$field] : '';
					
					update_woocommerce_term_meta($term_id, $field, $value);
				}
			}
		}
		
	}
	SnsBiaMuc_Woocommerce::getInstance();
    // Re-render rating
    add_filter( 'woocommerce_product_get_rating_html', 'snsbiamuc_get_rating_html', 100, 2 );
    function snsbiamuc_get_rating_html(){
        global $woocommerce, $product;
        if( $product && $product->get_average_rating() ) $rating = $product->get_average_rating();
        if( isset($rating) && $rating > 0){
        	$rating_html  = '<div class="star-rating" title="' . sprintf( esc_html__( 'Rated %s out of 5', 'snsbiamuc' ), $rating ) . '">';
    		$rating_html .= '<span style="width:' . ( ( $rating / 5 ) * 100 ) . '%"><strong class="rating">' . $rating . '</strong> ' . esc_html__( 'out of 5', 'snsbiamuc' ) . '</span>';
        }else{
        	$rating_html  = '<div class="star-rating">';
        }
    	$rating_html .= '</div>';
    	return $rating_html;
    }

    // Set template view mode
    function snsbiamuc_woo_modeview() {
    	wc_get_template( 'loop/modeview.php' );
    }
    // Override quickview
    function snsbiamuc_woo_images_quickview() {
    	wc_get_template( 'single-product/product-image-quickview.php' );
    }

    function snsbiamuc_woo_query($type, $post_per_page=-1, $cat='', $offset=0, $paged=1){
        global $product, $woocommerce;
        $args = array(
            'post_type' => 'product',
            'posts_per_page' => $post_per_page,
            'post_status' => 'publish',
        	'offset'            => $offset,
            'paged' => $paged
        );
        switch ($type) {
            case 'best_selling':
                $args['meta_key']='total_sales';
                $args['orderby']='meta_value_num';
                $args['ignore_sticky_posts']   = 1;
                $args['meta_query'] = array();
                $args['meta_query'][] = $woocommerce->query->stock_status_meta_query();
                $args['meta_query'][] = $woocommerce->query->visibility_meta_query();
                break;
            case 'featured_product':
                $args['ignore_sticky_posts']=1;
                $args['meta_query'] = array();
                $args['meta_query'][] = $woocommerce->query->stock_status_meta_query();
                $args['meta_query'][] = array(
                             'key' => '_featured',
                             'value' => 'yes'
                         );
                $query_args['meta_query'][] = $woocommerce->query->visibility_meta_query();
                break;
            case 'top_rate':
                add_filter( 'posts_clauses',  array( $woocommerce->query, 'order_by_rating_post_clauses' ) );
                $args['meta_query'] = array();
                $args['meta_query'][] = $woocommerce->query->stock_status_meta_query();
                $args['meta_query'][] = $woocommerce->query->visibility_meta_query();
                break;
            case 'recent':
                $args['meta_query'] = array();
                $args['meta_query'][] = $woocommerce->query->stock_status_meta_query();
                break;
            case 'on_sale':
                $args['meta_query'] = array();
                $args['meta_query'][] = $woocommerce->query->stock_status_meta_query();
                $args['meta_query'][] = $woocommerce->query->visibility_meta_query();
                $args['post__in'] = wc_get_product_ids_on_sale();
                break;
            case 'recent_review':
                if($post_per_page == -1) $_limit = 4;
                else $_limit = $post_per_page;
                global $wpdb;
                $query = $wpdb->prepare( "
                    SELECT c.comment_post_ID 
                    FROM {$wpdb->prefix}posts p, {$wpdb->prefix}comments c 
                    WHERE p.ID = c.comment_post_ID AND c.comment_approved > %d 
                    AND p.post_type = %s AND p.post_status = %s
                    AND p.comment_count > %d ORDER BY c.comment_date ASC" ,
                    0, 'product', 'publish', 0 );
                $results = $wpdb->get_results($query, OBJECT);
                $_pids = array();
                foreach ($results as $re) {
                    if(!in_array($re->comment_post_ID, $_pids))
                        $_pids[] = $re->comment_post_ID;
                    if(count($_pids) == $_limit)
                        break;
                }

                $args['meta_query'] = array();
                $args['meta_query'][] = $woocommerce->query->stock_status_meta_query();
                $args['meta_query'][] = $woocommerce->query->visibility_meta_query();
                $args['post__in'] = $_pids;
                break;
            case 'related_products':
            	
            	break;
        }

        if($cat!=''){
            $args['product_cat']= $cat;
        }
        return new WP_Query($args);
    }

    add_filter( 'body_class', 'snsbiamuc_woo_class' );
    function snsbiamuc_woo_class( $classes ) {
        $classes[] = 'woocommerce';
        return $classes;
    }
    //
    add_action('woocommerce_single_product_summary', 'snsbiamuc_woo_addthis', 99);
    function snsbiamuc_woo_addthis(){
        global $snsbiamuc_opt;
        $html = '';
        if ( $snsbiamuc_opt['woo_sharebox'] == 1 ) {
            $html .= '<div class="sns-product-share"><lable>'.esc_html__( 'Share:', 'snsbiamuc' ).'</lable>
            <div class="addthis_toolbox addthis_default_style ">
            <a class="addthis_button_facebook_like" fb:like:layout="button_count"></a>
            <a class="addthis_button_tweet"></a>
            <a class="addthis_button_pinterest_pinit" pi:pinit:layout="horizontal"></a>
            <a class="addthis_counter addthis_pill_style"></a>
            </div>
            <script type="text/javascript">var addthis_config = {"data_track_addressbar":false};</script>
            <script type="text/javascript" src="//s7.addthis.com/js/300/addthis_widget.js#pubid=ra-507b2455057cfd5f"></script>
             </div>';
        }
        echo wp_kses($html, array(
                                'div' => array(
                                    'class' => array(),
                                ),
                                'lable' => array(
                                    'class' => array(),
                                ),
                                'a' => array(
                                    'href' => array(),
                                    'class' => array(),
                                    'fb:like:layout' => array()
                                ),
                                'script' => array(
                                    'type' => array(),
                                    'src' => array()
                                ),
                            ) );
    }
    //
    remove_action('woocommerce_after_single_product_summary', 'woocommerce_output_related_products', 20);
    add_action('woocommerce_after_single_product_summary', 'snsbiamuc_relatedproducts', 20);
    function snsbiamuc_relatedproducts() {
        global $snsbiamuc_opt;
        if ( $snsbiamuc_opt['woo_related'] == '1' ) {
            $args = array(
                'posts_per_page' => $snsbiamuc_opt['woo_related_num'],
                'orderby' => 'rand'
            );
            woocommerce_related_products( apply_filters( 'woocommerce_output_related_products_args', $args ) );
        }else{
            return;
        }
    }
    //add_action('woocommerce_after_single_product_summary', 'snsbiamuc_upsellproducts', 25);
    function snsbiamuc_upsellproducts() {
        woocommerce_upsell_display();
    }
    add_action( 'woocommerce_archive_description', 'snsbiamuc_woo_category_image', 2 );
    function snsbiamuc_woo_category_image() {
        if ( is_product_category() ){
            global $wp_query;
            $cat = $wp_query->get_queried_object();
           
            $thumbnail_id = get_woocommerce_term_meta( $cat->term_id, 'thumbnail_id', true );
            
            $image = wp_get_attachment_image_src($thumbnail_id, 'full');
            $image = isset($image[0]) ? $image[0] : '';
            if ( $image ) {
                echo '<p class="cate-img"><img src="' . esc_attr($image) . '" alt="" /></p>';
            }
        }
    }

    // Override thumbnail
    function snsbiamuc_post_thumbnail_html($html, $post_id, $post_thumbnail_id, $size, $attr) {
        if(snsbiamuc_get_option('woo_uselazyload', '1') == 1){
            $id = get_post_thumbnail_id();
            $src = wp_get_attachment_image_src($id, $size);
            $alt = get_the_title($id);
            $class = ( isset($attr['class']) ) ? $attr['class'] : '';
            if (strpos($class, 'lazy') !== false) {
                $html = '<img src="'.SNSBIAMUC_THEME_URI.'/assets/img/prod_loading.gif" alt="'.$alt.'" data-original="' . $src[0] . '" class="' . $class . '" />';
            }
        }
        return $html;
    }
    add_filter('post_thumbnail_html', 'snsbiamuc_post_thumbnail_html', 1, 5);
    
    function snsbiamuc_product_thumbnail(){
        echo snsbiamuc_woo_get_product_thumbnail();
		if( snsbiamuc_get_option('woo_product_thumb_second', '0') == 1 ){
        	echo snsbiamuc_woo_get_product_first_thumbnail();
        }
    }
    function snsbiamuc_product_thumbnail2(){
        echo snsbiamuc_woo_get_product_thumbnail2();
		
    }
    if ( ! function_exists( 'snsbiamuc_woo_get_product_thumbnail2' ) ) {
    	function snsbiamuc_woo_get_product_thumbnail2( $size = 'snsbiamuc_sc_cat_thumb', $deprecated1 = 0, $deprecated2 = 0 ) {
    		global $post;
    		$class = '';
    		if(snsbiamuc_woo_get_product_first_thumbnail()) $class = 'img-main';
    		$html = '<span class="'.$class.'">';
    		if ( has_post_thumbnail() ) {
    			if( snsbiamuc_get_option('woo_uselazyload') == 1 ){
    				$html .= get_the_post_thumbnail( $post->ID, $size, array('class' => "lazy attachment-$size") );
    			}else{
    				$html .=  get_the_post_thumbnail( $post->ID, $size );
    			}
    		} elseif ( wc_placeholder_img_src() ) {
    			$html .=  wc_placeholder_img( $size );
    		}
    		$html .= '</span>';
    		return $html;
    	}
    }
    if ( ! function_exists( 'snsbiamuc_woo_get_product_thumbnail' ) ) {
    
    	/**
    	 * Get the product thumbnail, or the placeholder if not set.
    	 *
    	 * @subpackage	Loop
    	 * @param string $size (default: 'shop_catalog')
    	 * @param int $deprecated1 Deprecated since WooCommerce 2.0 (default: 0)
    	 * @param int $deprecated2 Deprecated since WooCommerce 2.0 (default: 0)
    	 * @return string
    	 */
    	function snsbiamuc_woo_get_product_thumbnail( $size = 'shop_catalog', $deprecated1 = 0, $deprecated2 = 0 ) {
    		global $post;
    		$class = '';
    		if(snsbiamuc_woo_get_product_first_thumbnail()) $class = 'img-main';
    		$html = '<span class="'.$class.'">';
    		if ( has_post_thumbnail() ) {
    			if( snsbiamuc_get_option('woo_uselazyload') == 1 ){
    				$html .= get_the_post_thumbnail( $post->ID, $size, array('class' => "lazy attachment-$size") );
    			}else{
    				$html .=  get_the_post_thumbnail( $post->ID, $size );
    			}
    		} elseif ( wc_placeholder_img_src() ) {
    			$html .=  wc_placeholder_img( $size );
    		}
    		$html .= '</span>';
    		return $html;
    	}
    }
    if ( ! function_exists( 'snsbiamuc_woo_get_product_first_thumbnail' ) ) {
    	function snsbiamuc_woo_get_product_first_thumbnail( $size = 'shop_catalog', $deprecated1 = 0, $deprecated2 = 0 ) {
    		global $post, $product;
    		$html = '';
    		$attachment_ids = $product->get_gallery_image_ids();
    		$i = 0;
    
    		if($attachment_ids){
    			$i++;
    			foreach ( $attachment_ids as $attachment_id ) {
    				$image_link = wp_get_attachment_url( $attachment_id );
    
    				if ( ! $image_link )
    					continue;
    
    				$image_title 	= esc_attr( get_the_title( $attachment_id ) );
    					
    				if( snsbiamuc_get_option('woo_uselazyload') == 1 ){
    					$image_src = wp_get_attachment_image_src($attachment_id, $size, 0);
    					if(isset($image_src[0]))
    						$image = '<img
							src="'.SNSBIAMUC_THEME_URI.'/assets/img/prod_loading.gif'.'"
							data-original="'.$image_src[0].'"
							title="'.$image_title.'"
							alt="'.$image_title.'"
							class="lazy attachment-'.$size.'"
							/>';
    				}else{
    					$image       = wp_get_attachment_image( $attachment_id, apply_filters( 'single_product_small_thumbnail_size', $size ), 0, $attr = array(
    						'title'	=> $image_title,
    						'alt'	=> $image_title,
    					) );
    				}
    
    
    
    				$html = '<span class="img-additional">';
    				$html .= $image;
    				$html .= '</span>';
    
    				if($i == 1)
    					break;
    			}

    			return $html;
    		}
    		
    	}
    }

    add_action('woocommerce_after_cart', 'snsbiamuc_woo_jsqty', 10);
	function snsbiamuc_woo_jsqty(){
	    $html = '';
	    ob_start();
	    ?>
	    <script type="text/javascript">
	        jQuery(document).ready(function($){
	            $('.qty-decrease, .qty-increase').click(function(){
	                $( 'div.woocommerce > form input[name="update_cart"]' ).prop( 'disabled', false );
	            });
	        });
	    </script>
	    <?php
	    $html .= ob_get_clean();
	    echo $html;
	}
    
    function get_woocommerce_categories(){
    	$args = array(
    		'taxonomy' => 'product_cat'
    	);
    	 return get_categories($args);
    }

    add_filter( 'woocommerce_product_tabs', 'snsbiamuc_woo_rename_tabs', 98 );
	function snsbiamuc_woo_rename_tabs( $tabs ) {
		$tabs['description']['title'] = esc_html__( 'Description', 'snsbiamuc' );		// Rename the description tab
		// $tabs['reviews']['title'] = esc_html__( 'Ratings','snsbiamuc' );				// Rename the reviews tab
		if ( isset($tabs['additional_information']) ) {
			$tabs['additional_information']['title'] = esc_html__( 'Information','snsbiamuc' );	// Rename the additional information tab
		}
		return $tabs;
	}
}

?>