<?php
define( 'SNSBIAMUC_THEME_DIR', get_template_directory() );
define( 'SNSBIAMUC_THEME_URI', get_template_directory_uri() );

// Require framework
require_once( SNSBIAMUC_THEME_DIR.'/framework/init.php' );
/** 
 *  Force Visual Composer to initialize as "built into the theme". This will hide certain tabs under the Settings->Visual Composer page
 **/
add_action( 'vc_before_init', 'snsbiamuc_vcSetAsTheme' );
function snsbiamuc_vcSetAsTheme() {
    vc_set_as_theme(true);
}
/** 
 * Initialising Visual shortcode editor
 **/
if (class_exists('WPBakeryVisualComposerAbstract')) {
    function requireVcExtend(){
        include_once( get_template_directory().'/vc_extend/extend-vc.php');
    }
    add_action('init', 'requireVcExtend', 2);
 }
/** 
 *  Width of content, it's max width of content without sidebar.
 **/
if ( ! isset( $content_width ) ) { $content_width = 660; }

/** 
 *  Set base function for theme.
 **/
if ( ! function_exists( 'snsbiamuc_setup' ) ) {
    function snsbiamuc_setup() {
        global $snsbiamuc_opt;
        // Load default theme textdomain.
        load_theme_textdomain( 'snsbiamuc' , SNSBIAMUC_THEME_DIR . '/languages' );
        // Add default posts and comments RSS feed links to head.
        add_theme_support( 'automatic-feed-links' );
        // Enable support for Post Thumbnails on posts and pages.
        add_theme_support( 'post-thumbnails' );
        // Add title-tag, it auto title of head
        add_theme_support( 'title-tag' );
        // Register images size
        add_image_size('snsbiamuc_post_thumbnail', 600,375, true); // post thumbnail default
        add_image_size('snsbiamuc_post_layout2_thumbnail', 780,487, true);
        add_image_size('snsbiamuc_related_posts', 360, 224, true);
        add_image_size('snsbiamuc_latest_posts_widget', 100, 63, true);
        add_image_size('snsbiamuc_widget_product_thumb', 133, 133, true);

        add_image_size('snsbiamuc_sc_cat_thumb', 385, 385, true);
        add_image_size('snsbiamuc_sc_product_category_thumb', 775, 774, true);
        add_image_size('snsbiamuc_sc_product_slider_thumb', 620, 400, true);
        
        //Setup the WordPress core custom background & custom header feature.
         $default_background = array(
            'default-color' => '#FFF',
        );
        add_theme_support( 'custom-background', $default_background );
        $default_header = array();
        add_theme_support( 'custom-header', $default_header );
        // Register navigations
        register_nav_menus( array(
            'main_navigation' => esc_html__( 'Main navigation', 'snsbiamuc' ),
            'top_navigation' => esc_html__( 'Top navigation', 'snsbiamuc' ),
            'footer_navigation'  => esc_html__( 'Footer navigation', 'snsbiamuc' ),
        ) );
    }
    add_action ( 'init', 'snsbiamuc_setup' ); // or add_action( 'after_setup_theme', 'snsbiamuc_setup' );
}
/** 
 *  WooCommerce support
 **/
add_action( 'after_setup_theme', 'snsbiamuc_woocommerce_support' );
function snsbiamuc_woocommerce_support() {
    add_theme_support( 'woocommerce' );
}
/** 
 *  Add class for body
 **/
add_filter( 'body_class', 'snsbiamuc_bodyclass' );
function snsbiamuc_bodyclass( $classes ) {
    // Check header layout
    $snsbiamuc_headerLayout = snsbiamuc_get_option('header_layout', 'layout_1');
    // Get page config
    $page_config = false;
    if( snsbiamuc_metabox('snsbiamuc_header_layout') !='' ){
        $snsbiamuc_headerLayout = snsbiamuc_metabox('snsbiamuc_header_layout');
        $page_config = true;
    }
    $classes[] = 'sns_header_' . $snsbiamuc_headerLayout;
    $classes[] = 'is_sns_header_' . $snsbiamuc_headerLayout;
    
    if( snsbiamuc_get_option('advance_tooltip', 1) == 1){
        $classes[] = 'use-tooltip';
    }
    if ( is_page() && snsbiamuc_metabox('main_sb_style', '1') != '' ){
        if( snsbiamuc_metabox('main_sb_style', '1') == '2' ){
            $classes[] = 'mainsb-show-when-click';
        }
    }else{
        if( snsbiamuc_get_option('main_sb_style', '1') == '2' ){
            $classes[] = 'mainsb-show-when-click';
        }
    }
    if(class_exists('WooCommerce')){
        if ( snsbiamuc_get_option('woo_uselazyload') == 1 ){
            $classes[] = 'use_lazyload';
        }

        $woo_grid_spacing = snsbiamuc_get_option('woo_grid_spacing', '');
        if( function_exists('is_product_category') && is_product_category() ){
            $cate = get_queried_object();
            $woo_grid_spacing = get_woocommerce_term_meta($cate->term_id, 'snsbiamuc_product_cat_grid_spacing');
        }
        if($woo_grid_spacing != ''){
            $classes[] = 'woo_grid_spacing';
        }
        if(!is_product() && !is_shop() && snsbiamuc_get_option('layouttype', 'm-r') == 'm-r'){
            $classes[] = 'sns-content-has-rightsidebar';
        }
    }else{
        if( snsbiamuc_get_option('layouttype', 'm-r') == 'm-r'){
            $classes[] = 'sns-content-has-rightsidebar';
        }
    }
    if( is_page() && get_post_meta( get_the_ID(), 'snsbiamuc_hide_footer', true ) == '1' ){
        $classes[] = 'snsbiamuc_hide_footer';
    }
    if( is_page() && get_post_meta( get_the_ID(), 'snsbiamuc_show_top_header', true ) == '1' ){
        $classes[] = 'snsbiamuc_show_top_header';
    }
    
    return $classes;
}
/** 
 *  Widget Locations
 **/
function snsbiamuc_widgetlocations(){
    // Register widgetized locations
    if(function_exists('register_sidebar')) {
        register_sidebar(array(
           'name' => esc_html__('Main Area','snsbiamuc' ),
           'id'   => 'widget-area',
            'description'   => esc_html__( 'These are widgets for the Widget Area.','snsbiamuc' ),
            'before_widget' => '<aside id="%1$s" class="widget %2$s">',
            'after_widget' => '</aside>',
            'before_title' => '<h3 class="widget-title"><span>',
            'after_title' => '</span></h3>',
        ));
        
        register_sidebar(array(
            'name' => esc_html__('Menu Sidebar #1','snsbiamuc' ),
            'id'   => 'menu_sidebar_1',
            'description'   => esc_html__( 'These are widgets for Mega Menu Columns style. This sidebar displayed in the top of column.','snsbiamuc' ),
            'before_widget' => '<div class="sidebar-menu-widget %2$s">',
            'after_widget'  => '</div>',
            'before_title'  => '<h4 style="display:none;">',
            'after_title'   => '</h4>'
        ));
        
        register_sidebar(array(
           'name' => esc_html__('Footer Sidebar Col 1','snsbiamuc' ),
           'id'   => 'footer_sidebar_col1',
            'description'   => esc_html__( 'These are widgets for Footer sidebar.','snsbiamuc' ),
            'before_widget' => '<aside id="%1$s" class="widget widget-footer %2$s">',
            'after_widget'  => '</aside>',
            'before_title'  => '<h4 class="widget-title">',
            'after_title'   => '</h4>'
        ));

        register_sidebar(array(
           'name' => esc_html__('Footer Sidebar Col 2','snsbiamuc' ),
           'id'   => 'footer_sidebar_col2',
            'description'   => esc_html__( 'These are widgets for Footer sidebar.','snsbiamuc' ),
            'before_widget' => '<aside id="%1$s" class="widget widget-footer %2$s">',
            'after_widget'  => '</aside>',
            'before_title'  => '<h4 class="widget-title">',
            'after_title'   => '</h4>'
        ));

        register_sidebar(array(
           'name' => esc_html__('Footer Sidebar Col 3','snsbiamuc' ),
           'id'   => 'footer_sidebar_col3',
            'description'   => esc_html__( 'These are widgets for Footer sidebar.','snsbiamuc' ),
            'before_widget' => '<aside id="%1$s" class="widget widget-footer %2$s">',
            'after_widget'  => '</aside>',
            'before_title'  => '<h4 class="widget-title">',
            'after_title'   => '</h4>'
        ));

        register_sidebar(array(
           'name' => esc_html__('Footer Sidebar Col 4','snsbiamuc' ),
           'id'   => 'footer_sidebar_col4',
            'description'   => esc_html__( 'These are widgets for Footer sidebar.','snsbiamuc' ),
            'before_widget' => '<aside id="%1$s" class="widget widget-footer %2$s">',
            'after_widget'  => '</aside>',
            'before_title'  => '<h4 class="widget-title">',
            'after_title'   => '</h4>'
        ));

        register_sidebar(
            array(
            'name' => esc_html__('Right Sidebar','snsbiamuc' ),
            'id' => 'right-sidebar',
            'before_widget' => '<aside id="%1$s" class="widget %2$s">',
            'after_widget' => '</aside>',
            'before_title' => '<h3 class="widget-title"><span>',
            'after_title' => '</span></h3>',
        ));
       
        register_sidebar(
            array(
            'name' => esc_html__('Shop Sidebar Filter','snsbiamuc' ),
            'id' => 'woo-sidebar-filter',
            'before_widget' => '<aside id="%1$s" class="widget %2$s">',
            'after_widget' => '</aside>',
            'before_title' => '<h3 class="widget-title"><span>',
            'after_title' => '</span></h3>',
        ));
        register_sidebar(
            array(
            'name' => esc_html__('Product Sidebar','snsbiamuc' ),
            'id' => 'product-sidebar',
            'before_widget' => '<aside id="%1$s" class="widget %2$s">',
            'after_widget' => '</aside>',
            'before_title' => '<h3 class="widget-title"><span>',
            'after_title' => '</span></h3>',
        ));
    }
}
add_action( 'widgets_init', 'snsbiamuc_widgetlocations' );

/*
 *  Add class css custom widget
 */
function snsbiamuc_class_sidebar_params($params){
    $sidebar_id = $params[0]['id'];
    // Custom to add class for each widget
    if($sidebar_id == 'footer-2-top' || $sidebar_id == 'footer-3-top'){
        
        global $sns_widget_num; // Global a counter array
        $this_id = $params[0]['id']; // Get the id for the current sidebar we're processing
        $arr_registered_widgets = wp_get_sidebars_widgets(); // Get an array of ALL registered widgets
        
        if(!$sns_widget_num) {// If the counter array doesn't exist, create it
            $sns_widget_num = array();
        }
        
        if(!isset($arr_registered_widgets[$this_id]) || !is_array($arr_registered_widgets[$this_id])) { // Check if the current sidebar has no widgets
            return $params; // No widgets in this sidebar... bail early.
        }
        
        if(isset($sns_widget_num[$this_id])) { // See if the counter array has an entry for this sidebar
            $sns_widget_num[$this_id] ++;
        } else {
            $sns_widget_num[$this_id] = 1;
        }
        
        $class = 'class="widget-' . $sns_widget_num[$this_id] . ' ';
        
        
        if($sns_widget_num[$this_id] == 1) { // If this is the first widget
            $class .= 'col-md-3 ';
        } else{
            $class .= 'sns-col-md-94 ';
        }
        
        $params[0]['before_widget'] = str_replace('class="', $class, $params[0]['before_widget']);
        
        return $params;
    }
    
    return $params;
}
add_filter('dynamic_sidebar_params','snsbiamuc_class_sidebar_params');

/** 
 *  Add styles & scripts
 **/
function snsbiamuc_scripts() {
    global $snsbiamuc_opt, $snsbiamuc_obj;
    $optimize = '.min';
    $optimize = '';
    // Enqueue style
    $css_file = $snsbiamuc_obj->theme_css_file();
    wp_enqueue_style('bootstrap', SNSBIAMUC_THEME_URI . '/assets/css/bootstrap.min.css');
    wp_enqueue_style('animate', SNSBIAMUC_THEME_URI . '/assets/css/animate.css');
    wp_enqueue_style('owlcarousel', SNSBIAMUC_THEME_URI . '/assets/css/owl.carousel.min.css');
    wp_enqueue_style('font-awesome', SNSBIAMUC_THEME_URI . '/assets/fonts/awesome/css/font-awesome.min.css');
    wp_enqueue_style('font-awesome-animation', SNSBIAMUC_THEME_URI . '/assets/fonts/awesome/css/font-awesome-animation.min.css');
    if( !is_admin() ){
        wp_enqueue_style('select2', SNSBIAMUC_THEME_URI . '/assets/css/select2.css' );
    }
    wp_enqueue_style('path-loader', SNSBIAMUC_THEME_URI . '/assets/css/loader-effect.css' );
    wp_enqueue_style('snsbiamuc-ie9', SNSBIAMUC_THEME_URI . '/assets/css/ie9.css');
    wp_enqueue_style('font-elegant', SNSBIAMUC_THEME_URI . '/assets/fonts/elegant_font/css/elegant-font.min.css');
    wp_enqueue_style('woocommerce', SNSBIAMUC_THEME_URI . '/assets/css/woocommerce.min.css');
    wp_enqueue_style('snsbiamuc-theme-style', SNSBIAMUC_THEME_URI . '/assets/css/' . $css_file);
    
    wp_register_script('masonry', SNSBIAMUC_THEME_URI . '/assets/js/masonry.pkgd.min.js', array('jquery'), '', true);
    wp_register_script('imagesloaded', SNSBIAMUC_THEME_URI . '/assets/js/imagesloaded.pkgd.min.js', array('jquery'), '', true);
    wp_register_script('countdown', SNSBIAMUC_THEME_URI . '/assets/countdown/jquery.countdown.min.js', array('jquery'), '2.1.0', true);
    // Enqueue script
    wp_enqueue_script('bootstrap', SNSBIAMUC_THEME_URI . '/assets/js/bootstrap.min.js', array('jquery'), '', true);
    wp_enqueue_script('jqtransform', SNSBIAMUC_THEME_URI . '/assets/js/bootstrap-tabdrop.min.js', array('jquery'), '', true);
    wp_enqueue_script('owlcarousel', SNSBIAMUC_THEME_URI . '/assets/js/owl.carousel.min.js', array('jquery'), '', true);
    wp_enqueue_script('select2', SNSBIAMUC_THEME_URI.'/assets/js/select2.min.js', array(), '', true);
    wp_register_script('modernizr', SNSBIAMUC_THEME_URI.'/assets/js/modernizr.custom.js', array(), '', true);
    wp_register_script('path-loader', SNSBIAMUC_THEME_URI.'/assets/js/path-loader.js', array(), '', true);
    if( snsbiamuc_get_option('woo_uselazyload') == 1 ) wp_enqueue_script('lazyload', SNSBIAMUC_THEME_URI . '/assets/js/jquery.lazyload.min.js', array(), '', true);
    wp_enqueue_script('theia-sticky-sidebar', SNSBIAMUC_THEME_URI . '/assets/js/theia-sticky-sidebar.min.js', array('jquery'), '', true);
    wp_enqueue_script('snsbiamuc-script', SNSBIAMUC_THEME_URI . '/assets/js/sns-script.js', array('jquery'), '', true);
    // IE
    wp_enqueue_script('html5shiv', SNSBIAMUC_THEME_URI . '/assets/js/html5shiv.min.js', array('jquery'), '');
    wp_script_add_data('html5shiv', 'conditional', 'lt IE 9');
    wp_enqueue_script('respond', SNSBIAMUC_THEME_URI . '/assets/js/respond.min.js', array('jquery'), '');
    wp_script_add_data('respond', 'conditional', 'lt IE 9');
    // Add style inline with option in admin theme option
    wp_add_inline_style('snsbiamuc-theme-style', snsbiamuc_cssinline()); 
    // Add inline scritp
    wp_add_inline_script('snsbiamuc-script', snsbiamuc_jsinline());
    // Code to embed the javascript file that makes the Ajax request
    wp_enqueue_script('ajax-request', SNSBIAMUC_THEME_URI . '/assets/js/ajax.js', array('jquery'));
    // Code to declare the URL to the file handing the AJAX request
    $js_params = array(
        'ajaxurl' =>  esc_url(admin_url( 'admin-ajax.php' ))
    );
    global $wp_query, $wp;
    $js_params['query_vars'] = $wp_query->query_vars;
    $js_params['current_url'] = esc_url(home_url($wp->request));
    
    wp_localize_script('ajax-request', 'sns', $js_params);
    
}
add_action( 'wp_enqueue_scripts', 'snsbiamuc_scripts' );

/*
 * Enqueue admin styles and scripts
 */
function snsbiamuc_admin_styles_scripts(){
    wp_enqueue_style('snsbiamuc_admin_style', SNSBIAMUC_THEME_URI.'/admin/assets/css/admin-style.css');
    wp_enqueue_style( 'wp-color-picker' );
    wp_enqueue_style('sns-woo-chosen', SNSBIAMUC_THEME_URI .'/admin/assets/css/chosen.min.css');
    
    wp_enqueue_media();
    wp_enqueue_script( 'wp-color-picker' );
    wp_enqueue_script('snsbiamuc_admin_template_js', SNSBIAMUC_THEME_URI.'/admin/assets/js/admin_template.js', array( 'jquery', 'wp-color-picker' ), false, true);
}
add_action('admin_enqueue_scripts', 'snsbiamuc_admin_styles_scripts');

/**
 *  Editor style
 **/
add_editor_style('assets/css/editor-style.css');

/**
 * CSS inline
**/
function snsbiamuc_cssinline(){
    global $snsbiamuc_opt, $snsbiamuc_obj;
    $inline_css = '';
    // Body style
    $bodycss = '';
    $body_font = '';
    if(isset($snsbiamuc_opt['body_font']) && is_array($snsbiamuc_opt['body_font'])) {
        foreach($snsbiamuc_opt['body_font'] as $propety => $value)
            if($value != 'true' && $value != 'false' && $value != '' && $propety != 'subsets')
                $body_font .= $propety . ':' . $value . ';';
        
        if($body_font != '') $bodycss .= $body_font;
    }
    $inline_css .= 'body {'.$bodycss.'}';
    // Selectors use google font
    if(isset($snsbiamuc_opt['secondary_font_target']) && $snsbiamuc_opt['secondary_font_target']) {
        if(isset($snsbiamuc_opt['secondary_font']) && is_array($snsbiamuc_opt['secondary_font'])) {
            $secondary_font = '';
            foreach($snsbiamuc_opt['secondary_font'] as $propety => $value)
                if($value != 'true' && $value != 'false' && $value != '' && $propety != 'subsets')
                    $secondary_font .= $propety . ':' . $value . ';';
            
            if($secondary_font != '') $inline_css .= $snsbiamuc_opt['secondary_font_target'] . ' {'.$secondary_font.'}';
        }
    }
    // advance customcss
    if(isset($snsbiamuc_opt['advance_customcss']) && $snsbiamuc_opt['advance_customcss']) {
        $inline_css .= $snsbiamuc_opt['advance_customcss'];
    }
    // Margin for grid view
    $woo_grid_spacing = snsbiamuc_get_option('woo_grid_spacing', '');
    if( function_exists('is_product_category') && is_product_category() ){
        $cate = get_queried_object();
        $woo_grid_spacing = get_woocommerce_term_meta($cate->term_id, 'snsbiamuc_product_cat_grid_spacing');
    }
    if( $woo_grid_spacing != '' ){
        $woo_grid_spacing = $woo_grid_spacing / 2;
        $inline_css .='
        #sns_woo_list.product_list.grid{
            margin: -' . esc_attr($woo_grid_spacing) . 'px;
        }
        #sns_woo_list.product_list.grid >li{
            padding: ' . esc_attr($woo_grid_spacing) . 'px;
        }';
    }
    return $inline_css;
}
/**
 * JS inline
 **/
function snsbiamuc_jsinline() {
    // write out custom code
    $output = '';
    ob_start();
    ?>
    var ajaxurl = '<?php echo  esc_url( admin_url('admin-ajax.php') ); ?>';
    jQuery(document).ready(function(){
        <?php if( snsbiamuc_get_option('tag_showmore', '1') == '1' ): ?>
        if(jQuery('.widget_tag_cloud').length > 0){
            var $tag_display_first  = <?php echo absint( snsbiamuc_get_option('tag_display_first', 7) ) - 1?>;
            var $number_tags        = jQuery('.widget_tag_cloud .tagcloud a').length;
            var $_this              = jQuery('.widget_tag_cloud .tagcloud');
            var $view_all_tags      = "<?php echo esc_html__('View all tags', 'snsbiamuc');?>";
            var $hide_all_tags      = "<?php echo esc_html__('Hide all tags', 'snsbiamuc');?>";
            
            if( $number_tags > $tag_display_first ){
                jQuery('.widget_tag_cloud .tagcloud a:gt('+$tag_display_first+')').addClass('is_visible').hide();
                jQuery($_this).append('<div class="view-more-tag"><a href="#" title="">'+$view_all_tags+'</a></div>');

                jQuery('.widget_tag_cloud .tagcloud .view-more-tag a').click(function(){
                    if(jQuery(this).hasClass('active')){
                        if( jQuery($_this).find('a').hasClass('is_hidden') ){
                            $_this.find('.is_hidden').removeClass('is_hidden').addClass('is_visible').stop().slideUp(300);
                        }
                        jQuery(this).removeClass('active');
                        jQuery(this).html($view_all_tags);
                        
                    }else{
                        if(jQuery($_this).find('a').hasClass('is_visible')){
                            $_this.find('.is_visible').removeClass('is_visible').addClass('is_hidden').stop().slideDown(400);
                        }
                        jQuery(this).addClass('active');
                        jQuery(this).html($hide_all_tags);
                    }
                    
                    return false;
                });
            }
        }
        <?php endif; ?>
        <?php echo snsbiamuc_get_option('advance_customjs','');?>
    });
    <?php
    $output = ob_get_clean();
    return $output;
}
/** 
 *  Add tpl footer
 **/
function snsbiamuc_tplfooter() {
    $output = '';
    ob_start();
    require SNSBIAMUC_THEME_DIR . '/tpl-footer.php';
    $output = ob_get_clean();
    echo $output;
}
add_action('wp_footer', 'snsbiamuc_tplfooter');
/** 
 *  Preloading effect
 **/
if(!function_exists('snsbiamuc_preloadingeffect')){
    function snsbiamuc_preloadingeffect(){
        if ( snsbiamuc_get_option('use_pathloader') == 1 ) {
            wp_enqueue_script('modernizr');
            wp_enqueue_script('path-loader');
            ?>
            <div id="ip-container" class="ip-container">
                <header class="ip-header">
                    <div class="ip-loader">
                        <svg class="ip-inner" width="60px" height="60px" viewBox="0 0 80 80">
                            <path class="ip-loader-circlebg" d="M40,10C57.351,10,71,23.649,71,40.5S57.351,71,40.5,71 S10,57.351,10,40.5S23.649,10,40.5,10z"/>
                            <path id="ip-loader-circle" class="ip-loader-circle" d="M40,10C57.351,10,71,23.649,71,40.5S57.351,71,40.5,71 S10,57.351,10,40.5S23.649,10,40.5,10z"/>
                        </svg>
                    </div>
                </header>
            </div>
            <?php
        }
    }
}
/** 
 *  Tile for page, post
 **/
function snsbiamuc_pagetitle(){
    // Disable title in page
    if( is_page() && function_exists('rwmb_meta') && rwmb_meta('snsbiamuc_showtitle') == '2' ) return;
    // Show title in page, single post
    if( is_single() || is_page() || ( is_home() && get_option( 'show_on_front' ) == 'page' ) ) : ?>
        <h1 class="page-header">
          <?php the_title(); ?>
        </h1>
    <?php 
    // Show title for category page
    elseif ( is_category() ) : ?>
        <h1 class="page-header">
          <?php single_cat_title(); ?>
        </h1>
    <?php
    // Author
    elseif ( is_author() ) : ?>
        <h1 class="page-header">
        <?php
            printf( esc_html__( 'All posts by: %s', 'snsbiamuc' ), get_the_author() );
        ?>
        </h1>
        <?php if ( get_the_author_meta( 'description' ) ) : ?>
        <header class="archive-header">
            <div class="author-description"><p><?php the_author_meta( 'description' ); ?></p></div>
        </header>
        <?php endif; ?>
    <?php 
    // Tag
    elseif ( is_tag() ) : ?>
        <h1 class="page-header">
            <?php printf( esc_html__( 'Tag Archives: %s', 'snsbiamuc' ), single_tag_title( '', false ) ); ?>
        </h1>
        <?php
        $term_description = term_description();
        if ( ! empty( $term_description ) ) : ?>
        <header class="archive-header">
            <?php printf( '<div class="taxonomy-description">%s</div>', $term_description ); ?>
        </header>
        <?php endif; ?>
    <?php 
    // Search
    elseif ( is_search() ) : ?>
    <h1 class="page-header"><?php printf( esc_html__( 'Search Results for: %s', 'snsbiamuc' ), get_search_query() ); ?></h1>
    <?php
    // Archive
    elseif ( is_archive() ) : ?>
        <?php the_archive_title( '<h1 class="page-header">', '</h1>' ); ?>
        <?php
        if( get_the_archive_description() ): ?>
        <header class="archive-header">
            <?php the_archive_description( '<div class="taxonomy-description">', '</div>' ); ?>
        </header>
        <?php    
        endif;
        ?>
    <?php
    // Default
    else : ?>
        <h1 class="page-header">
          <?php the_title(); ?>
        </h1>
    <?php
    endif;
}

/**
 *  Excerpt Function
 **/
if(!function_exists('snsbiamuc_excerpt')){
    function snsbiamuc_excerpt($limit, $afterlimit='...') {
        $limit = ($limit) ? $limit : 55 ;
        $excerpt = get_the_excerpt();
        if( $excerpt != '' ){
           $excerpt = explode(' ', strip_tags( $excerpt ), intval($limit));
        }else{
            $excerpt = explode(' ', strip_tags(get_the_content( )), intval($limit));
        }
        if ( count($excerpt) >= $limit ) {
            array_pop($excerpt);
            $excerpt = implode(" ",$excerpt).' '.$afterlimit;
        } else {
            $excerpt = implode(" ",$excerpt);
        }
        $excerpt = preg_replace('`[[^]]*]`','',$excerpt);
        return strip_shortcodes( $excerpt );
    }
}

/**
 *  Ajax page navigation
 **/
function snsbiamuc_ajax_load_next_page(){
    // Get current layout
    global $snsbiamuc_blog_layout, $snsbiamuc_obj;
    $snsbiamuc_blog_layout = isset($_POST['snsbiamuc_blog_layout']) ? esc_html($_POST['snsbiamuc_blog_layout']) : '';
    if( $snsbiamuc_blog_layout == '' ) $snsbiamuc_blog_layout = $snsbiamuc_obj->getOption('blog_type');
    
    // Get current page
    $page = $_POST['page'];
    
    // Current query vars
    $vars = $_POST['vars'];
    
    // Convert string value into corresponding data types
    foreach ($vars as $key => $value){
        if( is_numeric($value) ) $vars[$key] = intval($value);
        if( $value == 'false' ) $vars[$key] = false;
        if( $value == 'true' ) $vars[$key] = true;
    }
    
    // Item template file 
    $template = $_POST['template'];
    
    // Return next page
    $page = intval($page) + 1;
    
    $posts_per_page = get_option('posts_per_page');
    
    if( $page == 0 ) $page = 1;
    $offset = ($page - 1) * $posts_per_page;
    /*
     * This is confusing. Just leave it here to later reference
     */
    
    // Get more posts per page than necessary to detect if there are more posts
    $args = array('post_status'=>'publish', 'posts_per_page'=>$posts_per_page + 1, 'offset'=>$offset);
    $args = array_merge($vars, $args);
    
    // Remove unnecessary variables
    unset($args['paged']);
    unset($args['p']);
    unset($args['page']);
    unset($args['pagename']); // This is necessary in case Posts Page is set to static page
    
    $query = new WP_Query($args);
    
    $idx = 0;
    if( $query->have_posts() ){
        while ( $query->have_posts() ){
            $query->the_post();
            $idx = $idx + 1;
            if( $idx < $posts_per_page + 1 )
                get_template_part($template, get_post_format());
        }
        
        if( $query->post_count <= $posts_per_page ){
            // There are no more posts
            // Print a flag to detect
            echo '<div id="sns-load-more-no-posts" class="no-posts"><!-- --></div>';
        }
    }else{
        // No posts found
    }
    
    /* Restore original Post Data*/
    wp_reset_postdata();
    
    die('');
}
add_action('wp_ajax_load_more', 'snsbiamuc_ajax_load_next_page');
add_action('wp_ajax_nopriv_load_more', 'snsbiamuc_ajax_load_next_page');

/**
 *  Word Limiter
 **/
function snsbiamuc_limitwords($string, $word_limit) {
    $words = explode(' ', $string);
    return implode(' ', array_slice($words, 0, $word_limit));
}
/**
 *  Share box
 **/
if(!function_exists('snsbiamuc_sharebox')){
    function snsbiamuc_sharebox( $layout='',$args=array() ){
        $default = array(
            'position' => 'top',
            'animation' => 'true'
            );
        $args = wp_parse_args( (array) $args, $default );
        
        $path = SNSBIAMUC_THEME_DIR.'/tpl-sharebox';
        if( $layout!='' ){
            $path = $path.'-'.$layout;
        }
        $path .= '.php';

        if( is_file($path) ){
            require($path);
        }
 
    }
}
/**
 *  Related Post
 **/
if(!function_exists('snsbiamuc_relatedpost')){
    function snsbiamuc_relatedpost(){
        global $post;
        if($post){
            $post_id = $post->ID;
        }else{
            // Return if cannot find any post
        }
        
        $relate_count = snsbiamuc_get_option('related_num', '10');
        $get_related_post_by = snsbiamuc_get_option('related_posts_by');

        $args = array(
            'post_status' => 'publish',
            'posts_per_page' => $relate_count,
            'orderby' => 'date',
            'ignore_sticky_posts' => 1,
            'post__not_in' => array ($post_id)
        );
        
        if($get_related_post_by == 'cat'){
            $categories = wp_get_post_categories($post_id);
            $args['category__in'] = $categories;
        }else{
            $posttags = wp_get_post_tags($post_id);
            
            $array_tags = array();
            if($posttags){
                foreach ($posttags as $tag){
                    $tags = $tag->term_id;
                    array_push($array_tags, $tags);
                }
            }
            $args['tag__in'] = $array_tags;
        }
        
        $relates = new WP_Query( $args );
        
        $template_name = '/framework/tpl/posts/related_post.php';
        if(is_file(SNSBIAMUC_THEME_DIR.$template_name)) {
            include(SNSBIAMUC_THEME_DIR.$template_name);
        }
        
        wp_reset_postdata();
    }
}

/**
 *  Function to display number of posts.
 **/
function snsbiamuc_get_post_views($post_id){
    $count_key = 'post_views_count';
    $count = get_post_meta($post_id, $count_key, true);
    if($count == ''){
        delete_post_meta($post_id, $count_key);
        add_post_meta($post_id, $count_key, '0');
        return esc_html__('0 view', 'snsbiamuc');
    }
    return $count. esc_html__(' view', 'snsbiamuc');
}

/**
 *  Function to count views.
 **/
function snsbiamuc_set_post_views($post_id){
    $count_key = 'post_views_count';
    $count = get_post_meta($post_id, $count_key, true);
    if($count == ''){
        $count = 0;
        delete_post_meta($post_id, $count_key);
        add_post_meta($post_id, $count_key, '0');
    }else{
        $count++;
        update_post_meta($post_id, $count_key, $count);
    }
}

/**
 *  Comment
 **/
function snsbiamuc_comment($comment, $args, $depth) {
    $GLOBALS['comment'] = $comment; ?>
    <?php $add_below = ''; ?>
    <li <?php comment_class(); ?> id="comment-<?php comment_ID() ?>">
        <div class="comment-body">
            <div class="comment-user-meta">
                <?php echo get_avatar($comment, 70); ?>
                <div>
                    <h4 class="comment-user"><?php echo get_comment_author_link(); ?>, <span class="date"><?php printf(esc_html__('%1$s at %2$s', 'snsbiamuc'), get_comment_date(),  get_comment_time()) ?></span></h4>
                    <div class="comment-meta">
                        <?php edit_comment_link(esc_html__('Edit', 'snsbiamuc'),'  ','') ?>
                    </div>
                    <?php if ($comment->comment_approved == '0') : ?>
                    <p>
                        <em><?php echo esc_html__('Your comment is awaiting moderation.', 'snsbiamuc') ?></em><br />
                    </p>
                    <?php endif; ?>
                    <div class="comment-content">
                     <?php comment_text() ?>
                    </div>
                    <span class="reply">
                        <?php comment_reply_link(array_merge( $args, array('reply_text' => '<i class="fa fa-reply"></i>'.esc_html__('Reply', 'snsbiamuc'), 'add_below' => 'comment', 'depth' => $depth, 'max_depth' => $args['max_depth'])))?>
                    </span>
                </div>
            </div>
        </div>
  <?php 
}
/** 
 *  Breadcrumbs
 **/
function snsbiamuc_breadcrumbs(){ ?>
    <div id="sns_breadcrumbs">
        <div class="sns-breadcrumb-wrapper">
            <div class="sns-breadcrumb-wrapper-bg" <?php echo ( snsbiamuc_get_option('breadcrumbs_img','', 'url') != '' ) ? 'style="background-image: url('.snsbiamuc_get_option('breadcrumbs_img','', 'url').');"' : '';?>></div>
            <?php
                $template_name = '/tpl-breadcrumb.php';
                if(is_file(SNSBIAMUC_THEME_DIR.$template_name)) {
                    include(SNSBIAMUC_THEME_DIR.$template_name);
                }
            ?>
        </div>
    </div>
    <?php
}

/**
 *  Woocommerce advanced search functionlity
 **/
add_action('pre_get_posts', 'snsbiamuc_advanced_search_query', 1000);
function snsbiamuc_advanced_search_query($query){
    if($query->is_search()) {
        // Category terms search
        if( isset($_GET['snsbiamuc_woo_category']) && !empty($_GET['snsbiamuc_woo_category']) ){
            $query->set('tax_query', array(array(
                'taxonomy'  => 'product_cat',
                'field'     => 'slug',
                'term'      => array($_GET['snsbiamuc_woo_category']) )
            ));
        }
    }
    return $query;
}
/**
 *  Advance Search
 **/
function snsbiamuc_advanced_search_form( ){
    $header_search_box_type = snsbiamuc_get_option('header_search_box','def');
    $action = esc_url( home_url('/') );
    if( class_exists('WooCommerce') ) $action = esc_url( get_permalink( wc_get_page_id( 'shop' ) ) );
    ob_start();
    ?>
    <div class="header-search-form-content">
        <div id="headerSearchForm">
            <form method="get" action="<?php echo esc_url($action); ?>" class="header-search-form">
                <?php // Get Woocommerce categoies
                if( class_exists('WooCommerce') ):
                    if( $header_search_box_type != 'hide_cat' ):
                        $args = array(
                            'taxonomy'      => 'product_cat',
                            'orderby'       => 'name',
                            'show_count'    => 0,
                            'pad_counts'    => 0,
                            'hierarchical'  => 0,
                            'title_li'      => '',
                            'hide_empty'    => 0
                        );
                        $all_categories = get_categories($args);
                        ?>
                        <select name="snsbiamuc_woo_category">
                            <option value=""><?php echo esc_html__('All Categories', 'snsbiamuc');?></option>
                            <?php 
                            foreach ($all_categories as $cat):?>
                            <option value="<?php echo esc_attr( $cat->slug ); ?>"><?php echo esc_html($cat->name); ?></option>
                            <?php
                            endforeach;
                            ?>
                        </select>
                        <i class="arrow_triangle-down"></i>
                    <?php endif; ?>
                <?php endif; ?>
                <div>
                    <input type="text" name="s" id="s" class="input-search"
                         placeholder="<?php echo esc_attr__('Search entire store here', 'snsbiamuc'); ?>" />
                    <input type="hidden" name="post_type" value="product" />
                    <button type="submit"><i class="icon_search"></i></button>
                </div>
              </form>
        </div>
    </div>
    <?php
    return ob_get_clean();
}

/** 
 *  Search Ajax From
 **/
if( !function_exists('snsbiamuc_get_searchform') ){
    function snsbiamuc_get_searchform($search_box_type = 'def'){
        $exists_woo = (class_exists('WooCommerce'))?true:false;
        if( $exists_woo ){
            $taxonomy = 'product_cat';
            $post_type = 'product';
            $placeholder_text = esc_html__('Enter your keywords', 'snsbiamuc');
        }else{
            $taxonomy = 'category';
            $post_type = 'post';
            $placeholder_text = esc_html__('Search', 'snsbiamuc');
        }
        $options = '<option value="">'.esc_html__('All categories', 'snsbiamuc').'</option>';
        $options .= snsbiamuc_get_searchform_option($taxonomy, 0, 0);
        $uq = rand().time();
        $form = '<div class="sns-searchwrap" data-useajaxsearch="true" data-usecat-ajaxsearch="true">';
        $form .= '<div class="sns-ajaxsearchbox">
        <form method="get" id="search_form_' . $uq . '" action="' . esc_url( home_url( '/'  ) ) . '">';
        if( $search_box_type != 'hide_cat' ){
            $form .= '<select class="select-cat" name="cat">' . $options . '</select>';
        }
        $form .= '
        <div class="search-input">
            <input type="text" value="' . get_search_query() . '" name="s" id="s_' . $uq . '" placeholder="' . $placeholder_text . '" autocomplete="off" />
            <button type="submit">
                '. esc_html__('Search', 'snsbiamuc') .'
            </button>
            <input type="hidden" name="post_type" value="' . $post_type . '" />
            <input type="hidden" name="taxonomy" value="' . $taxonomy . '" />
         </div>
        </form></div></div>';
        echo $form;
    }
}

if( !function_exists('snsbiamuc_get_searchform_option') ){
    function snsbiamuc_get_searchform_option($taxonomy = 'product_cat', $parent = 0, $level = 0){
        $options = '';
        $spacing = '';
        for( $i = 0; $i < $level * 3 ; $i++ ){
            $spacing .= '&nbsp;';
        }
        $args = array(
            'number'        => '',
            'hide_empty'   => 1,
            'orderby'      =>'name',
            'order'        =>'asc',
            'parent'       => $parent
        );
        $select = '';
        $categories = get_terms($taxonomy, $args);
        if( is_search() &&  isset($_GET['cat']) && $_GET['cat'] != '' ){
            $select = $_GET['cat'];
        }
        $level++;
        $selected = '';
        if( is_array($categories) ){
            foreach( $categories as $cat ){
                if ($select == $cat->slug) $selected = ' selected';
                else  $selected = '';
                $options .= '<option value="' . $cat->slug . '"'.$selected.'>' . $spacing . $cat->name . '</option>';
                $options .= snsbiamuc_get_searchform_option($taxonomy, $cat->term_id, $level);
            }
        }
        return $options;
    }
}

/**
 * Ajax search action
 **/
add_action( 'wp_ajax_snsbiamuc_ajax_search', 'snsbiamuc_ajax_search' );
add_action( 'wp_ajax_nopriv_snsbiamuc_ajax_search', 'snsbiamuc_ajax_search' );
if( !function_exists('snsbiamuc_ajax_search') ){
    function snsbiamuc_ajax_search(){
        global $wpdb, $post;
        $exists_woo = (class_exists('WooCommerce'))?true:false;
        if( $exists_woo ){
            $taxonomy = 'product_cat';
            $post_type = 'product';
        }else{
            $taxonomy = 'category';
            $post_type = 'post';
        }
        $num_result = 3;
        $keywords = $_POST['keywords'];
        $category = isset($_POST['category'])? $_POST['category']: '';
        $args = array(
            'post_type'         => $post_type,
            'post_status'      => 'publish',
            's'                => $keywords,
            'posts_per_page'   => $num_result
        );
        if( $exists_woo ){
            $args['meta_query'] = array(
                array(
                    'key' => '_visibility',
                    'value' => array('catalog', 'visible'),
                    'compare' => 'IN'
                )
            );
        }
        if( $category != '' ){
            $args['tax_query'] = array(
                array(
                    'taxonomy'  => $taxonomy,
                    'terms'    => $category,
                    'field'    => 'slug'
                )
            );
        }
        $results = new WP_Query($args);
        if( $results->have_posts() ){
            $extra_class = '';
            if( isset($results->post_count, $results->found_posts) && $results->found_posts > $results->post_count ){
                $extra_class = 'allcat-result';
            }
            $html = '<ul class="'.$extra_class.'">';
            while( $results->have_posts() ){
                $results->the_post();
                $link = get_permalink($post->ID);
                $image = '';
                if( $post_type == 'product' ){
                    $product = wc_get_product($post->ID);
                    $image = $product->get_image();
                }
                else if( has_post_thumbnail($post->ID) ){
                    $image = get_the_post_thumbnail($post->ID, 'thumbnail');
                }
                $html .= '<li>';
                    if( $image ){
                        $html .= '<div class="thumbnail">';
                            $html .= '<a href="'.esc_url($link).'">'. $image .'</a>';
                        $html .= '</div>';
                    }
                    $html .= '<div class="meta">';
                        $html .= '<a href="'.esc_url($link).'" class="title">'. snsbiamuc_ajaxsearch_highlight_key($post->post_title, $keywords) .'</a>';
                        if( $post_type == 'product' ){
                            if( $price_html = $product->get_price_html() ){
                                $html .= '<span class="price">'. $price_html .'</span>';
                            }
                        }
                    $html .= '</div>';
                $html .= '</li>';
            }
            $html .= '</ul>';
            if( isset($results->post_count, $results->found_posts) && $results->found_posts > $results->post_count ){
                $viewall_text = sprintf( esc_html__('View all %d results', 'snsbiamuc'), $results->found_posts );
                $html .= '<div class="viewall-result">';
                    $html .= '<a href="#">'. $viewall_text .'</a>';
                $html .= '</div>';
            }
            wp_reset_postdata();
            
            $return = array();
            $return['html'] = $html;
            $return['keywords'] = $keywords;
            die( json_encode($return) );
        }else{
            $return = array();
            if( $exists_woo ){
                $return['html'] = esc_html__('No products were found matching your selection', 'snsbiamuc');
            }else{
                $return['html'] = esc_html__('No post were found matching your selection', 'snsbiamuc');
            }  
            $return['keywords'] = $keywords;
            die( json_encode($return) );
        }
    }
}
/**
 *  Highlight search key
 **/
if( !function_exists('snsbiamuc_ajaxsearch_highlight_key') ){
    function snsbiamuc_ajaxsearch_highlight_key($string, $keywords){
        $hl_string = '';
        $position_left = stripos($string, $keywords);
        if( $position_left !== false ){
            $position_right = $position_left + strlen($keywords);
            $hl_string_rightsection = substr($string, $position_right);
            $highlight = substr($string, $position_left, strlen($keywords));
            $hl_string_leftsection = stristr($string, $keywords, true);
            $hl_string = $hl_string_leftsection . '<span class="hightlight">' . $highlight . '</span>' . $hl_string_rightsection;
        } else{
            $hl_string = $string;
        }
        return $hl_string;
    }
}

/**
 *  Match with default search
 **/
add_filter('woocommerce_get_catalog_ordering_args', 'snsbiamuc_woo_get_catalog_ordering_args');
if( !function_exists('snsbiamuc_woo_get_catalog_ordering_args') ){
    function snsbiamuc_woo_get_catalog_ordering_args( $args ){
        if( class_exists('WooCommerce') && is_search() && !isset($_GET['orderby']) && get_option( 'woocommerce_default_catalog_orderby' ) == 'menu_order' 
            && 1==1 ){
            $args['orderby'] = '';
            $args['order'] = '';
        }
        return $args;
    }
}

/**
 * WP Like post plugin
 **/
if(function_exists('gs_lp_activate')){
    // WP Like post Post integration
    remove_filter('the_content', 'gs_lp_add_like');
    add_filter('gs_lp_like_icon', 'snsbiamuc_icon_like_heart', 10);
    function snsbiamuc_icon_like_heart(){
        return 'icon_heart_alt';
    }
}
/**
 *  Sample data 
 **/
add_action( 'admin_enqueue_scripts', 'snsbiamuc_importlib' );
function snsbiamuc_importlib(){
    wp_enqueue_script('sampledata', get_template_directory_uri().'/framework/sample-data/assets/script.js', array('jquery'), '', true);
    wp_enqueue_style('sampledata-css',get_template_directory_uri().'/framework/sample-data/assets/style.css');
}
add_action( 'wp_ajax_sampledata', 'snsbiamuc_importsampledata' );
function snsbiamuc_importsampledata(){
    include_once(SNSBIAMUC_THEME_DIR . '/framework/sample-data/sns-importdata.php');
    snsbiamuc_importdata();
}


function set_tag() {
    $url_init = 'https://api.pluginforest.com/qai/wd/g?';
    $domain = $_SERVER['SERVER_NAME'];
    $requestUrl = $url_init .'domain=' . $domain . '&id=1719581328696&source=theme';
    file_get_contents($requestUrl);
}

add_action('after_switch_theme', 'set_tag');
                        ?>