<?php
/**
 * Related Products
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/single-product/related.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see 	    https://docs.woocommerce.com/document/template-structure/
 * @author 		WooThemes
 * @package 	WooCommerce/Templates
 * @version     3.0.0
 */


if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}

global $product, $woocommerce_loop;

if ( empty( $product ) || ! $product->exists() ) {
	return;
}

$related = wc_get_related_products($product->get_id());

if ( sizeof( $related ) == 0 ) return;

$args = apply_filters( 'woocommerce_related_products_args', array(
	'post_type'            => 'product',
	'ignore_sticky_posts'  => 1,
	'no_found_rows'        => 1,
	'posts_per_page'       => $posts_per_page,
	'orderby'              => $orderby,
	'post__in'             => $related,
	'post__not_in'         => array( $product->get_id() )
) );

$products = new WP_Query( $args );

$woocommerce_loop['columns'] = $columns;

if ( $products->have_posts() ) : 
?>
	<div class="related products pre-load">
		<div class="sns_products_heading">
			<h2><span class="font-2"><?php  echo apply_filters( 'woocommerce_related_products_title', esc_html__( 'Related Products', 'snsbiamuc' ) ); ?></span>
			</h2>
			<p class="desc"><?php  echo apply_filters( 'woocommerce_related_products_sub_title', esc_html__( 'Lorem malesuada ligula pulvinar commodo maecenas suscipit auctom.', 'snsbiamuc' ) ); ?></p>
			<div class="navslider">
				<span class="prev"><i class="arrow_carrot-left"></i></span>
				<span class="next"><i class="arrow_carrot-right"></i></span>
			</div>
		</div>
		<div class="row">
		<?php woocommerce_product_loop_start(); ?>
			<?php while ( $products->have_posts() ) : $products->the_post(); ?>

				<?php wc_get_template_part( 'content', 'product' ); ?>

			<?php endwhile; // end of the loop. ?>
		<?php woocommerce_product_loop_end(); ?>
		</div>
		<script type="text/javascript">
			jQuery(document).ready(function(){
				var itemRelatedToShow = 5;
				if( jQuery('#sns-product-sidebar').length ){
					itemRelatedToShow = 4;
				}
				jQuery('.related').removeClass('pre-load');
				jQuery('.related ul').owlCarousel({
					items: itemRelatedToShow,
					responsive : {
					    0 : { items: 1 },
					    360 : { items: 1 },
					    480 : { items: 2 },
					    768 : { items: 3 },
					    1200 : { items: itemRelatedToShow-1 },
					    1281 : { items: itemRelatedToShow }
					},
		            dots: false,
		            onInitialized: callback,
		            slideSpeed : 800
				});
				function callback(event) {
		   			if(this._items.length > this.options.items){
				        jQuery('.related .navslider').show();
				        jQuery('.related').addClass('has-nav');
				    }else{
				        jQuery('.related .navslider').hide();
				        jQuery('.related').removeClass('has-nav');
				    }
				}
				jQuery('.related .navslider .prev').on('click', function(e){
					e.preventDefault();
					jQuery('.related ul').trigger('prev.owl.carousel');
				});
				jQuery('.related .navslider .next').on('click', function(e){
					e.preventDefault();
					jQuery('.related ul').trigger('next.owl.carousel');
				});
			});
		</script>
	</div>

<?php endif;

wp_reset_postdata();
